:root { --blue-1: #99c1f1; --blue-2: #62a0ea; --blue-3: #3584e4; --blue-4: #1c71d8; --blue-5: #1a5fb4; --green-1: #8ff0a4; --green-2: #57e389; --green-3: #33d17a; --green-4: #2ec27e; --green-5: #26a269; --yellow-1: #f9f06b; --yellow-2: #f8e45c; --yellow-3: #f6d32d; --yellow-4: #f5c211; --yellow-5: #e5a50a; --orange-1: #ffbe6f; --orange-2: #ffa348; --orange-3: #ff7800; --orange-4: #e66100; --orange-5: #c64600; --red-1: #f66151; --red-2: #ed333b; --red-3: #e01b24; --red-4: #c01c28; --red-5: #a51d2d; --purple-1: #dc8add; --purple-2: #c061cb; --purple-3: #9141ac; --purple-4: #813d9c; --purple-5: #613583; --brown-1: #cdab8f; --brown-2: #b5835a; --brown-3: #986a44; --brown-4: #865e3c; --brown-5: #63452c; --light-1: #ffffff; --light-2: #f6f5f4; --light-3: #deddda; --light-4: #c0bfbc; --light-5: #9a9996; --dark-1: #77767b; --dark-2: #5e5c64; --dark-3: #3d3846; --dark-4: #241f31; --dark-5: #000000; }

@define-color blue_1 #99c1f1;
@define-color blue_2 #62a0ea;
@define-color blue_3 #3584e4;
@define-color blue_4 #1c71d8;
@define-color blue_5 #1a5fb4;
@define-color green_1 #8ff0a4;
@define-color green_2 #57e389;
@define-color green_3 #33d17a;
@define-color green_4 #2ec27e;
@define-color green_5 #26a269;
@define-color yellow_1 #f9f06b;
@define-color yellow_2 #f8e45c;
@define-color yellow_3 #f6d32d;
@define-color yellow_4 #f5c211;
@define-color yellow_5 #e5a50a;
@define-color orange_1 #ffbe6f;
@define-color orange_2 #ffa348;
@define-color orange_3 #ff7800;
@define-color orange_4 #e66100;
@define-color orange_5 #c64600;
@define-color red_1 #f66151;
@define-color red_2 #ed333b;
@define-color red_3 #e01b24;
@define-color red_4 #c01c28;
@define-color red_5 #a51d2d;
@define-color purple_1 #dc8add;
@define-color purple_2 #c061cb;
@define-color purple_3 #9141ac;
@define-color purple_4 #813d9c;
@define-color purple_5 #613583;
@define-color brown_1 #cdab8f;
@define-color brown_2 #b5835a;
@define-color brown_3 #986a44;
@define-color brown_4 #865e3c;
@define-color brown_5 #63452c;
@define-color light_1 #ffffff;
@define-color light_2 #f6f5f4;
@define-color light_3 #deddda;
@define-color light_4 #c0bfbc;
@define-color light_5 #9a9996;
@define-color dark_1 #77767b;
@define-color dark_2 #5e5c64;
@define-color dark_3 #3d3846;
@define-color dark_4 #241f31;
@define-color dark_5 #000000;
/* GTK NAMED COLORS ---------------- use responsibly! */
@define-color destructive_bg_color @red_3;
@define-color destructive_fg_color white;
@define-color success_bg_color @green_4;
@define-color success_fg_color white;
@define-color warning_bg_color @yellow_5;
@define-color warning_fg_color RGB(0 0 0 / 80%);
@define-color error_bg_color @red_3;
@define-color error_fg_color white;
@define-color accent_color oklab(from @accent_bg_color min(l, 0.5) a b);
@define-color destructive_color oklab(from @destructive_bg_color min(l, 0.5) a b);
@define-color success_color oklab(from @success_bg_color min(l, 0.5) a b);
@define-color warning_color oklab(from @warning_bg_color min(l, 0.5) a b);
@define-color error_color oklab(from @error_bg_color min(l, 0.5) a b);
@define-color window_bg_color #fafafb;
@define-color window_fg_color RGB(0 0 6 / 80%);
@define-color view_bg_color #ffffff;
@define-color view_fg_color RGB(0 0 6 / 80%);
@define-color headerbar_bg_color #ffffff;
@define-color headerbar_fg_color RGB(0 0 6 / 80%);
@define-color headerbar_border_color RGB(0 0 6 / 80%);
@define-color headerbar_backdrop_color @window_bg_color;
@define-color headerbar_shade_color RGB(0 0 6 / 12%);
@define-color headerbar_darker_shade_color RGB(0 0 6 / 12%);
@define-color sidebar_bg_color #ebebed;
@define-color sidebar_fg_color RGB(0 0 6 / 80%);
@define-color sidebar_backdrop_color #f2f2f4;
@define-color sidebar_shade_color RGB(0 0 6 / 7%);
@define-color sidebar_border_color RGB(0 0 6 / 7%);
@define-color secondary_sidebar_bg_color #f3f3f5;
@define-color secondary_sidebar_fg_color RGB(0 0 6 / 80%);
@define-color secondary_sidebar_backdrop_color #f6f6fa;
@define-color secondary_sidebar_shade_color RGB(0 0 6 / 7%);
@define-color secondary_sidebar_border_color RGB(0 0 6 / 7%);
@define-color card_bg_color #ffffff;
@define-color card_fg_color RGB(0 0 6 / 80%);
@define-color card_shade_color RGB(0 0 6 / 7%);
@define-color dialog_bg_color #fafafb;
@define-color dialog_fg_color RGB(0 0 6 / 80%);
@define-color popover_bg_color #ffffff;
@define-color popover_fg_color RGB(0 0 6 / 80%);
@define-color popover_shade_color RGB(0 0 6 / 7%);
@define-color thumbnail_bg_color #ffffff;
@define-color thumbnail_fg_color RGB(0 0 6 / 80%);
@define-color shade_color RGB(0 0 6 / 7%);
@define-color scrollbar_outline_color white;
@media (prefers-color-scheme: dark) { @define-color destructive_bg_color @red_4; @define-color success_bg_color @green_5; @define-color warning_bg_color #cd9309; @define-color error_bg_color @red_4; @define-color accent_color oklab(from @accent_bg_color min(l, 0.5) a b); @define-color destructive_color oklab(from @destructive_bg_color min(l, 0.5) a b); @define-color success_color oklab(from @success_bg_color min(l, 0.5) a b); @define-color warning_color oklab(from @warning_bg_color min(l, 0.5) a b); @define-color error_color oklab(from @error_bg_color min(l, 0.5) a b); @define-color accent_color oklab(from @accent_bg_color max(l, 0.85) a b); @define-color destructive_color oklab(from @destructive_bg_color max(l, 0.85) a b); @define-color success_color oklab(from @success_bg_color max(l, 0.85) a b); @define-color warning_color oklab(from @warning_bg_color max(l, 0.85) a b); @define-color error_color oklab(from @error_bg_color max(l, 0.85) a b); @define-color window_bg_color #222226; @define-color window_fg_color white; @define-color view_bg_color #1d1d20; @define-color view_fg_color white; @define-color headerbar_bg_color #2e2e32; @define-color headerbar_fg_color white; @define-color headerbar_border_color white; @define-color headerbar_shade_color RGB(0 0 6 / 36%); @define-color headerbar_darker_shade_color RGB(0 0 12 / 90%); @define-color sidebar_bg_color #2e2e32; @define-color sidebar_fg_color white; @define-color sidebar_backdrop_color #28282c; @define-color sidebar_shade_color RGB(0 0 6 / 25%); @define-color sidebar_border_color RGB(0 0 6 / 36%); @define-color secondary_sidebar_bg_color #28282c; @define-color secondary_sidebar_fg_color white; @define-color secondary_sidebar_backdrop_color #252529; @define-color secondary_sidebar_shade_color RGB(0 0 6 / 25%); @define-color secondary_sidebar_border_color RGB(0 0 6 / 36%); @define-color card_bg_color RGB(255 255 255 / 8%); @define-color card_fg_color white; @define-color card_shade_color RGB(0 0 6 / 36%); @define-color dialog_bg_color #36363a; @define-color dialog_fg_color white; @define-color popover_bg_color #36363a; @define-color popover_fg_color white; @define-color popover_shade_color RGB(0 0 6 / 25%); @define-color thumbnail_bg_color #39393d; @define-color thumbnail_fg_color white; @define-color shade_color RGB(0 0 6 / 25%); @define-color scrollbar_outline_color RGB(0 0 12 / 95%); }

:root { --standalone-color-oklab: min(l, 0.5) a b; }

@media (prefers-color-scheme: dark) { :root { --standalone-color-oklab: max(l, 0.85) a b; } }

:root { --accent-blue: #3584e4; --accent-teal: #2190a4; --accent-green: #3a944a; --accent-yellow: #c88800; --accent-orange: #ed5b00; --accent-red: #e62d42; --accent-pink: #d56199; --accent-purple: #9141ac; --accent-slate: #6f8396; --accent-bg-color: @accent_bg_color; --accent-fg-color: @accent_fg_color; --accent-color: oklab(
    from var(--accent-bg-color) var(--standalone-color-oklab)
  ); --destructive-bg-color: @destructive_bg_color; --destructive-fg-color: @destructive_fg_color; --destructive-color: oklab(
    from var(--destructive-bg-color) var(--standalone-color-oklab)
  ); --success-bg-color: @success_bg_color; --success-fg-color: @success_fg_color; --success-color: oklab(
    from var(--success-bg-color) var(--standalone-color-oklab)
  ); --warning-bg-color: @warning_bg_color; --warning-fg-color: @warning_fg_color; --warning-color: oklab(
    from var(--warning-bg-color) var(--standalone-color-oklab)
  ); --error-bg-color: @error_bg_color; --error-fg-color: @error_fg_color; --error-color: oklab(
    from var(--error-bg-color) var(--standalone-color-oklab)
  ); --window-bg-color: @window_bg_color; --window-fg-color: @window_fg_color; --view-bg-color: @view_bg_color; --view-fg-color: @view_fg_color; --headerbar-bg-color: @headerbar_bg_color; --headerbar-fg-color: @headerbar_fg_color; --headerbar-border-color: @headerbar_border_color; --headerbar-backdrop-color: @headerbar_backdrop_color; --headerbar-shade-color: @headerbar_shade_color; --headerbar-darker-shade-color: @headerbar_darker_shade_color; --sidebar-bg-color: @sidebar_bg_color; --sidebar-fg-color: @sidebar_fg_color; --sidebar-backdrop-color: @sidebar_backdrop_color; --sidebar-border-color: @sidebar_border_color; --sidebar-shade-color: @sidebar_shade_color; --secondary-sidebar-bg-color: @secondary_sidebar_bg_color; --secondary-sidebar-fg-color: @secondary_sidebar_fg_color; --secondary-sidebar-backdrop-color: @secondary_sidebar_backdrop_color; --secondary-sidebar-border-color: @secondary_sidebar_border_color; --secondary-sidebar-shade-color: @secondary_sidebar_shade_color; --card-bg-color: @card_bg_color; --card-fg-color: @card_fg_color; --card-shade-color: @card_shade_color; --dialog-bg-color: @dialog_bg_color; --dialog-fg-color: @dialog_fg_color; --popover-bg-color: @popover_bg_color; --popover-fg-color: @popover_fg_color; --popover-shade-color: @popover_shade_color; --thumbnail-bg-color: @thumbnail_bg_color; --thumbnail-fg-color: @thumbnail_fg_color; --shade-color: @shade_color; --scrollbar-outline-color: @scrollbar_outline_color; --active-toggle-bg-color: #ffffff; --active-toggle-fg-color: rgb(0 0 6 / 80%); --overview-bg-color: #f3f3f5; --overview-fg-color: rgb(0 0 6 / 80%); }

@media (prefers-color-scheme: dark) { :root { --active-toggle-bg-color: rgb(255 255 255 / 20%); --active-toggle-fg-color: #ffffff; --overview-bg-color: #28282c; --overview-fg-color: #ffffff; } }

:root { --border-color: color-mix(in srgb, currentColor var(--border-opacity), transparent); --border-opacity: 15%; --dim-opacity: 55%; --disabled-opacity: 50%; }

:root { --window-radius: 15px; }

.background { color: var(--window-fg-color); background-color: var(--window-bg-color); }

dnd { color: var(--window-fg-color); }

.normal-icons { -gtk-icon-size: 16px; }

.large-icons { -gtk-icon-size: 32px; }

.osd popover > arrow, .osd popover > contents, popover.touch-selection > arrow, popover.touch-selection > contents, popover.magnifier > arrow, popover.magnifier > contents, .app-notification, dialog-host > dialog.osd:not(progressbar):not(button):not(menubutton):not(splitbutton) sheet, .osd:not(progressbar):not(button):not(menubutton):not(splitbutton):not(inline-view-switcher) { --accent-bg-color: RGB(255 255 255 / 75%); --accent-fg-color: RGB(0 0 0 / 75%); --scrollbar-outline-color: RGB(0 0 0 / 50%); --standalone-color-oklab: Max(l, 0.85) a b; --accent-color: oklab(from var(--accent-bg-color) var(--standalone-color-oklab)); --destructive-color: oklab(from var(--destructive-bg-color) var(--standalone-color-oklab)); --success-color: oklab(from var(--success-bg-color) var(--standalone-color-oklab)); --warning-color: oklab(from var(--warning-bg-color) var(--standalone-color-oklab)); --error-color: oklab(from var(--error-bg-color) var(--standalone-color-oklab)); color: RGB(255 255 255/90%); border: none; background-color: RGB(0 0 0/70%); background-clip: padding-box; }

/* Text selection */
selection { background-color: color-mix(in srgb, var(--view-fg-color) 10%, transparent); color: transparent; }

selection:focus-within { background-color: color-mix(in srgb, var(--accent-bg-color) 30%, transparent); }

:not(window):drop(active):focus, :not(window):drop(active) { border-color: var(--accent-bg-color); box-shadow: inset 0 0 0 1px var(--accent-bg-color); caret-color: var(--accent-bg-color); }

placessidebar :not(window):drop(active):focus, placessidebar :not(window):drop(active), stackswitcher :not(window):drop(active):focus, stackswitcher :not(window):drop(active), expander-widget :not(window):drop(active):focus, expander-widget :not(window):drop(active) { box-shadow: none; }

/* Outline for low res icons */
.lowres-icon { -gtk-icon-shadow: 0 -1px RGB(0 0 6/5%), 1px 0 RGB(0 0 6/10%), 0 1px RGB(0 0 6/30%), -1px 0 RGB(0 0 6/10%); }

/* Drop shadow for large icons */
.icon-dropshadow { -gtk-icon-shadow: 0 1px 12px RGB(0 0 6/5%), 0 -1px RGB(0 0 6/5%), 1px 0 RGB(0 0 6/10%), 0 1px RGB(0 0 6/30%), -1px 0 RGB(0 0 6/10%); }

@keyframes needs_attention { from { background-image: radial-gradient(farthest-side, var(--accent-color) 0%, transparent 0%); }
  to { background-image: radial-gradient(farthest-side, var(--accent-color) 95%, transparent); } }

stacksidebar row.needs-attention > label, stackswitcher > button.needs-attention > label, stackswitcher > button.needs-attention > image { animation: needs_attention 150ms ease-in; background-image: radial-gradient(farthest-side, var(--accent-color) 96%, transparent); background-size: 6px 6px; background-repeat: no-repeat; background-position: right 3px; }

stacksidebar row.needs-attention > label:dir(rtl), stackswitcher > button.needs-attention > label:dir(rtl), stackswitcher > button.needs-attention > image:dir(rtl) { background-position: left 3px; }

avatar { border-radius: 9999px; font-weight: bold; }

avatar.color1 { background-image: linear-gradient(#83b6ec, #337fdc); color: #cfe1f5; }

avatar.color2 { background-image: linear-gradient(#7ad9f1, #0f9ac8); color: #caeaf2; }

avatar.color3 { background-image: linear-gradient(#8de6b1, #29ae74); color: #cef8d8; }

avatar.color4 { background-image: linear-gradient(#b5e98a, #6ab85b); color: #e6f9d7; }

avatar.color5 { background-image: linear-gradient(#f8e359, #d29d09); color: #f9f4e1; }

avatar.color6 { background-image: linear-gradient(#ffcb62, #d68400); color: #ffead1; }

avatar.color7 { background-image: linear-gradient(#ffa95a, #ed5b00); color: #ffe5c5; }

avatar.color8 { background-image: linear-gradient(#f78773, #e62d42); color: #f8d2ce; }

avatar.color9 { background-image: linear-gradient(#e973ab, #e33b6a); color: #fac7de; }

avatar.color10 { background-image: linear-gradient(#cb78d4, #9945b5); color: #e7c2e8; }

avatar.color11 { background-image: linear-gradient(#9e91e8, #7a59ca); color: #d5d2f5; }

avatar.color12 { background-image: linear-gradient(#e3cf9c, #b08952); color: #f2eade; }

avatar.color13 { background-image: linear-gradient(#be916d, #785336); color: #e5d6ca; }

avatar.color14 { background-image: linear-gradient(#c0bfbc, #6e6d71); color: #d8d7d3; }

avatar.contrasted { color: white; }

avatar.image { background: none; }

bottom-sheet > dimming { background-color: RGB(from var(--shade-color) r g b/calc(alpha * 2)); }

bottom-sheet > sheet { box-shadow: 0 0 14px 2px RGB(0 0 6/3%), 0 0 5px 2px RGB(0 0 6/10%), 0 0 0 1px RGB(0 0 0 / 5%); transition: border-radius 100ms ease-out, box-shadow 250ms ease; }

bottom-sheet > sheet > stack > widget > drag-handle { background-color: color-mix(in srgb, currentColor 25%, transparent); min-width: 54px; min-height: 6px; margin: 15px; border-radius: 99px; }

bottom-sheet > sheet > outline { box-shadow: inset 1px 0 RGB(255 255 255/7%), inset -1px 0 RGB(255 255 255/7%), inset 0 1px RGB(255 255 255/7%); transition: border-radius 100ms ease-out; }

bottom-sheet > sheet > stack > button { border-radius: 0; padding: 0; min-width: 0; min-height: 0; font-weight: inherit; background: none; box-shadow: none; }

bottom-sheet > sheet > stack > button { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

bottom-sheet > sheet > stack > button:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: 0; }

bottom-sheet > sheet > stack > button:hover { background: color-mix(in srgb, currentColor 4%, transparent); }

bottom-sheet > sheet > stack > button.keyboard-activating, bottom-sheet > sheet > stack > button:active { background: color-mix(in srgb, currentColor 8%, transparent); }

bottom-sheet > sheet > stack > button.inert:hover, bottom-sheet > sheet > stack > button.inert:active, bottom-sheet > sheet > stack > button.inert.keyboard-activating { background: none; }

bottom-sheet > sheet, bottom-sheet > sheet > outline, bottom-sheet > sheet > stack > widget, bottom-sheet > sheet > stack > button, bottom-sheet > sheet > stack > button > widget { border-top-left-radius: 15px; border-top-right-radius: 15px; }

bottom-sheet > sheet.flush-left > outline { box-shadow: inset -1px 0 RGB(255 255 255/7%), inset 0 1px RGB(255 255 255/7%); }

bottom-sheet > sheet.flush-right > outline { box-shadow: inset 1px 0 RGB(255 255 255/7%), inset 0 1px RGB(255 255 255/7%); }

bottom-sheet > sheet.flush-left.flush-right > outline { box-shadow: inset 0 1px RGB(255 255 255/7%); }

bottom-sheet > sheet.bottom-bar { box-shadow: 0 0 0 1px color-mix(in srgb, var(--shade-color) 75%, transparent), 0 2px 8px 2px var(--shade-color), 0 3px 20px 10px RGB(0 0 6/5%), 0 6px 32px 16px RGB(0 0 6/2%); }

bottom-sheet > sheet.bottom-bar.hidden { box-shadow: none; }

bottom-sheet > sheet.bottom-bar.flush-left, bottom-sheet > sheet.bottom-bar.flush-left > outline, bottom-sheet > sheet.bottom-bar.flush-left > stack > widget, bottom-sheet > sheet.bottom-bar.flush-left > stack > button, bottom-sheet > sheet.bottom-bar.flush-left > stack > button > widget { border-top-left-radius: 0; }

bottom-sheet > sheet.bottom-bar.flush-right, bottom-sheet > sheet.bottom-bar.flush-right > outline, bottom-sheet > sheet.bottom-bar.flush-right > stack > widget, bottom-sheet > sheet.bottom-bar.flush-right > stack > button, bottom-sheet > sheet.bottom-bar.flush-right > stack > button > widget { border-top-right-radius: 0; }

bottom-sheet > sheet.bottom-bar > outline, bottom-sheet > sheet.bottom-bar > stack > widget, bottom-sheet > sheet.bottom-bar > stack > button, bottom-sheet > sheet.bottom-bar > stack > button > widget, bottom-sheet > sheet.bottom-bar.flush-left > outline, bottom-sheet > sheet.bottom-bar.flush-left > stack > widget, bottom-sheet > sheet.bottom-bar.flush-left > stack > button, bottom-sheet > sheet.bottom-bar.flush-left > stack > button > widget, bottom-sheet > sheet.bottom-bar.flush-right > outline, bottom-sheet > sheet.bottom-bar.flush-right > stack > widget, bottom-sheet > sheet.bottom-bar.flush-right > stack > button, bottom-sheet > sheet.bottom-bar.flush-right > stack > button > widget, bottom-sheet > sheet.bottom-bar.flush-left.flush-right > outline, bottom-sheet > sheet.bottom-bar.flush-left.flush-right > stack > widget, bottom-sheet > sheet.bottom-bar.flush-left.flush-right > stack > button, bottom-sheet > sheet.bottom-bar.flush-left.flush-right > stack > button > widget { box-shadow: none; }

bottom-sheet > sheet.has-drag-handle toolbarview .top-bar > windowhandle { min-height: 36px; }

bottom-sheet > sheet.has-drag-handle toolbarview toolbarview .top-bar > windowhandle { min-height: 0; }

notebook > header > tabs > arrow, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay, button { min-height: 24px; min-width: 16px; padding: 5px 10px; border-radius: 9px; font-weight: bold; }

notebook > header > tabs > arrow, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay, button { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

notebook > header > tabs > arrow:focus:focus-visible, row.spin spinbutton > button.image-button.up:focus:focus-visible:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.down:focus:focus-visible:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:focus:focus-visible:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:focus:focus-visible:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay:focus:focus-visible, button:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

actionbar > revealer > box popover menubutton.image-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, searchbar > revealer > box popover menubutton.image-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, .toolbar popover menubutton.image-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, headerbar popover menubutton.image-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, actionbar > revealer > box popover button.arrow-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.arrow-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.arrow-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.arrow-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-text-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-text-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-text-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-text-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay, button { background-color: color-mix(in srgb, currentColor 10%, transparent); }

actionbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:hover, searchbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:hover, .toolbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:hover, headerbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:hover, actionbar > revealer > box popover button.arrow-button:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.arrow-button:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.arrow-button:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.arrow-button:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-button:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-button:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-button:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-button:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-text-button:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-text-button:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-text-button:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-text-button:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.arrow-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.arrow-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.arrow-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.arrow-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-text-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-text-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-text-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-text-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.arrow-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.arrow-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.arrow-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.arrow-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-text-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-text-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-text-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-text-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow:hover, row.spin spinbutton > button.image-button.up:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.image-button.down:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay:hover, button:hover { background-color: color-mix(in srgb, currentColor 15%, transparent); }

actionbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button.keyboard-activating, searchbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button.keyboard-activating, .toolbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button.keyboard-activating, headerbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button.keyboard-activating, actionbar > revealer > box popover button.keyboard-activating.arrow-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.keyboard-activating.arrow-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.keyboard-activating.arrow-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.keyboard-activating.arrow-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.keyboard-activating.image-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.keyboard-activating.image-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.keyboard-activating.image-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.keyboard-activating.image-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.keyboard-activating.image-text-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.keyboard-activating.image-text-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.keyboard-activating.image-text-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.keyboard-activating.image-text-button:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.keyboard-activating.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.keyboard-activating.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.keyboard-activating.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.keyboard-activating.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.keyboard-activating.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.keyboard-activating.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.keyboard-activating.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.keyboard-activating.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.keyboard-activating.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.keyboard-activating.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.keyboard-activating.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.keyboard-activating.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.keyboard-activating.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.keyboard-activating.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.keyboard-activating.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.keyboard-activating.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.keyboard-activating.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.keyboard-activating.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.keyboard-activating.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.keyboard-activating.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.keyboard-activating.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.keyboard-activating.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.keyboard-activating.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.keyboard-activating.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:active, searchbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:active, .toolbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:active, headerbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:active, actionbar > revealer > box popover button.arrow-button:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.arrow-button:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.arrow-button:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.arrow-button:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-button:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-button:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-button:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-button:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-text-button:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-text-button:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-text-button:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-text-button:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.arrow-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.arrow-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.arrow-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.arrow-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-text-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-text-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-text-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-text-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.arrow-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.arrow-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.arrow-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.arrow-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-text-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-text-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-text-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-text-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow.keyboard-activating, row.spin spinbutton > button.keyboard-activating.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.keyboard-activating.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.keyboard-activating.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.keyboard-activating.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.keyboard-activating.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.keyboard-activating.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay.keyboard-activating, notebook > header > tabs > arrow:active, row.spin spinbutton > button.image-button.up:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.image-button.down:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay:active, button.keyboard-activating, button:active { background-color: color-mix(in srgb, currentColor 30%, transparent); }

actionbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked, searchbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked, .toolbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked, headerbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked, actionbar > revealer > box popover button.arrow-button:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.arrow-button:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.arrow-button:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.arrow-button:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-button:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-button:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-button:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-button:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-text-button:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-text-button:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-text-button:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-text-button:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.arrow-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.arrow-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.arrow-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.arrow-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-text-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-text-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-text-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-text-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.arrow-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.arrow-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.arrow-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.arrow-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-text-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-text-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-text-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-text-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow:checked, row.spin spinbutton > button.image-button.up:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.image-button.down:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay:checked, button:checked { background-color: color-mix(in srgb, currentColor 30%, transparent); }

actionbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:hover, searchbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:hover, .toolbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:hover, headerbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:hover, actionbar > revealer > box popover button.arrow-button:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.arrow-button:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.arrow-button:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.arrow-button:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-button:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-button:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-button:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-button:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-text-button:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-text-button:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-text-button:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-text-button:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.arrow-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.arrow-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.arrow-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.arrow-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-text-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-text-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-text-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-text-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.arrow-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.arrow-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.arrow-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.arrow-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-text-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-text-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-text-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-text-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow:checked:hover, row.spin spinbutton > button.image-button.up:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.down:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay:checked:hover, button:checked:hover { background-color: color-mix(in srgb, currentColor 35%, transparent); }

actionbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked.keyboard-activating, searchbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked.keyboard-activating, .toolbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked.keyboard-activating, headerbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked.keyboard-activating, actionbar > revealer > box popover button.arrow-button:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.arrow-button:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.arrow-button:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.arrow-button:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-button:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-button:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-button:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-button:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-text-button:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-text-button:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-text-button:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-text-button:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.arrow-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.arrow-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.arrow-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.arrow-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-text-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-text-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-text-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-text-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.arrow-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.arrow-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.arrow-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.arrow-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-text-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-text-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-text-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-text-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:active, searchbar > revealer > box popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:active, .toolbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:active, headerbar popover menubutton:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:active, actionbar > revealer > box popover button.arrow-button:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.arrow-button:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.arrow-button:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.arrow-button:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-button:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-button:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-button:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-button:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box popover button.image-text-button:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box popover button.image-text-button:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar popover button.image-text-button:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar popover button.image-text-button:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.arrow-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.arrow-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.arrow-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.arrow-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.raised > button.image-text-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.raised > button.image-text-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.raised > button.image-text-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.raised > button.image-text-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.arrow-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.arrow-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.arrow-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.arrow-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box .linked button.image-text-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box .linked button.image-text-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar .linked button.image-text-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar .linked button.image-text-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow:checked.keyboard-activating, row.spin spinbutton > button.image-button.up:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.down:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay:checked.keyboard-activating, notebook > header > tabs > arrow:checked:active, row.spin spinbutton > button.image-button.up:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.down:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay:checked:active, button:checked.keyboard-activating, button:checked:active { background-color: color-mix(in srgb, currentColor 40%, transparent); }

notebook > header > tabs > arrow:disabled, row.spin spinbutton > button.image-button.up:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.image-button.down:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay:disabled, button:disabled { filter: Opacity(var(--disabled-opacity)); }

notebook > header > tabs > arrow:disabled label, row.spin spinbutton > button.image-button.up:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child label, row.spin spinbutton > button.image-button.up:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr) label, row.spin spinbutton > button.image-button.up:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child label, row.spin spinbutton > button.image-button.down:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) label, row.spin spinbutton > button.image-button.down:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child label, row.spin spinbutton > button.image-button.down:disabled:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child label, colorswatch#add-color-button > overlay:disabled label, button:disabled label { filter: none; }

notebook > header > tabs > arrow.image-button, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay.image-button, button.image-button { min-width: 24px; padding-left: 5px; padding-right: 5px; }

notebook > header > tabs > arrow.text-button, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay.text-button, button.text-button { padding-left: 17px; padding-right: 17px; }

notebook > header > tabs > arrow.text-button.image-button, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay.text-button.image-button, notebook > header > tabs > arrow.image-text-button, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay.image-text-button, button.text-button.image-button, button.image-text-button { padding-left: 9px; padding-right: 9px; }

notebook > header > tabs > arrow.text-button.image-button > box, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child > box, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr) > box, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child > box, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > box, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child > box, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child > box, colorswatch#add-color-button > overlay.text-button.image-button > box, notebook > header > tabs > arrow.text-button.image-button > box > box, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child > box > box, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr) > box > box, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child > box > box, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > box > box, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child > box > box, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child > box > box, colorswatch#add-color-button > overlay.text-button.image-button > box > box, notebook > header > tabs > arrow.image-text-button > box, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child > box, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr) > box, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child > box, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > box, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child > box, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child > box, colorswatch#add-color-button > overlay.image-text-button > box, notebook > header > tabs > arrow.image-text-button > box > box, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child > box > box, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr) > box > box, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child > box > box, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > box > box, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child > box > box, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child > box > box, colorswatch#add-color-button > overlay.image-text-button > box > box, button.text-button.image-button > box, button.text-button.image-button > box > box, button.image-text-button > box, button.image-text-button > box > box { border-spacing: 4px; }

notebook > header > tabs > arrow.text-button.image-button > box > label, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child > box > label, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr) > box > label, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child > box > label, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > box > label, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child > box > label, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child > box > label, colorswatch#add-color-button > overlay.text-button.image-button > box > label, notebook > header > tabs > arrow.text-button.image-button > box > box > label, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child > box > box > label, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr) > box > box > label, row.spin spinbutton > button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child > box > box > label, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > box > box > label, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child > box > box > label, row.spin spinbutton > button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child > box > box > label, colorswatch#add-color-button > overlay.text-button.image-button > box > box > label, notebook > header > tabs > arrow.image-text-button > box > label, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child > box > label, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr) > box > label, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child > box > label, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > box > label, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child > box > label, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child > box > label, colorswatch#add-color-button > overlay.image-text-button > box > label, notebook > header > tabs > arrow.image-text-button > box > box > label, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child > box > box > label, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr) > box > box > label, row.spin spinbutton > button.image-text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child > box > box > label, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > box > box > label, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child > box > box > label, row.spin spinbutton > button.image-text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child > box > box > label, colorswatch#add-color-button > overlay.image-text-button > box > box > label, button.text-button.image-button > box > label, button.text-button.image-button > box > box > label, button.image-text-button > box > label, button.image-text-button > box > box > label { padding-left: 2px; padding-right: 2px; }

notebook > header > tabs > arrow.arrow-button, row.spin spinbutton > button.arrow-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.arrow-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.arrow-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.arrow-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.arrow-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.arrow-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay.arrow-button, button.arrow-button { padding-left: 9px; padding-right: 9px; }

notebook > header > tabs > arrow.arrow-button > box, row.spin spinbutton > button.arrow-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child > box, row.spin spinbutton > button.arrow-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr) > box, row.spin spinbutton > button.arrow-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child > box, row.spin spinbutton > button.arrow-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > box, row.spin spinbutton > button.arrow-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child > box, row.spin spinbutton > button.arrow-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child > box, colorswatch#add-color-button > overlay.arrow-button > box, button.arrow-button > box { border-spacing: 4px; }

notebook > header > tabs > arrow.arrow-button.text-button > box, row.spin spinbutton > button.arrow-button.text-button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child > box, row.spin spinbutton > button.arrow-button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > box, row.spin spinbutton > button.arrow-button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child > box, row.spin spinbutton > button.arrow-button.text-button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child > box, colorswatch#add-color-button > overlay.arrow-button.text-button > box, button.arrow-button.text-button > box { border-spacing: 4px; }

dropdown:drop(active) button.combo, combobox:drop(active) button.combo, searchbar > revealer > box .close:drop(active), actionbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:drop(active), searchbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:drop(active), .toolbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:drop(active), headerbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:drop(active), actionbar > revealer > box button.arrow-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.arrow-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.arrow-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.arrow-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-text-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-text-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-text-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-text-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.up:drop(active):not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.down:drop(active):not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), popover.menu box.circular-buttons button.circular.image-button.model:drop(active), popover.menu box.inline-buttons button.image-button.model:drop(active), filechooser #pathbarbox > stack > box > button:drop(active), filechooser #pathbarbox > stack > box > box > button:drop(active), filechooser #pathbarbox > stack > box > menubutton > button:drop(active), button.sidebar-button:drop(active), button.emoji-section.image-button:drop(active):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), infobar .close:drop(active), calendar > header > button:drop(active), actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:drop(active), searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:drop(active), .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:drop(active), headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:drop(active), actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:drop(active), searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:drop(active), .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:drop(active), headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:drop(active), splitbutton.flat > button:drop(active), splitbutton.flat > menubutton > button:drop(active), menubutton.flat > button:drop(active), button.flat:drop(active), menubutton.osd > button:drop(active), button.osd:drop(active), notebook > header > tabs > arrow:drop(active), row.spin spinbutton > button.image-button.up:drop(active):not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:drop(active):not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr), row.spin spinbutton > button.image-button.up:drop(active):not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.image-button.down:drop(active):not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:drop(active):not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:drop(active):not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, colorswatch#add-color-button > overlay:drop(active), button:drop(active) { color: var(--accent-bg-color); box-shadow: inset 0 0 0 2px var(--accent-bg-color); }

menubutton.osd > button, button.osd { min-width: 32px; min-height: 32px; color: RGB(255 255 255/90%); background-color: RGB(0 0 0/65%); }

menubutton.osd > button, button.osd { outline: 0 solid transparent; outline-offset: 5px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

menubutton.osd > button:focus:focus-visible, button.osd:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: 1px; }

menubutton.osd > button:hover, button.osd:hover { color: white; background-color: color-mix(in srgb, black calc(0.85 * 65%), currentColor calc(0.15 * 65%)); }

menubutton.osd > button.keyboard-activating, menubutton.osd > button:active, button.osd.keyboard-activating, button.osd:active { color: white; background-color: color-mix(in srgb, black calc(0.75 * 65%), currentColor calc(0.25 * 65%)); }

menubutton.osd > button:checked, button.osd:checked { background-color: color-mix(in srgb, black calc(0.8 * 65%), currentColor calc(0.2 * 65%)); }

menubutton.osd > button:checked:hover, button.osd:checked:hover { background-color: color-mix(in srgb, black calc(0.75 * 65%), currentColor calc(0.25 * 65%)); }

menubutton.osd > button:checked.keyboard-activating, menubutton.osd > button:checked:active, button.osd:checked.keyboard-activating, button.osd:checked:active { background-color: color-mix(in srgb, black calc(0.65 * 65%), currentColor calc(0.35 * 65%)); }

actionbar > revealer > box menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.suggested-action > button, splitbutton.suggested-action > menubutton > button, splitbutton.opaque > button, splitbutton.opaque > menubutton > button, menubutton.suggested-action > button, menubutton.opaque > button, button.suggested-action, button.opaque { box-shadow: none; }

actionbar > revealer > box menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.suggested-action > button, splitbutton.suggested-action > menubutton > button, splitbutton.opaque > button, splitbutton.opaque > menubutton > button, menubutton.suggested-action > button, menubutton.opaque > button, button.suggested-action, button.opaque { outline: 0 solid transparent; outline-offset: 5px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

actionbar > revealer > box menubutton.suggested-action > button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.suggested-action > button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.suggested-action > button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.suggested-action > button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.opaque > button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.opaque > button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.opaque > button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.opaque > button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.suggested-action > button:focus:focus-visible, splitbutton.suggested-action > menubutton > button:focus:focus-visible, splitbutton.opaque > button:focus:focus-visible, splitbutton.opaque > menubutton > button:focus:focus-visible, menubutton.suggested-action > button:focus:focus-visible, menubutton.opaque > button:focus:focus-visible, button.suggested-action:focus:focus-visible, button.opaque:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: 1px; }

actionbar > revealer > box menubutton.suggested-action > button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.suggested-action > button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.suggested-action > button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.suggested-action > button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.opaque > button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.opaque > button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.opaque > button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.opaque > button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.suggested-action > button:hover, splitbutton.suggested-action > menubutton > button:hover, splitbutton.opaque > button:hover, splitbutton.opaque > menubutton > button:hover, menubutton.suggested-action > button:hover, menubutton.opaque > button:hover, button.suggested-action:hover, button.opaque:hover { background-image: image(color-mix(in srgb, currentColor 10%, transparent)); }

actionbar > revealer > box menubutton.suggested-action > button.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.suggested-action > button.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.suggested-action > button.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.suggested-action > button.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.opaque > button.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.opaque > button.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.opaque > button.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.opaque > button.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.suggested-action > button.keyboard-activating, splitbutton.suggested-action > menubutton > button.keyboard-activating, splitbutton.opaque > button.keyboard-activating, splitbutton.opaque > menubutton > button.keyboard-activating, menubutton.suggested-action > button.keyboard-activating, menubutton.opaque > button.keyboard-activating, button.keyboard-activating.suggested-action, button.keyboard-activating.opaque, actionbar > revealer > box menubutton.suggested-action > button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.suggested-action > button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.suggested-action > button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.suggested-action > button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.opaque > button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.opaque > button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.opaque > button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.opaque > button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.suggested-action > button:active, splitbutton.suggested-action > menubutton > button:active, splitbutton.opaque > button:active, splitbutton.opaque > menubutton > button:active, menubutton.suggested-action > button:active, menubutton.opaque > button:active, button.suggested-action:active, button.opaque:active { background-image: image(RGB(0 0 6/20%)); }

actionbar > revealer > box menubutton.suggested-action > button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.suggested-action > button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.suggested-action > button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.suggested-action > button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.opaque > button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.opaque > button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.opaque > button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.opaque > button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.suggested-action > button:checked, splitbutton.suggested-action > menubutton > button:checked, splitbutton.opaque > button:checked, splitbutton.opaque > menubutton > button:checked, menubutton.suggested-action > button:checked, menubutton.opaque > button:checked, button.suggested-action:checked, button.opaque:checked { background-image: image(RGB(0 0 6/15%)); }

actionbar > revealer > box menubutton.suggested-action > button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.suggested-action > button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.suggested-action > button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.suggested-action > button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.opaque > button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.opaque > button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.opaque > button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.opaque > button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.suggested-action > button:checked:hover, splitbutton.suggested-action > menubutton > button:checked:hover, splitbutton.opaque > button:checked:hover, splitbutton.opaque > menubutton > button:checked:hover, menubutton.suggested-action > button:checked:hover, menubutton.opaque > button:checked:hover, button.suggested-action:checked:hover, button.opaque:checked:hover { background-image: image(RGB(0 0 6/5%)); }

actionbar > revealer > box menubutton.suggested-action > button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.suggested-action > button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.suggested-action > button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.suggested-action > button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.opaque > button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.opaque > button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.opaque > button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.opaque > button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.suggested-action > button:checked.keyboard-activating, splitbutton.suggested-action > menubutton > button:checked.keyboard-activating, splitbutton.opaque > button:checked.keyboard-activating, splitbutton.opaque > menubutton > button:checked.keyboard-activating, menubutton.suggested-action > button:checked.keyboard-activating, menubutton.opaque > button:checked.keyboard-activating, button.suggested-action:checked.keyboard-activating, button.opaque:checked.keyboard-activating, actionbar > revealer > box menubutton.suggested-action > button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.suggested-action > button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.suggested-action > button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.suggested-action > button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.opaque > button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.opaque > button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.opaque > button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.opaque > button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.suggested-action > button:checked:active, splitbutton.suggested-action > menubutton > button:checked:active, splitbutton.opaque > button:checked:active, splitbutton.opaque > menubutton > button:checked:active, menubutton.suggested-action > button:checked:active, menubutton.opaque > button:checked:active, button.suggested-action:checked:active, button.opaque:checked:active { background-image: image(RGB(0 0 6/30%)); }

actionbar > revealer > box menubutton.destructive-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.destructive-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.destructive-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.destructive-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.destructive-action > button, splitbutton.destructive-action > menubutton > button, menubutton.destructive-action > button, button.destructive-action { --accent-bg-color: var(--destructive-bg-color); --accent-fg-color: var(--destructive-fg-color); --accent-color: var(--destructive-color); color: var(--accent-color); background-color: color-mix(in srgb, currentColor 15%, transparent); }

actionbar > revealer > box menubutton.destructive-action > button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.destructive-action > button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.destructive-action > button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.destructive-action > button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.destructive-action > button:hover, splitbutton.destructive-action > menubutton > button:hover, menubutton.destructive-action > button:hover, button.destructive-action:hover { background-color: color-mix(in srgb, currentColor 20%, transparent); }

actionbar > revealer > box menubutton.destructive-action > button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.destructive-action > button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.destructive-action > button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.destructive-action > button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.destructive-action > button:active, splitbutton.destructive-action > menubutton > button:active, menubutton.destructive-action > button:active, button.destructive-action:active, actionbar > revealer > box menubutton.destructive-action > button.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.destructive-action > button.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.destructive-action > button.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.destructive-action > button.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.destructive-action > button.keyboard-activating, splitbutton.destructive-action > menubutton > button.keyboard-activating, menubutton.destructive-action > button.keyboard-activating, button.keyboard-activating.destructive-action { background-color: color-mix(in srgb, currentColor 35%, transparent); }

actionbar > revealer > box menubutton.destructive-action > button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.destructive-action > button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.destructive-action > button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.destructive-action > button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.destructive-action > button:checked, splitbutton.destructive-action > menubutton > button:checked, menubutton.destructive-action > button:checked, button.destructive-action:checked { background-color: color-mix(in srgb, currentColor 35%, transparent); }

actionbar > revealer > box menubutton.destructive-action > button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.destructive-action > button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.destructive-action > button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.destructive-action > button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.destructive-action > button:checked:hover, splitbutton.destructive-action > menubutton > button:checked:hover, menubutton.destructive-action > button:checked:hover, button.destructive-action:checked:hover { background-color: color-mix(in srgb, currentColor 40%, transparent); }

actionbar > revealer > box menubutton.destructive-action > button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.destructive-action > button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.destructive-action > button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.destructive-action > button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.destructive-action > button:checked.keyboard-activating, splitbutton.destructive-action > menubutton > button:checked.keyboard-activating, menubutton.destructive-action > button:checked.keyboard-activating, button.destructive-action:checked.keyboard-activating, actionbar > revealer > box menubutton.destructive-action > button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.destructive-action > button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.destructive-action > button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.destructive-action > button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.destructive-action > button:checked:active, splitbutton.destructive-action > menubutton > button:checked:active, menubutton.destructive-action > button:checked:active, button.destructive-action:checked:active { background-color: color-mix(in srgb, currentColor 45%, transparent); }

button.opaque { background-color: color-mix(in srgb, var(--window-bg-color) 85%, var(--window-fg-color)); color: var(--window-fg-color); }

button.suggested-action { color: var(--accent-fg-color); }

button.suggested-action, button.suggested-action:checked { background-color: var(--accent-bg-color); }

searchbar > revealer > box .close, actionbar > revealer > box menubutton.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, searchbar > revealer > box menubutton.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, .toolbar menubutton.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, headerbar menubutton.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, actionbar > revealer > box button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow, popover.menu box.circular-buttons button.circular.image-button.model, popover.menu box.inline-buttons button.image-button.model, filechooser #pathbarbox > stack > box > button, filechooser #pathbarbox > stack > box > box > button, filechooser #pathbarbox > stack > box > menubutton > button, button.sidebar-button, button.emoji-section.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), infobar .close, calendar > header > button, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button, splitbutton.flat > button, splitbutton.flat > menubutton > button, menubutton.flat > button, button.flat { background: transparent; box-shadow: none; }

searchbar > revealer > box .close, actionbar > revealer > box menubutton.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, searchbar > revealer > box menubutton.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, .toolbar menubutton.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, headerbar menubutton.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, actionbar > revealer > box button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow, popover.menu box.circular-buttons button.circular.image-button.model, popover.menu box.inline-buttons button.image-button.model, filechooser #pathbarbox > stack > box > button, filechooser #pathbarbox > stack > box > box > button, filechooser #pathbarbox > stack > box > menubutton > button, button.sidebar-button, button.emoji-section.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), infobar .close, calendar > header > button, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button, splitbutton.flat > button, splitbutton.flat > menubutton > button, menubutton.flat > button, button.flat { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

searchbar > revealer > box .close:focus:focus-visible, actionbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:focus:focus-visible, searchbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:focus:focus-visible, .toolbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:focus:focus-visible, headerbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:focus:focus-visible, actionbar > revealer > box button.arrow-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.arrow-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.arrow-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.arrow-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-text-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-text-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-text-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-text-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.up:focus:focus-visible:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.down:focus:focus-visible:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow:focus:focus-visible, popover.menu box.circular-buttons button.circular.image-button.model:focus:focus-visible, popover.menu box.inline-buttons button.image-button.model:focus:focus-visible, filechooser #pathbarbox > stack > box > button:focus:focus-visible, filechooser #pathbarbox > stack > box > box > button:focus:focus-visible, filechooser #pathbarbox > stack > box > menubutton > button:focus:focus-visible, button.sidebar-button:focus:focus-visible, button.emoji-section.image-button:focus:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), infobar .close:focus:focus-visible, calendar > header > button:focus:focus-visible, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:focus:focus-visible, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:focus:focus-visible, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:focus:focus-visible, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:focus:focus-visible, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:focus:focus-visible, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:focus:focus-visible, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:focus:focus-visible, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:focus:focus-visible, splitbutton.flat > button:focus:focus-visible, splitbutton.flat > menubutton > button:focus:focus-visible, menubutton.flat > button:focus:focus-visible, button.flat:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

searchbar > revealer > box .close:hover, actionbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:hover, searchbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:hover, .toolbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:hover, headerbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:hover, actionbar > revealer > box button.arrow-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.arrow-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.arrow-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.arrow-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-text-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-text-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-text-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-text-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.up:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.down:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow:hover, popover.menu box.circular-buttons button.circular.image-button.model:hover, popover.menu box.inline-buttons button.image-button.model:hover, filechooser #pathbarbox > stack > box > button:hover, filechooser #pathbarbox > stack > box > box > button:hover, filechooser #pathbarbox > stack > box > menubutton > button:hover, button.sidebar-button:hover, button.emoji-section.image-button:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), infobar .close:hover, calendar > header > button:hover, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:hover, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:hover, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:hover, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:hover, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:hover, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:hover, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:hover, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:hover, splitbutton.flat > button:hover, splitbutton.flat > menubutton > button:hover, menubutton.flat > button:hover, button.flat:hover { background: color-mix(in srgb, currentColor 7%, transparent); }

searchbar > revealer > box .keyboard-activating.close, actionbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button.keyboard-activating, searchbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button.keyboard-activating, .toolbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button.keyboard-activating, headerbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button.keyboard-activating, actionbar > revealer > box button.keyboard-activating.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.keyboard-activating.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.keyboard-activating.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.keyboard-activating.arrow-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.keyboard-activating.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.keyboard-activating.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.keyboard-activating.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.keyboard-activating.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.keyboard-activating.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.keyboard-activating.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.keyboard-activating.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.keyboard-activating.image-text-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.keyboard-activating.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.keyboard-activating.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow.keyboard-activating, popover.menu box.circular-buttons button.keyboard-activating.circular.image-button.model, popover.menu box.inline-buttons button.keyboard-activating.image-button.model, filechooser #pathbarbox > stack > box > button.keyboard-activating, filechooser #pathbarbox > stack > box > box > button.keyboard-activating, filechooser #pathbarbox > stack > box > menubutton > button.keyboard-activating, button.keyboard-activating.sidebar-button, button.keyboard-activating.emoji-section.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), infobar .keyboard-activating.close, calendar > header > button.keyboard-activating, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button.keyboard-activating, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button.keyboard-activating, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button.keyboard-activating, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button.keyboard-activating, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button.keyboard-activating, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button.keyboard-activating, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button.keyboard-activating, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button.keyboard-activating, splitbutton.flat > button.keyboard-activating, splitbutton.flat > menubutton > button.keyboard-activating, menubutton.flat > button.keyboard-activating, searchbar > revealer > box .close:active, actionbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:active, searchbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:active, .toolbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:active, headerbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:active, actionbar > revealer > box button.arrow-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.arrow-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.arrow-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.arrow-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-text-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-text-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-text-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-text-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.up:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.down:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow:active, popover.menu box.circular-buttons button.circular.image-button.model:active, popover.menu box.inline-buttons button.image-button.model:active, filechooser #pathbarbox > stack > box > button:active, filechooser #pathbarbox > stack > box > box > button:active, filechooser #pathbarbox > stack > box > menubutton > button:active, button.sidebar-button:active, button.emoji-section.image-button:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), infobar .close:active, calendar > header > button:active, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:active, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:active, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:active, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:active, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:active, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:active, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:active, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:active, splitbutton.flat > button:active, splitbutton.flat > menubutton > button:active, menubutton.flat > button:active, button.flat.keyboard-activating, button.flat:active { background: color-mix(in srgb, currentColor 16%, transparent); }

searchbar > revealer > box .close:checked, actionbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked, searchbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked, .toolbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked, headerbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked, actionbar > revealer > box button.arrow-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.arrow-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.arrow-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.arrow-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-text-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-text-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-text-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-text-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.up:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.down:checked:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow:checked, popover.menu box.circular-buttons button.circular.image-button.model:checked, popover.menu box.inline-buttons button.image-button.model:checked, filechooser #pathbarbox > stack > box > button:checked, filechooser #pathbarbox > stack > box > box > button:checked, filechooser #pathbarbox > stack > box > menubutton > button:checked, button.sidebar-button:checked, button.emoji-section.image-button:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), infobar .close:checked, calendar > header > button:checked, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked, splitbutton.flat > button:checked, splitbutton.flat > menubutton > button:checked, menubutton.flat > button:checked, button.flat:checked { background: color-mix(in srgb, currentColor 10%, transparent); }

searchbar > revealer > box .close:checked:hover, actionbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:hover, searchbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:hover, .toolbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:hover, headerbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:hover, actionbar > revealer > box button.arrow-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.arrow-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.arrow-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.arrow-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-text-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-text-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-text-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-text-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.up:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.down:checked:hover:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow:checked:hover, popover.menu box.circular-buttons button.circular.image-button.model:checked:hover, popover.menu box.inline-buttons button.image-button.model:checked:hover, filechooser #pathbarbox > stack > box > button:checked:hover, filechooser #pathbarbox > stack > box > box > button:checked:hover, filechooser #pathbarbox > stack > box > menubutton > button:checked:hover, button.sidebar-button:checked:hover, button.emoji-section.image-button:checked:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), infobar .close:checked:hover, calendar > header > button:checked:hover, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked:hover, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked:hover, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked:hover, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked:hover, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked:hover, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked:hover, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked:hover, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked:hover, splitbutton.flat > button:checked:hover, splitbutton.flat > menubutton > button:checked:hover, menubutton.flat > button:checked:hover, button.flat:checked:hover { background: color-mix(in srgb, currentColor 13%, transparent); }

searchbar > revealer > box .close:checked.keyboard-activating, actionbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked.keyboard-activating, searchbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked.keyboard-activating, .toolbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked.keyboard-activating, headerbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked.keyboard-activating, actionbar > revealer > box button.arrow-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.arrow-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.arrow-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.arrow-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-text-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-text-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-text-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-text-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.up:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.down:checked.keyboard-activating:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow:checked.keyboard-activating, popover.menu box.circular-buttons button.circular.image-button.model:checked.keyboard-activating, popover.menu box.inline-buttons button.image-button.model:checked.keyboard-activating, filechooser #pathbarbox > stack > box > button:checked.keyboard-activating, filechooser #pathbarbox > stack > box > box > button:checked.keyboard-activating, filechooser #pathbarbox > stack > box > menubutton > button:checked.keyboard-activating, button.sidebar-button:checked.keyboard-activating, button.emoji-section.image-button:checked.keyboard-activating:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), infobar .close:checked.keyboard-activating, calendar > header > button:checked.keyboard-activating, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked.keyboard-activating, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked.keyboard-activating, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked.keyboard-activating, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked.keyboard-activating, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked.keyboard-activating, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked.keyboard-activating, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked.keyboard-activating, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked.keyboard-activating, splitbutton.flat > button:checked.keyboard-activating, splitbutton.flat > menubutton > button:checked.keyboard-activating, menubutton.flat > button:checked.keyboard-activating, searchbar > revealer > box .close:checked:active, actionbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:active, searchbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:active, .toolbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:active, headerbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:checked:active, actionbar > revealer > box button.arrow-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.arrow-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.arrow-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.arrow-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-text-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-text-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-text-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-text-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.up:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.down:checked:active:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow:checked:active, popover.menu box.circular-buttons button.circular.image-button.model:checked:active, popover.menu box.inline-buttons button.image-button.model:checked:active, filechooser #pathbarbox > stack > box > button:checked:active, filechooser #pathbarbox > stack > box > box > button:checked:active, filechooser #pathbarbox > stack > box > menubutton > button:checked:active, button.sidebar-button:checked:active, button.emoji-section.image-button:checked:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), infobar .close:checked:active, calendar > header > button:checked:active, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked:active, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked:active, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked:active, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:checked:active, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked:active, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked:active, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked:active, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:checked:active, splitbutton.flat > button:checked:active, splitbutton.flat > menubutton > button:checked:active, menubutton.flat > button:checked:active, button.flat:checked.keyboard-activating, button.flat:checked:active { background: color-mix(in srgb, currentColor 19%, transparent); }

searchbar > revealer > box .close:disabled:not(:checked), actionbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:disabled:not(:checked), searchbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:disabled:not(:checked), .toolbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:disabled:not(:checked), headerbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button > button:disabled:not(:checked), actionbar > revealer > box button.arrow-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.arrow-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.arrow-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.arrow-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box button.image-text-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box button.image-text-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar button.image-text-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar button.image-text-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.up:disabled:not(:checked):not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.down:disabled:not(:checked):not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), notebook > header > tabs > arrow:disabled:not(:checked), popover.menu box.circular-buttons button.circular.image-button.model:disabled:not(:checked), popover.menu box.inline-buttons button.image-button.model:disabled:not(:checked), filechooser #pathbarbox > stack > box > button:disabled:not(:checked), filechooser #pathbarbox > stack > box > box > button:disabled:not(:checked), filechooser #pathbarbox > stack > box > menubutton > button:disabled:not(:checked), button.sidebar-button:disabled:not(:checked), button.emoji-section.image-button:disabled:not(:checked):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), infobar .close:disabled:not(:checked), calendar > header > button:disabled:not(:checked), actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:disabled:not(:checked), searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:disabled:not(:checked), .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:disabled:not(:checked), headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:disabled:not(:checked), actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:disabled:not(:checked), searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:disabled:not(:checked), .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:disabled:not(:checked), headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:disabled:not(:checked), splitbutton.flat > button:disabled:not(:checked), splitbutton.flat > menubutton > button:disabled:not(:checked), menubutton.flat > button:disabled:not(:checked), button.flat:disabled:not(:checked) { filter: opacity(30%); }

stackswitcher > button > label { padding: 0 6px; margin: 0 -6px; }

stackswitcher > button > image { padding: 3px 6px; margin: -3px -6px; }

stackswitcher > button.text-button { min-width: 100px; }

button.font separator { background-color: transparent; }

button.font > box { border-spacing: 6px; }

button.font > box > box > label { font-weight: bold; }

row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, button.emoji-section.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), menubutton.circular > button, button.circular { min-width: 34px; min-height: 34px; padding: 0; border-radius: 9999px; }

row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child label, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child label, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child label, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) label, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child label, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child label, button.emoji-section.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) label, menubutton.circular > button label, button.circular label { padding: 0; }

menubutton.pill > button, button.pill { padding: 10px 32px; border-radius: 9999px; }

button.card { background-color: var(--card-bg-color); background-clip: padding-box; font-weight: inherit; padding: 0; }

button.card { outline: 0 solid transparent; outline-offset: 5px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

button.card:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -1px; }

button.card:hover { background-image: image(color-mix(in srgb, currentColor 4%, transparent)); }

button.card.keyboard-activating, button.card:active { background-image: image(color-mix(in srgb, currentColor 8%, transparent)); }

button.card:checked { background-color: var(--card-bg-color); background-image: image(color-mix(in srgb, var(--accent-bg-color) 25%, transparent)); }

button.card:checked:hover { background-image: image(color-mix(in srgb, var(--accent-bg-color) 32%, transparent)); }

button.card:checked.keyboard-activating, button.card:checked:active { background-image: image(color-mix(in srgb, var(--accent-bg-color) 39%, transparent)); }

button.card:checked.has-open-popup { background-image: image(color-mix(in srgb, var(--accent-bg-color) 32%, transparent)); }

.osd button.card:checked { background-color: color-mix(in srgb, currentColor 10%, transparent); }

button.card:drop(active) { color: var(--accent-bg-color); box-shadow: inset 0 0 0 1px var(--accent-bg-color); }

button.color { padding: 5px; }

button.color > colorswatch:only-child { border-radius: 4.5px; }

button.color > colorswatch:only-child > overlay { border-radius: 4px; }

button.color > colorswatch:only-child:disabled { filter: none; }

button.color > colorswatch:only-child.light > overlay { border-color: color-mix(in srgb, var(--view-fg-color) 10%, transparent); }

menubutton.osd { background: none; color: inherit; }

menubutton:disabled { filter: opacity(50%); }

menubutton > button:disabled:not(:checked) { filter: none; }

menubutton.flat:disabled { filter: none; }

menubutton.suggested-action { background-color: var(--accent-bg-color); color: var(--accent-fg-color); }

menubutton.opaque { background-color: color-mix(in srgb, var(--window-bg-color) 85%, var(--window-fg-color)); color: var(--window-fg-color); }

menubutton.suggested-action, menubutton.opaque { border-radius: 9px; }

menubutton.suggested-action.circular, menubutton.suggested-action.pill, menubutton.opaque.circular, menubutton.opaque.pill { border-radius: 9999px; }

menubutton.suggested-action > button, menubutton.suggested-action > button:checked, menubutton.opaque > button, menubutton.opaque > button:checked { background-color: transparent; color: inherit; }

menubutton.image-button > button { min-width: 24px; padding-left: 5px; padding-right: 5px; }

menubutton.card > button { border-radius: 12px; }

menubutton arrow { min-height: 16px; min-width: 16px; }

menubutton arrow.none { -gtk-icon-source: -gtk-icontheme("open-menu-symbolic"); }

menubutton arrow.down { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

menubutton arrow.up { -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

menubutton arrow.left { -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

menubutton arrow.right { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

splitbutton { border-radius: 9px; }

splitbutton, splitbutton > separator { transition: background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); transition-property: background; }

splitbutton > separator { margin-top: 6px; margin-bottom: 6px; background: none; }

splitbutton > menubutton > button { padding-left: 4px; padding-right: 4px; }

splitbutton.image-button > button { min-width: 24px; padding-left: 5px; padding-right: 5px; }

splitbutton.text-button.image-button > button, splitbutton.image-text-button > button { padding-left: 9px; padding-right: 9px; }

splitbutton.text-button.image-button > button > box, splitbutton.image-text-button > button > box { border-spacing: 6px; }

splitbutton:disabled { filter: Opacity(var(--disabled-opacity)); }

splitbutton:disabled > button, splitbutton:disabled > menubutton, splitbutton:disabled > menubutton > button { filter: none; }

splitbutton > button:dir(ltr), splitbutton > menubutton > button:dir(rtl) { border-top-right-radius: 0; border-bottom-right-radius: 0; margin-right: -1px; }

splitbutton > button:dir(rtl), splitbutton > menubutton > button:dir(ltr) { border-top-left-radius: 0; border-bottom-left-radius: 0; margin-left: -1px; }

actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, splitbutton.flat > separator { background: color-mix(in srgb, currentColor 30%, transparent); }

actionbar > revealer > box splitbutton:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box splitbutton:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar splitbutton:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar splitbutton:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box splitbutton:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box splitbutton:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar splitbutton:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar splitbutton:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box splitbutton:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box splitbutton:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar splitbutton:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar splitbutton:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.flat:hover, splitbutton.flat:active, splitbutton.flat:checked { background: color-mix(in srgb, currentColor 7%, transparent); }

actionbar > revealer > box splitbutton:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, searchbar > revealer > box splitbutton:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, .toolbar splitbutton:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, headerbar splitbutton:hover:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, actionbar > revealer > box splitbutton:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, searchbar > revealer > box splitbutton:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, .toolbar splitbutton:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, headerbar splitbutton:active:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, actionbar > revealer > box splitbutton:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, searchbar > revealer > box splitbutton:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, .toolbar splitbutton:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, headerbar splitbutton:checked:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, splitbutton.flat:hover > separator, splitbutton.flat:active > separator, splitbutton.flat:checked > separator { background: none; }

actionbar > revealer > box splitbutton:disabled:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box splitbutton:disabled:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar splitbutton:disabled:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar splitbutton:disabled:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), splitbutton.flat:disabled { filter: opacity(30%); }

actionbar > revealer > box splitbutton:disabled:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:disabled, searchbar > revealer > box splitbutton:disabled:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:disabled, .toolbar splitbutton:disabled:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:disabled, headerbar splitbutton:disabled:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button:disabled, actionbar > revealer > box splitbutton:disabled:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:disabled, searchbar > revealer > box splitbutton:disabled:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:disabled, .toolbar splitbutton:disabled:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:disabled, headerbar splitbutton:disabled:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button:disabled, splitbutton.flat:disabled > button:disabled, splitbutton.flat:disabled > menubutton > button:disabled { filter: none; }

actionbar > revealer > box splitbutton:focus-within:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, searchbar > revealer > box splitbutton:focus-within:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, .toolbar splitbutton:focus-within:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, headerbar splitbutton:focus-within:focus-visible:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > separator, splitbutton.flat:focus-within:focus-visible > separator { background: none; }

actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > button, actionbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button, searchbar > revealer > box splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button, .toolbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button, headerbar splitbutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) > menubutton > button, splitbutton.flat > button, splitbutton.flat > menubutton > button { border-radius: 9px; }

splitbutton.suggested-action { background-color: var(--accent-bg-color); color: var(--accent-fg-color); }

splitbutton.destructive-action { --accent-bg-color: var(--destructive-bg-color); --accent-fg-color: var(--destructive-fg-color); --accent-color: var(--destructive-color); color: var(--accent-color); }

splitbutton.opaque { background-color: color-mix(in srgb, var(--window-bg-color) 85%, var(--window-fg-color)); color: var(--window-fg-color); }

splitbutton.suggested-action > button, splitbutton.suggested-action > button:checked, splitbutton.suggested-action > menubutton > button, splitbutton.suggested-action > menubutton > button:checked, splitbutton.opaque > button, splitbutton.opaque > button:checked, splitbutton.opaque > menubutton > button, splitbutton.opaque > menubutton > button:checked { color: inherit; background-color: transparent; }

splitbutton.suggested-action > menubutton > button:dir(ltr), splitbutton.opaque > menubutton > button:dir(ltr) { box-shadow: inset 1px 0 color-mix(in srgb, currentColor 30%, transparent); }

splitbutton.suggested-action > menubutton > button:dir(rtl), splitbutton.opaque > menubutton > button:dir(rtl) { box-shadow: inset -1px 0 color-mix(in srgb, currentColor 30%, transparent); }

splitbutton > menubutton > button > arrow.none { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

buttoncontent > box { border-spacing: 6px; }

buttoncontent > box > label { font-weight: bold; }

buttoncontent > box > label:dir(ltr) { padding-right: 2px; }

buttoncontent > box > label:dir(rtl) { padding-left: 2px; }

.arrow-button > box > buttoncontent > box > label:dir(ltr), splitbutton > button > buttoncontent > box > label:dir(ltr) { padding-right: 0; }

.arrow-button > box > buttoncontent > box > label:dir(rtl), splitbutton > button > buttoncontent > box > label:dir(rtl) { padding-left: 0; }

tabbutton label { font-weight: 800; font-size: 10.5px; }

tabbutton label.small { font-size: 8px; }

tabbutton indicatorbin > indicator:dir(ltr), tabbutton indicatorbin > mask:dir(ltr) { transform: translate(-1px, 1px); }

tabbutton indicatorbin > indicator:dir(rtl), tabbutton indicatorbin > mask:dir(rtl) { transform: translate(1px, 1px); }

calendar { color: var(--view-fg-color); background-clip: padding-box; border: 1px solid color-mix(in srgb, currentColor var(--border-opacity), transparent); font-feature-settings: "tnum"; }

calendar.view:disabled, window.print:not(.ssd-frame) calendar.dialog-action-box:disabled { color: var(--view-fg-color); }

calendar > header { border-bottom: 1px solid color-mix(in srgb, currentColor var(--border-opacity), transparent); }

calendar > header > button { border-radius: 0; }

calendar > grid { padding-left: 3px; padding-bottom: 3px; }

calendar > grid > label.today { box-shadow: inset 0px -2px color-mix(in srgb, currentColor var(--border-opacity), transparent); }

calendar > grid > label.today:selected { box-shadow: none; }

calendar > grid > label { margin-top: 3px; margin-right: 3px; }

calendar > grid > label { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

calendar > grid > label:focus { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

calendar > grid > label.day-number { padding: 3px; }

calendar > grid > label.day-number:checked { border-radius: 9px; background-color: color-mix(in srgb, var(--accent-bg-color) 30%, transparent); }

calendar > grid > label.day-number:selected { border-radius: 9px; background-color: var(--accent-bg-color); color: var(--accent-fg-color); }

calendar > grid > label.day-number.other-month { color: color-mix(in srgb, currentColor 30%, transparent); }

checkbutton { border-spacing: 4px; border-radius: 9px; padding: 3px; }

checkbutton { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

checkbutton:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

checkbutton.text-button { padding: 4px; }

checkbutton.grouped { border-radius: 999px; }

check, radio { transition: background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); min-height: 14px; min-width: 14px; -gtk-icon-size: 14px; padding: 3px; box-shadow: inset 0 0 0 2px color-mix(in srgb, currentColor 15%, transparent); }

check:not(:checked):not(:indeterminate):hover, radio:not(:checked):not(:indeterminate):hover { box-shadow: inset 0 0 0 2px color-mix(in srgb, currentColor 20%, transparent); }

check:not(:checked):not(:indeterminate):active, radio:not(:checked):not(:indeterminate):active { background-color: color-mix(in srgb, currentColor 25%, transparent); box-shadow: none; }

check:checked, check:indeterminate, radio:checked, radio:indeterminate { background-color: var(--accent-bg-color); color: var(--accent-fg-color); box-shadow: none; }

check:checked:hover, check:indeterminate:hover, radio:checked:hover, radio:indeterminate:hover { background-image: image(color-mix(in srgb, currentColor 10%, transparent)); }

check:checked:active, check:indeterminate:active, radio:checked:active, radio:indeterminate:active { background-image: image(RGB(0 0 6/20%)); }

check:disabled, radio:disabled { filter: Opacity(var(--disabled-opacity)); }

check { border-radius: 6px; }

check:checked { -gtk-icon-source: -gtk-recolor(url("assets/check-symbolic.svg")); }

radio { border-radius: 100%; }

radio:checked { -gtk-icon-source: -gtk-recolor(url("assets/bullet-symbolic.svg")); }

check:indeterminate, radio:indeterminate { -gtk-icon-source: -gtk-recolor(url("assets/dash-symbolic.svg")); }

checkbutton.selection-mode { border-radius: 100px; }

checkbutton.selection-mode check, checkbutton.selection-mode radio { padding: 7px; border-radius: 100px; }

checkbutton.selection-mode label:dir(ltr) { margin-right: 6px; }

checkbutton.selection-mode label:dir(rtl) { margin-left: 6px; }

colorswatch { outline: 0 solid transparent; outline-offset: 6px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

colorswatch:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 4px; outline-offset: -2px; }

colorswatch.top { border-top-left-radius: 9.5px; border-top-right-radius: 9.5px; }

colorswatch.top > overlay { border-top-left-radius: 9px; border-top-right-radius: 9px; }

colorswatch.bottom { border-bottom-left-radius: 9.5px; border-bottom-right-radius: 9.5px; }

colorswatch.bottom > overlay { border-bottom-left-radius: 9px; border-bottom-right-radius: 9px; }

colorswatch.left, colorswatch:first-child:not(.top) { border-top-left-radius: 9.5px; border-bottom-left-radius: 9.5px; }

colorswatch.left > overlay, colorswatch:first-child:not(.top) > overlay { border-top-left-radius: 9px; border-bottom-left-radius: 9px; }

colorswatch.right, colorswatch:last-child:not(.bottom) { border-top-right-radius: 9.5px; border-bottom-right-radius: 9.5px; }

colorswatch.right > overlay, colorswatch:last-child:not(.bottom) > overlay { border-top-right-radius: 9px; border-bottom-right-radius: 9px; }

colorswatch.dark > overlay { color: white; }

colorswatch.light > overlay { color: RGB(0 0 6/75%); box-shadow: inset 0 0 0 1px color-mix(in srgb, var(--view-fg-color) 10%, transparent); }

colorswatch:drop(active).light > overlay { box-shadow: inset 0 0 0 2px var(--accent-bg-color); }

colorswatch:drop(active).dark > overlay { box-shadow: inset 0 0 0 2px var(--accent-bg-color); }

colorswatch#add-color-button > overlay { border-radius: 9px 0 0 9px; }

colorswatch#add-color-button:only-child > overlay { border-radius: 9px; }

colorswatch:disabled { filter: Opacity(var(--disabled-opacity)); }

colorswatch#editor-color-sample { border-radius: 9px; }

colorswatch#editor-color-sample > overlay { border-radius: 9.5px; }

plane { outline: 0 solid transparent; outline-offset: 6px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

plane:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: 2px; }

colorchooser .popover.osd { border-radius: 15px; }

columnview, treeview.view, window.print:not(.ssd-frame) treeview.dialog-action-box { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

columnview:focus:focus-visible, treeview.view:focus:focus-visible, window.print:not(.ssd-frame) treeview.dialog-action-box:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

columnview.view:disabled, treeview.view:disabled, window.print:not(.ssd-frame) columnview.dialog-action-box:disabled, window.print:not(.ssd-frame) treeview.dialog-action-box:disabled { color: var(--view-fg-color); }

columnview:drop(active), treeview.view:drop(active), window.print:not(.ssd-frame) treeview.dialog-action-box:drop(active) { box-shadow: none; }

columnview > header > button, treeview.view > header > button, window.print:not(.ssd-frame) treeview.dialog-action-box > header > button { background-color: transparent; padding-top: 3px; padding-bottom: 3px; padding-left: 6px; padding-right: 6px; border-radius: 0; box-shadow: none; line-height: 100%; border-left: 1px solid transparent; }

columnview > header > button:first-child, treeview.view > header > button:first-child, window.print:not(.ssd-frame) treeview.dialog-action-box > header > button:first-child { border-left-width: 0; }

columnview > header > button > box, treeview.view > header > button > box, window.print:not(.ssd-frame) treeview.dialog-action-box > header > button > box { color: color-mix(in srgb, currentColor 40%, transparent); border-spacing: 6px; }

columnview > header > button:hover > box, treeview.view > header > button:hover > box, window.print:not(.ssd-frame) treeview.dialog-action-box > header > button:hover > box { color: color-mix(in srgb, currentColor 70%, transparent); box-shadow: none; }

columnview > header > button:active > box, treeview.view > header > button:active > box, window.print:not(.ssd-frame) treeview.dialog-action-box > header > button:active > box { color: currentColor; }

columnview > header > button sort-indicator, treeview.view > header > button sort-indicator, window.print:not(.ssd-frame) treeview.dialog-action-box > header > button sort-indicator { min-height: 16px; min-width: 16px; }

columnview > header > button sort-indicator.ascending, treeview.view > header > button sort-indicator.ascending, window.print:not(.ssd-frame) treeview.dialog-action-box > header > button sort-indicator.ascending { -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

columnview > header > button sort-indicator.descending, treeview.view > header > button sort-indicator.descending, window.print:not(.ssd-frame) treeview.dialog-action-box > header > button sort-indicator.descending { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

columnview button.dnd:active, columnview button.dnd:selected, columnview button.dnd:hover, columnview button.dnd, treeview.view button.dnd, window.print:not(.ssd-frame) treeview.dialog-action-box button.dnd, columnview header.button.dnd:active, columnview header.button.dnd:selected, columnview header.button.dnd:hover, columnview header.button.dnd, treeview.view header.button.dnd, window.print:not(.ssd-frame) treeview.dialog-action-box header.button.dnd { color: var(--accent-fg-color); background-color: var(--accent-bg-color); transition: none; }

columnview.view > listview.view, treeview.view > listview.view, window.print:not(.ssd-frame) columnview.dialog-action-box > listview.view, window.print:not(.ssd-frame) treeview.dialog-action-box > listview.view, window.print:not(.ssd-frame) columnview.view > listview.dialog-action-box, window.print:not(.ssd-frame) treeview.view > listview.dialog-action-box, window.print:not(.ssd-frame) columnview.dialog-action-box > listview.dialog-action-box, window.print:not(.ssd-frame) treeview.dialog-action-box > listview.dialog-action-box { background: none; color: inherit; }

columnview > listview > row, treeview.view > listview > row, window.print:not(.ssd-frame) treeview.dialog-action-box > listview > row { padding: 0; }

columnview > listview > row > cell, treeview.view > listview > row > cell, window.print:not(.ssd-frame) treeview.dialog-action-box > listview > row > cell { padding: 8px 6px; }

columnview > listview > row > cell:not(:first-child), treeview.view > listview > row > cell:not(:first-child), window.print:not(.ssd-frame) treeview.dialog-action-box > listview > row > cell:not(:first-child) { border-left: 1px solid transparent; }

columnview.column-separators > listview > row > cell, treeview.column-separators.view > listview > row > cell, window.print:not(.ssd-frame) treeview.column-separators.dialog-action-box > listview > row > cell, columnview.column-separators > header > button, treeview.column-separators.view > header > button, window.print:not(.ssd-frame) treeview.column-separators.dialog-action-box > header > button { border-left-color: color-mix(in srgb, currentColor var(--border-opacity), transparent); }

columnview > listview:not(.horizontal).separators > row:not(.separator), treeview.view > listview:not(.horizontal).separators > row:not(.separator), window.print:not(.ssd-frame) treeview.dialog-action-box > listview:not(.horizontal).separators > row:not(.separator) { border-top: 1px solid color-mix(in srgb, currentColor var(--border-opacity), transparent); border-bottom: none; }

columnview.data-table > listview > row > cell, treeview.data-table.view > listview > row > cell, window.print:not(.ssd-frame) treeview.data-table.dialog-action-box > listview > row > cell { padding-top: 2px; padding-bottom: 2px; }

columnview ~ undershoot.top, treeview.view ~ undershoot.top, window.print:not(.ssd-frame) treeview.dialog-action-box ~ undershoot.top { box-shadow: inset 0 1px color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to bottom, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

columnview row:not(:selected) cell editablelabel:not(.editing):focus-within, treeview.view row:not(:selected) cell editablelabel:not(.editing):focus-within, window.print:not(.ssd-frame) treeview.dialog-action-box row:not(:selected) cell editablelabel:not(.editing):focus-within { outline: 2px solid color-mix(in srgb, var(--accent-color) 50%, transparent); }

columnview row:not(:selected) cell editablelabel.editing:focus-within, treeview.view row:not(:selected) cell editablelabel.editing:focus-within, window.print:not(.ssd-frame) treeview.dialog-action-box row:not(:selected) cell editablelabel.editing:focus-within { outline: 2px solid var(--accent-color); }

treeexpander { border-spacing: 4px; }

.dialog-action-area { margin: 6px; border-spacing: 6px; }

/**************** Print dialog * */
window.print:not(.ssd-frame) drawing { color: var(--window-fg-color); background: none; border: none; padding: 0; }

window.print:not(.ssd-frame) drawing paper { background-color: white; color: RGB(0 0 6/80%); background-clip: padding-box; border: 1px solid color-mix(in srgb, currentColor var(--border-opacity), transparent); }

/******************** Page setup dalog * */
/****************** GtkAboutDialog * */
window.aboutdialog:not(.ssd-frame) image.large-icons { -gtk-icon-size: 128px; }

/************************* GtkColorChooserDialog * */
/************* AdwDialog * */
floating-sheet > dimming { background-color: RGB(from var(--shade-color) r g b/calc(alpha * 2)); }

floating-sheet > sheet { border-radius: 15px; box-shadow: 0 0 14px 2px RGB(0 0 6/3%), 0 0 5px 2px RGB(0 0 6/10%), 0 0 0 1px RGB(0 0 0 / 5%); outline: 1px solid RGB(255 255 255/7%); outline-offset: -1px; }

dialog.bottom-sheet:not(.narrow) sheet { margin-left: 30px; margin-right: 30px; }

dialog.bottom-sheet:not(.narrow) sheet.flush-left > outline, dialog.bottom-sheet:not(.narrow) sheet.flush-right > outline, dialog.bottom-sheet:not(.narrow) sheet.flush-left.flush-right > outline { box-shadow: inset 1px 0 RGB(255 255 255/7%), inset -1px 0 RGB(255 255 255/7%), inset 0 1px RGB(255 255 255/7%); }

dialog-host > dialog.background { background: none; }

dialog-host > dialog.background sheet { background-color: var(--window-bg-color); color: var(--window-fg-color); }

dialog-host > dialog.view, window.print:not(.ssd-frame) dialog-host > dialog.dialog-action-box { background: none; }

dialog-host > dialog.osd:not(progressbar):not(button):not(menubutton):not(splitbutton) { background: none; }

/*********************** GtkAppChooserDialog * */
window.appchooser:not(.ssd-frame) headerbar.titlebar > windowhandle { padding-top: 3px; }

window.appchooser:not(.ssd-frame) headerbar.titlebar box.start + box { margin-top: -6px; margin-bottom: -6px; min-height: 12px; }

window.appchooser:not(.ssd-frame) searchbar { background: none; }

window.appchooser:not(.ssd-frame) .dialog-vbox > box > box:not(.dialog-action-area) { margin: 6px; }

window.appchooser:not(.ssd-frame) .dialog-action-area { margin-top: 0; }

/**************** GtkAssistant * */
window.assistant .sidebar { padding: 6px; background-color: var(--sidebar-bg-color); color: var(--sidebar-fg-color); }

window.assistant .sidebar:not(separator):dir(ltr) { border-right: none; box-shadow: inset -1px 0 var(--sidebar-border-color); }

window.assistant .sidebar:not(separator):dir(rtl) { box-shadow: inset 1px 0 var(--sidebar-border-color); }

window.assistant .sidebar:backdrop { background-color: var(--sidebar-backdrop-color); transition: background-color 200ms ease-out; }

window.assistant .sidebar > label { padding: 6px 12px; border-radius: 9px; }

window.assistant .sidebar > label.highlight { background-color: color-mix(in srgb, currentColor 10%, transparent); }

/*************** GtkComboBox * */
combobox button { padding-top: 2px; padding-bottom: 2px; min-height: 30px; }

/*************** GtkIconView * */
iconview:not(:selected) { background-color: color-mix(in srgb, var(--accent-bg-color) 0.0001%, var(--view-bg-color)); }

iconview { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

iconview:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

iconview:drop(active) { box-shadow: none; }

iconview > dndtarget:drop(active) { border-style: solid; border-width: 1px; border-color: var(--accent-bg-color); }

/************** GtkInfoBar * */
infobar > revealer > box { padding: 6px; padding-bottom: 7px; border-spacing: 6px; box-shadow: inset 0 -1px var(--shade-color); }

infobar > revealer > box > box { border-spacing: 6px; }

infobar.action:hover > revealer > box { background-image: image(color-mix(in srgb, currentColor 5%, transparent)); }

infobar.action:active > revealer > box { background-image: image(color-mix(in srgb, currentColor 10%, transparent)); }

infobar.info > revealer > box { background-color: color-mix(in srgb, var(--accent-bg-color) 30%, var(--window-bg-color)); color: var(--window-fg-color); }

infobar.question > revealer > box { background-color: color-mix(in srgb, var(--accent-bg-color) 30%, var(--window-bg-color)); color: var(--window-fg-color); }

infobar.warning > revealer > box { background-color: color-mix(in srgb, var(--warning-bg-color) 30%, var(--window-bg-color)); color: var(--window-fg-color); }

infobar.error > revealer > box { background-color: color-mix(in srgb, var(--error-bg-color) 30%, var(--window-bg-color)); color: var(--window-fg-color); }

infobar .close { min-width: 18px; min-height: 18px; padding: 4px; border-radius: 50%; }

/**************** GtkStatusBar * */
statusbar { padding: 6px 10px 6px 10px; }

/*************** GtkTreeView * */
treeview.view, window.print:not(.ssd-frame) treeview.dialog-action-box { border-left-color: color-mix(in srgb, currentColor 20%, var(--view-bg-color)); border-top-color: color-mix(in srgb, currentColor 20%, var(--view-bg-color)); }

treeview.view:disabled, window.print:not(.ssd-frame) treeview.dialog-action-box:disabled { color: color-mix(in srgb, var(--view-fg-color) var(--disabled-opacity), transparent); }

treeview.view:not(:selected), window.print:not(.ssd-frame) treeview.dialog-action-box:not(:selected) { background-color: color-mix(in srgb, var(--accent-bg-color) 0.0001%, var(--view-bg-color)); }

treeview.view:selected:focus, treeview.view:selected, window.print:not(.ssd-frame) treeview.dialog-action-box:selected { border-radius: 0; }

treeview.view.separator, window.print:not(.ssd-frame) treeview.separator.dialog-action-box { min-height: 2px; color: color-mix(in srgb, currentColor var(--border-opacity), transparent); }

treeview.view.expander, window.print:not(.ssd-frame) treeview.expander.dialog-action-box { min-width: 16px; min-height: 16px; -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); color: color-mix(in srgb, currentColor 70%, transparent); }

treeview.view.expander:dir(rtl), window.print:not(.ssd-frame) treeview.expander.dialog-action-box:dir(rtl) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }

treeview.view.expander:hover, window.print:not(.ssd-frame) treeview.expander.dialog-action-box:hover, treeview.view.expander:active, window.print:not(.ssd-frame) treeview.expander.dialog-action-box:active { color: currentColor; }

treeview.view.expander:checked, window.print:not(.ssd-frame) treeview.expander.dialog-action-box:checked { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

treeview.view.expander:disabled, window.print:not(.ssd-frame) treeview.expander.dialog-action-box:disabled { color: color-mix(in srgb, currentColor var(--disabled-opacity), transparent); }

treeview.view > dndtarget:drop(active), window.print:not(.ssd-frame) treeview.dialog-action-box > dndtarget:drop(active) { border-style: solid none; border-width: 1px; border-color: var(--accent-bg-color); }

treeview.view > dndtarget:drop(active).after, window.print:not(.ssd-frame) treeview.dialog-action-box > dndtarget:drop(active).after { border-top-style: none; }

treeview.view > dndtarget:drop(active).before, window.print:not(.ssd-frame) treeview.dialog-action-box > dndtarget:drop(active).before { border-bottom-style: none; }

treeview.view > header > button, window.print:not(.ssd-frame) treeview.dialog-action-box > header > button { padding-left: 4px; padding-right: 4px; border-bottom: 1px solid color-mix(in srgb, currentColor var(--border-opacity), transparent); }

treeview.view.progressbar, window.print:not(.ssd-frame) treeview.progressbar.dialog-action-box { box-shadow: none; }

treeview.view.progressbar, window.print:not(.ssd-frame) treeview.progressbar.dialog-action-box, treeview.view.progressbar:selected { background-color: var(--accent-bg-color); color: var(--accent-fg-color); }

treeview.view.trough, window.print:not(.ssd-frame) treeview.trough.dialog-action-box { background-color: color-mix(in srgb, currentColor 10%, transparent); }

treeview.view ~ undershoot.top, window.print:not(.ssd-frame) treeview.dialog-action-box ~ undershoot.top { box-shadow: none; background: none; }

treeview.view acceleditor > label, window.print:not(.ssd-frame) treeview.dialog-action-box acceleditor > label { background-color: color-mix(in srgb, currentColor 10%, var(--view-bg-color)); }

treeview.navigation-sidebar { padding: 0; }

treeview.navigation-sidebar:selected:focus, treeview.navigation-sidebar:selected { background-color: color-mix(in srgb, currentColor 10%, transparent); }

treeview entry:focus-within:dir(rtl), treeview entry:focus-within:dir(ltr) { background-color: var(--view-bg-color); transition-property: color, background; }

treeview entry.flat, treeview entry { border-radius: 0; background-image: none; background-color: var(--view-bg-color); }

treeview entry.flat:focus-within, treeview entry:focus-within { border-color: var(--accent-color); }

treeview spinbutton:not(.vertical) { min-height: 0; border-style: none; border-radius: 0; }

treeview spinbutton:not(.vertical) > text { min-height: 0; padding: 1px 2px; }

/******************** GtkShortcutLabel * */
shortcut { border-spacing: 6px; border-radius: 6px; }

shortcut { outline: 0 solid transparent; outline-offset: 8px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

shortcut:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: 4px; }

shortcut > .keycap { min-width: 20px; min-height: 25px; padding: 2px 6px; background: color-mix(in srgb, currentColor 10%, transparent); box-shadow: inset 0 -2px var(--card-shade-color); border-radius: 6px; font-size: smaller; }

/********************** GtkShortcutsWindow * */
shortcuts-section { margin: 20px; }

.shortcuts-search-results { margin: 20px; border-spacing: 24px; }

shortcuts-section stackswitcher.circular { border-spacing: 12px; }

shortcuts-section stackswitcher.circular > button.circular, shortcuts-section stackswitcher.circular > button.text-button.circular { min-width: 32px; min-height: 32px; padding: 0; }

window.shortcuts:not(.ssd-frame) headerbar.titlebar > windowhandle { padding-top: 3px; }

window.shortcuts:not(.ssd-frame) searchbar { background: none; }

/* Transition shadows */
flap > dimming, leaflet > dimming { background: var(--shade-color); }

flap > shadow, leaflet > shadow { min-width: 56px; min-height: 56px; }

flap > shadow.left, leaflet > shadow.left { background-image: linear-gradient(to right, color-mix(in srgb, var(--shade-color) 70%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 40px, RGB(from var(--shade-color) r g b/0) 56px), linear-gradient(to right, color-mix(in srgb, var(--shade-color) 40%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 7px, RGB(from var(--shade-color) r g b/0) 24px); }

flap > shadow.right, leaflet > shadow.right { background-image: linear-gradient(to left, color-mix(in srgb, var(--shade-color) 70%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 40px, RGB(from var(--shade-color) r g b/0) 56px), linear-gradient(to left, color-mix(in srgb, var(--shade-color) 40%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 7px, RGB(from var(--shade-color) r g b/0) 24px); }

flap > shadow.up, leaflet > shadow.up { background-image: linear-gradient(to bottom, color-mix(in srgb, var(--shade-color) 70%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 40px, RGB(from var(--shade-color) r g b/0) 56px), linear-gradient(to bottom, color-mix(in srgb, var(--shade-color) 40%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 7px, RGB(from var(--shade-color) r g b/0) 24px); }

flap > shadow.down, leaflet > shadow.down { background-image: linear-gradient(to top, color-mix(in srgb, var(--shade-color) 70%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 40px, RGB(from var(--shade-color) r g b/0) 56px), linear-gradient(to top, color-mix(in srgb, var(--shade-color) 40%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 7px, RGB(from var(--shade-color) r g b/0) 24px); }

.sidebar:not(separator):dir(ltr), .sidebar:not(separator).left, .sidebar:not(separator).left:dir(rtl) { border-right: 1px solid color-mix(in srgb, currentColor var(--border-opacity), transparent); border-left-style: none; }

.sidebar:not(separator):dir(rtl), .sidebar:not(separator).right { border-left: 1px solid color-mix(in srgb, currentColor var(--border-opacity), transparent); border-right-style: none; }

.sidebar listview.view, .sidebar window.print:not(.ssd-frame) listview.dialog-action-box, window.print:not(.ssd-frame) .sidebar listview.dialog-action-box, .sidebar list { background-color: transparent; color: inherit; }

paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar { border-style: none; }

.large-title { font-weight: 300; font-size: 24pt; }

/********************* App Notifications * */
.app-notification { padding: 10px; border-spacing: 10px; border-radius: 0 0 15px 15px; background-image: linear-gradient(to bottom, RGB(0 0 0/20%), transparent 2px); background-clip: padding-box; }

.app-notification border { border: none; }

dropdown > button > box, combobox > button > box { border-spacing: 6px; }

dropdown > button > box > stack > row.activatable:hover, combobox > button > box > stack > row.activatable:hover, dropdown > button > box > stack > row.activatable:active, combobox > button > box > stack > row.activatable:active { background: none; }

dropdown arrow, combobox arrow { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); min-height: 16px; min-width: 16px; }

dropdown:drop(active), combobox:drop(active) { box-shadow: none; }

dropdown popover.menu, combobox popover.menu { padding-top: 6px; }

dropdown popover.menu listview > row, combobox popover.menu listview > row { min-width: 0; }

dropdown popover.menu .dropdown-searchbar, combobox popover.menu .dropdown-searchbar { padding: 6px; }

dropdown popover.menu .dropdown-searchbar + scrolledwindow:not(.undershoot-top) > undershoot.top, combobox popover.menu .dropdown-searchbar + scrolledwindow:not(.undershoot-top) > undershoot.top { box-shadow: inset 0 1px color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to bottom, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

popover.emoji-picker > contents { padding: 0; }

.emoji-searchbar { padding: 6px; }

.emoji-toolbar { padding: 3px; }

button.emoji-section.image-button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) { min-width: 32px; min-height: 32px; }

popover.emoji-picker emoji { font-size: x-large; padding: 6px; border-radius: 9px; }

popover.emoji-picker emoji:focus, popover.emoji-picker emoji:hover { background: color-mix(in srgb, currentColor 7%, transparent); }

popover.emoji-picker emoji:active { background: color-mix(in srgb, currentColor 16%, transparent); }

popover.emoji-picker scrolledwindow.view, popover.emoji-picker window.print:not(.ssd-frame) scrolledwindow.dialog-action-box, window.print:not(.ssd-frame) popover.emoji-picker scrolledwindow.dialog-action-box { background: none; color: inherit; }

popover.emoji-picker scrolledwindow.view:not(.undershoot-top) > undershoot.top, popover.emoji-picker window.print:not(.ssd-frame) scrolledwindow.dialog-action-box:not(.undershoot-top) > undershoot.top, window.print:not(.ssd-frame) popover.emoji-picker scrolledwindow.dialog-action-box:not(.undershoot-top) > undershoot.top { box-shadow: inset 0 1px color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to bottom, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

popover.emoji-picker scrolledwindow.view:not(.undershoot-bottom) > undershoot.bottom, popover.emoji-picker window.print:not(.ssd-frame) scrolledwindow.dialog-action-box:not(.undershoot-bottom) > undershoot.bottom, window.print:not(.ssd-frame) popover.emoji-picker scrolledwindow.dialog-action-box:not(.undershoot-bottom) > undershoot.bottom { box-shadow: inset 0 -1px color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to top, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

popover.emoji-completion > contents { padding: 6px; padding-bottom: 4px; }

emoji-completion-row { padding: 6px; margin-bottom: 2px; border-radius: 9px; }

emoji-completion-row:dir(ltr) { padding-right: 12px; }

emoji-completion-row:dir(rtl) { padding-left: 12px; }

emoji-completion-row > box { border-spacing: 6px; }

emoji-completion-row:focus, emoji-completion-row:hover { background-color: color-mix(in srgb, currentColor 10%, transparent); color: var(--popover-fg-color); }

emoji-completion-row:active { background-color: color-mix(in srgb, currentColor 16%, transparent); }

spinbutton, entry { min-height: 34px; padding-left: 9px; padding-right: 9px; border-radius: 9px; border-spacing: 6px; background-color: color-mix(in srgb, currentColor 10%, transparent); background-clip: padding-box; caret-color: currentColor; }

spinbutton, entry { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

spinbutton:focus-within, entry:focus-within { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

spinbutton > text > block-cursor, entry > text > block-cursor { color: var(--view-bg-color); background-color: var(--view-fg-color); }

spinbutton.flat:focus-within, spinbutton.flat:disabled, spinbutton.flat, entry.flat:focus-within, entry.flat:disabled, entry.flat { min-height: 0; padding: 2px; background-color: transparent; box-shadow: none; border-radius: 0; }

spinbutton:disabled, entry:disabled { filter: Opacity(var(--disabled-opacity)); }

spinbutton > image, entry > image { opacity: 0.7; }

spinbutton > image:hover, entry > image:hover { opacity: 1; }

spinbutton > image:active, entry > image:active { opacity: 0.8; }

spinbutton > image.left, entry > image.left { margin-right: 6px; }

spinbutton > image.right, entry > image.right { margin-left: 6px; }

spinbutton.password image.caps-lock-indicator, entry.password image.caps-lock-indicator { opacity: 30%; }

spinbutton:drop(active), entry:drop(active):focus-within, entry:drop(active) { border-color: var(--accent-bg-color); box-shadow: inset 0 0 0 1px var(--accent-bg-color); }

spinbutton > progress, entry > progress { margin-bottom: 3px; }

spinbutton > progress > trough, entry > progress > trough { min-height: 2px; }

spinbutton > progress > trough > progress, entry > progress > trough > progress { background-color: transparent; background-image: none; border-radius: 0; border-width: 0 0 2px; border-color: var(--accent-bg-color); border-style: solid; box-shadow: none; }

expander { min-width: 16px; min-height: 16px; -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

expander:dir(rtl) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }

expander:disabled { filter: Opacity(var(--disabled-opacity)); }

expander:checked { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

expander-widget > box > title { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

expander-widget:focus:focus-visible > box > title { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

expander-widget > box > title { border-radius: 6px; }

expander-widget > box > title > expander { opacity: .7; }

expander-widget > box > title:hover > expander, expander-widget > box > title:active > expander { opacity: 1; }

placessidebar .navigation-sidebar > row { padding: 0; }

placessidebar .navigation-sidebar > row > revealer { padding: 0 14px; }

placessidebar .navigation-sidebar > row image.sidebar-icon:dir(ltr) { padding-right: 8px; }

placessidebar .navigation-sidebar > row image.sidebar-icon:dir(rtl) { padding-left: 8px; }

placessidebar .navigation-sidebar > row label.sidebar-label:dir(ltr) { padding-right: 2px; }

placessidebar .navigation-sidebar > row label.sidebar-label:dir(rtl) { padding-left: 2px; }

button.sidebar-button { min-height: 26px; min-width: 26px; margin-top: 3px; margin-bottom: 3px; padding: 0; border-radius: 100%; }

placessidebar .navigation-sidebar > row:selected:active { box-shadow: none; }

placessidebar .navigation-sidebar > row.sidebar-placeholder-row { padding: 0 8px; min-height: 2px; background-image: image(var(--accent-bg-color)); background-clip: content-box; }

placessidebar .navigation-sidebar > row.sidebar-new-bookmark-row { color: var(--accent-color); }

placessidebar .navigation-sidebar > row:drop(active):not(:disabled) { color: var(--accent-bg-color); box-shadow: inset 0 0 0 1px var(--accent-bg-color); }

row image.sidebar-icon { opacity: 0.7; }

row .sidebar-button { opacity: 0.7; }

row .sidebar-button:hover, row .sidebar-button:active, row .sidebar-button.keyboard-activating { opacity: 1; }

placesview .server-list-button > image { transition: -gtk-icon-transform 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); -gtk-icon-transform: rotate(0turn); }

placesview .server-list-button:checked > image { -gtk-icon-transform: rotate(-0.5turn); }

placesview > actionbar > revealer > box > box { border-spacing: 6px; }

filechooser { box-shadow: 0 1px color-mix(in srgb, currentColor var(--border-opacity), transparent); }

filechooser pathbar button:not(.image-button) { padding-left: 9px; padding-right: 9px; }

filechooser pathbar button > box { border-spacing: 4px; }

filechooser pathbar button > box > label { padding-left: 2px; padding-right: 2px; }

filechooser columnview > listview > row > cell, filechooser treeview.view > listview > row > cell, filechooser window.print:not(.ssd-frame) treeview.dialog-action-box > listview > row > cell, window.print:not(.ssd-frame) filechooser treeview.dialog-action-box > listview > row > cell { padding: 0; }

filechooser columnview > listview > row > cell > filelistcell, filechooser treeview.view > listview > row > cell > filelistcell, filechooser window.print:not(.ssd-frame) treeview.dialog-action-box > listview > row > cell > filelistcell, window.print:not(.ssd-frame) filechooser treeview.dialog-action-box > listview > row > cell > filelistcell { padding: 8px 6px; }

filechooser gridview { padding: 15px; }

filechooser gridview ~ undershoot.top { box-shadow: inset 0 1px color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to bottom, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

filechooser gridview > child { border-radius: 12px; padding: 0; margin: 3px; }

filechooser gridview > child > filelistcell { padding: 6px 12px; }

filechooser gridview > child filethumbnail image { filter: drop-shadow(0px 1px 1px RGB(0 0 6/30%)); }

filechooser gridview > child box { border-spacing: 6px; }

filechooser columnview > listview, filechooser treeview.view > listview, filechooser window.print:not(.ssd-frame) treeview.dialog-action-box > listview, window.print:not(.ssd-frame) filechooser treeview.dialog-action-box > listview, filechooser gridview { --accent-bg-color: #959595; --accent-color: oklab(from var(--accent-bg-color) var(--standalone-color-oklab)); }

filechooser > box > actionbar { box-shadow: 0 -1px color-mix(in srgb, var(--headerbar-shade-color) 50%, transparent), 0 -2px 4px color-mix(in srgb, var(--headerbar-shade-color) 50%, transparent); }

filechooser > box > actionbar > revealer > box { box-shadow: none; padding-top: 6px; }

filechooser scrolledwindow + actionbar > revealer > box { background-color: color-mix(in srgb, var(--accent-bg-color) 30%, var(--view-bg-color)); color: var(--window-fg-color); box-shadow: none; padding-top: 6px; font-weight: bold; }

filechooser scrolledwindow + actionbar > revealer > box:backdrop { background-color: color-mix(in srgb, var(--accent-bg-color) 15%, var(--view-bg-color)); }

filechooser placesview > stack > scrolledwindow > undershoot.bottom { box-shadow: inset 0 -1px color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to top, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

filechooser placesview > stack > scrolledwindow list { --accent-bg-color: #959595; --accent-color: oklab(from var(--accent-bg-color) var(--standalone-color-oklab)); }

filechooser placesview > actionbar > revealer > box { background: var(--view-bg-color); color: var(--view-fg-color); box-shadow: none; padding-top: 6px; }

filechooser placesview > actionbar > revealer > box:backdrop { background: var(--view-bg-color); transition: none; }

filechooser placessidebar { background-color: var(--sidebar-bg-color); color: var(--sidebar-fg-color); }

filechooser placessidebar:backdrop { background-color: var(--sidebar-backdrop-color); transition: background-color 200ms ease-out; }

filechooser paned.horizontal > separator:dir(ltr) { box-shadow: inset 1px 0 var(--sidebar-bg-color), inset 1px 0 var(--sidebar-border-color); }

filechooser paned.horizontal > separator:dir(ltr):backdrop { box-shadow: inset 1px 0 var(--sidebar-backdrop-color), inset 1px 0 var(--sidebar-border-color); }

filechooser paned.horizontal > separator:dir(rtl) { box-shadow: inset -1px 0 var(--sidebar-bg-color), inset -1px 0 var(--sidebar-border-color); }

filechooser paned.horizontal > separator:dir(rtl):backdrop { box-shadow: inset -1px 0 var(--sidebar-backdrop-color), inset -1px 0 var(--sidebar-border-color); }

filechooser paned.horizontal > separator:backdrop { transition: box-shadow 200ms ease-out; }

/* Fix header bar height in the file chooser */
window.filechooser headerbar box.start + box.vertical { margin-top: -6px; margin-bottom: -6px; min-height: 12px; }

headerbar { min-height: 47px; background-color: var(--headerbar-bg-color); color: var(--headerbar-fg-color); box-shadow: inset 0 -1px var(--headerbar-shade-color), inset 1px 0 color-mix(in srgb, var(--headerbar-border-color) var(--border-opacity), transparent), inset -1px 0 color-mix(in srgb, var(--headerbar-border-color) var(--border-opacity), transparent); margin-left: -1px; margin-right: -1px; }

headerbar > windowhandle > box { padding: 6px 7px 7px 7px; }

headerbar > windowhandle > box > box.start, headerbar > windowhandle > box > box.end { border-spacing: 6px; }

headerbar > windowhandle > box > box.start:dir(ltr), headerbar > windowhandle > box > box.end:dir(rtl), headerbar > windowhandle > box > widget > box.start:dir(ltr), headerbar > windowhandle > box > widget > box.end:dir(rtl) { margin-right: 6px; }

headerbar > windowhandle > box > box.start:dir(rtl), headerbar > windowhandle > box > box.end:dir(ltr), headerbar > windowhandle > box > widget > box.start:dir(rtl), headerbar > windowhandle > box > widget > box.end:dir(ltr) { margin-left: 6px; }

headerbar:backdrop { background-color: var(--headerbar-backdrop-color); transition: background-color 200ms ease-out; }

headerbar:backdrop > windowhandle { filter: opacity(0.5); transition: filter 200ms ease-out; }

headerbar.default-decoration { min-height: 37px; }

headerbar.default-decoration > windowhandle > box { padding: 3px 4px 4px 4px; }

headerbar.default-decoration windowcontrols > button { min-height: 22px; min-width: 22px; padding: 4px; }

headerbar.default-decoration windowcontrols > button > image { padding: 3px; }

headerbar.default-decoration windowcontrols > .icon { margin: 7px; }

window:not(.ssd-frame) > .titlebar:not(.flat) { box-shadow: 0 1px color-mix(in srgb, var(--headerbar-shade-color) 50%, transparent), 0 2px 4px color-mix(in srgb, var(--headerbar-shade-color) 50%, transparent); }

window:not(.ssd-frame) > .titlebar headerbar:not(.flat) { box-shadow: inset 1px 0 color-mix(in srgb, var(--headerbar-border-color) var(--border-opacity), transparent), inset -1px 0 color-mix(in srgb, var(--headerbar-border-color) var(--border-opacity), transparent); }

window:not(.ssd-frame) > headerbar.titlebar, window:not(.ssd-frame) > .titlebar headerbar { min-height: 46px; }

window:not(.ssd-frame) > headerbar.titlebar > windowhandle > box, window:not(.ssd-frame) > .titlebar headerbar > windowhandle > box { padding-bottom: 6px; }

window:not(.ssd-frame) > headerbar.titlebar.default-decoration, window:not(.ssd-frame) > .titlebar headerbar.default-decoration { min-height: 36px; }

window:not(.ssd-frame) > headerbar.titlebar.default-decoration > windowhandle > box, window:not(.ssd-frame) > .titlebar headerbar.default-decoration > windowhandle > box { padding-bottom: 3px; }

toolbarview > .top-bar headerbar, toolbarview > .bottom-bar headerbar, headerbar.flat, adaptive-preview headerbar.adaptive-mode-flat, window.print:not(.ssd-frame) headerbar.titlebar, window.pagesetup:not(.ssd-frame) headerbar.titlebar, window.aboutdialog:not(.ssd-frame) headerbar.titlebar, window.colorchooser:not(.ssd-frame) headerbar.titlebar, window.appchooser:not(.ssd-frame) headerbar.titlebar, window.shortcuts:not(.ssd-frame) headerbar.titlebar { background: none; box-shadow: none; color: inherit; min-height: 46px; }

toolbarview > .top-bar headerbar > windowhandle > box, toolbarview > .bottom-bar headerbar > windowhandle > box, headerbar.flat > windowhandle > box, adaptive-preview headerbar.adaptive-mode-flat > windowhandle > box, window.print:not(.ssd-frame) headerbar.titlebar > windowhandle > box, window.pagesetup:not(.ssd-frame) headerbar.titlebar > windowhandle > box, window.aboutdialog:not(.ssd-frame) headerbar.titlebar > windowhandle > box, window.colorchooser:not(.ssd-frame) headerbar.titlebar > windowhandle > box, window.appchooser:not(.ssd-frame) headerbar.titlebar > windowhandle > box, window.shortcuts:not(.ssd-frame) headerbar.titlebar > windowhandle > box { padding-bottom: 6px; }

toolbarview > .top-bar headerbar.default-decoration, toolbarview > .bottom-bar headerbar.default-decoration, headerbar.default-decoration.flat, adaptive-preview headerbar.default-decoration.adaptive-mode-flat, window.print:not(.ssd-frame) headerbar.default-decoration.titlebar, window.pagesetup:not(.ssd-frame) headerbar.default-decoration.titlebar, window.aboutdialog:not(.ssd-frame) headerbar.default-decoration.titlebar, window.colorchooser:not(.ssd-frame) headerbar.default-decoration.titlebar, window.appchooser:not(.ssd-frame) headerbar.default-decoration.titlebar, window.shortcuts:not(.ssd-frame) headerbar.default-decoration.titlebar { min-height: 36px; }

toolbarview > .top-bar headerbar.default-decoration > windowhandle > box, toolbarview > .bottom-bar headerbar.default-decoration > windowhandle > box, headerbar.default-decoration.flat > windowhandle > box, adaptive-preview headerbar.default-decoration.adaptive-mode-flat > windowhandle > box, window.print:not(.ssd-frame) headerbar.default-decoration.titlebar > windowhandle > box, window.pagesetup:not(.ssd-frame) headerbar.default-decoration.titlebar > windowhandle > box, window.aboutdialog:not(.ssd-frame) headerbar.default-decoration.titlebar > windowhandle > box, window.colorchooser:not(.ssd-frame) headerbar.default-decoration.titlebar > windowhandle > box, window.appchooser:not(.ssd-frame) headerbar.default-decoration.titlebar > windowhandle > box, window.shortcuts:not(.ssd-frame) headerbar.default-decoration.titlebar > windowhandle > box { padding-bottom: 3px; }

toolbarview > .top-bar headerbar:backdrop, toolbarview > .bottom-bar headerbar:backdrop { transition: none; }

toolbarview > .top-bar headerbar:backdrop > windowhandle, toolbarview > .bottom-bar headerbar:backdrop > windowhandle { filter: none; transition: none; }

window.devel toolbarview > .top-bar headerbar > windowhandle, toolbarview > .top-bar window.devel headerbar > windowhandle, window.devel toolbarview > .bottom-bar headerbar > windowhandle, toolbarview > .bottom-bar window.devel headerbar > windowhandle { background-image: none; }

toolbarview > .top-bar .collapse-spacing headerbar, toolbarview > .bottom-bar .collapse-spacing headerbar, window.appchooser:not(.ssd-frame) headerbar.titlebar, window.shortcuts:not(.ssd-frame) headerbar.titlebar { min-height: 40px; }

toolbarview > .top-bar .collapse-spacing headerbar > windowhandle > box, toolbarview > .bottom-bar .collapse-spacing headerbar > windowhandle > box, window.appchooser:not(.ssd-frame) headerbar.titlebar > windowhandle > box, window.shortcuts:not(.ssd-frame) headerbar.titlebar > windowhandle > box { padding-top: 3px; padding-bottom: 3px; }

toolbarview > .top-bar .collapse-spacing headerbar.default-decoration, toolbarview > .bottom-bar .collapse-spacing headerbar.default-decoration, window.appchooser:not(.ssd-frame) headerbar.default-decoration.titlebar, window.shortcuts:not(.ssd-frame) headerbar.default-decoration.titlebar { min-height: 30px; }

toolbarview > .top-bar .collapse-spacing headerbar.default-decoration > windowhandle > box, toolbarview > .bottom-bar .collapse-spacing headerbar.default-decoration > windowhandle > box, window.appchooser:not(.ssd-frame) headerbar.default-decoration.titlebar > windowhandle > box, window.shortcuts:not(.ssd-frame) headerbar.default-decoration.titlebar > windowhandle > box { padding-top: 0px; padding-bottom: 0px; }

.titlebar:not(headerbar) separator { background-color: color-mix(in srgb, var(--headerbar-border-color) var(--border-opacity), transparent); }

/********************* GtkWindowControls * */
windowcontrols { border-spacing: 3px; }

windowcontrols > button { min-width: 24px; padding: 5px; }

windowcontrols > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button, windowcontrols > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button:hover, windowcontrols > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button:active { background: none; box-shadow: none; }

windowcontrols > button > image { background-color: color-mix(in srgb, currentColor 10%, transparent); border-radius: 100%; padding: 4px; transition: background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

windowcontrols > button:hover > image { background-color: color-mix(in srgb, currentColor 15%, transparent); }

windowcontrols > button:active > image { background-color: color-mix(in srgb, currentColor 30%, transparent); }

windowcontrols > .icon { margin: 9px; }

/****************** AdwWindowTitle * */
headerbar .title, windowtitle .title { padding-left: 12px; padding-right: 12px; font-weight: bold; }

headerbar .subtitle, windowtitle .subtitle { font-size: smaller; padding-left: 12px; padding-right: 12px; }

windowtitle { margin-top: -6px; margin-bottom: -6px; min-height: 12px; }

window.devel headerbar > windowhandle { background-image: cross-fade(5% -gtk-recolor(url("assets/devel-symbolic.svg")), image(transparent)); background-repeat: repeat-x; }

window.devel sheet headerbar > windowhandle { background-image: unset; background-repeat: unset; }

.accent-color-row color { min-width: 16px; min-height: 16px; border-radius: 16px; }

.accent-color-row color:disabled { opacity: var(--disabled-opacity); }

adaptive-preview .device-view { background: #101011; color: white; box-shadow: 0 0 0 2px RGB(255 255 255/15%); margin: 2px; padding: var(--top-bezel) var(--side-bezel) var(--bottom-bezel); border-radius: var(--top-device-corner-radius) var(--top-device-corner-radius) var(--bottom-device-corner-radius) var(--bottom-device-corner-radius); --window-radius: 0px; /* Hack to make GtkGraphicsOffload disable offload in this case */ opacity: 99.9999999999999%; }

adaptive-preview .device-view.custom { padding: 0; border-radius: 0; margin: 0; box-shadow: 0 0 14px 2px RGB(0 0 6/3%), 0 0 5px 2px RGB(0 0 6/10%), 0 0 0 1px RGB(0 0 0 / 5%); }

adaptive-preview .device-view.highlight { background: oklab(from var(--accent-bg-color) 0.5 a b); box-shadow: none; }

adaptive-preview .device-view.highlight .screen-view .shell-top-bar, adaptive-preview .device-view.highlight .screen-view .shell-bottom-bar { background: none; }

adaptive-preview .device-view.highlight.custom { box-shadow: 0 0 14px 2px RGB(0 0 6/3%), 0 0 5px 2px RGB(0 0 6/10%), 0 0 0 3px oklab(from var(--accent-bg-color) 0.5 a b); }

adaptive-preview .device-view .screen-view { border-radius: var(--top-screen-corner-radius) var(--top-screen-corner-radius) var(--bottom-screen-corner-radius) var(--bottom-screen-corner-radius); }

adaptive-preview .device-view .screen-view.outline { filter: drop-shadow(3px 0 0 var(--accent-bg-color)) drop-shadow(-3px 0 0 var(--accent-bg-color)) drop-shadow(0 3px 0 var(--accent-bg-color)) drop-shadow(0 -3px 0 var(--accent-bg-color)); }

adaptive-preview .device-view .screen-view .shell-top-bar, adaptive-preview .device-view .screen-view .shell-bottom-bar { background: black; }

label { caret-color: currentColor; }

label:disabled { filter: Opacity(var(--disabled-opacity)); }

.dimmed, dialog.shortcuts .shortcut-row .title-box > .subtitle, scale > value, progressbar > text, row.property > box.header > box.title > .title, row.property.expander > box > list > row.header > box.header > box.title > .title, row.expander image.expander-row-arrow, row label.subtitle, .dim-label, spinbutton > text > placeholder, entry > text > placeholder, headerbar .subtitle, windowtitle .subtitle, label.separator { opacity: var(--dim-opacity); }

.accent { color: var(--accent-color); }

.error { color: var(--accent-color); --accent-bg-color: var(--error-bg-color); --accent-fg-color: var(--error-fg-color); --accent-color: var(--error-color); }

.warning { color: var(--accent-color); --accent-bg-color: var(--warning-bg-color); --accent-fg-color: var(--warning-fg-color); --accent-color: var(--warning-color); }

.success { color: var(--accent-color); --accent-bg-color: var(--success-bg-color); --accent-fg-color: var(--success-fg-color); --accent-color: var(--success-color); }

/********************** General Typography * */
.title-1, statuspage > scrolledwindow > viewport > box > clamp > box > .title { font-weight: 800; font-size: 181%; }

.title-2, statuspage.spinner > scrolledwindow > viewport > box > clamp > box > .title, statuspage.compact > scrolledwindow > viewport > box > clamp > box > .title, window.dialog.message box.dialog-vbox.vertical > box > box > box > label.title { font-weight: 800; font-size: 136%; }

.title-3 { font-weight: 700; font-size: 136%; }

.title-4 { font-weight: 700; font-size: 118%; }

.heading, row.button .title, listview > header { font-weight: 700; }

.body { font-weight: 400; line-height: 140%; }

.caption-heading, columnview > header > button > box, treeview.view > header > button > box, window.print:not(.ssd-frame) treeview.dialog-action-box > header > button > box { font-weight: 700; font-size: 82%; }

.caption, dialog.shortcuts .shortcut-row .title-box > .subtitle { font-weight: 400; font-size: 82%; line-height: 140%; }

.document { font-family: var(--document-font-family); font-size: var(--document-font-size); line-height: 140%; }

.monospace { font-family: var(--monospace-font-family); font-size: var(--monospace-font-size); }

.numeric, spinbutton, scale > value, progressbar > text { font-feature-settings: "tnum"; }

/******************* Editable Labels * */
editablelabel > stack > text { color: var(--view-fg-color); background-color: var(--view-bg-color); }

levelbar:disabled { filter: Opacity(var(--disabled-opacity)); }

levelbar.horizontal trough > block { min-height: 8px; border-radius: 99px; }

levelbar.horizontal trough > block.empty, levelbar.horizontal trough > block.full { border-radius: 99px; }

levelbar.horizontal.discrete > trough > block { min-height: 8px; margin-right: 2px; min-width: 26px; border-radius: 0; }

levelbar.horizontal.discrete > trough > block:first-child { border-radius: 99px 0 0 99px; }

levelbar.horizontal.discrete > trough > block:last-child { border-radius: 0 99px 99px 0; margin-right: 0; }

levelbar.vertical trough > block { min-width: 8px; border-radius: 99px; }

levelbar.vertical trough > block.empty, levelbar.vertical trough > block.full { border-radius: 99px; }

levelbar.vertical.discrete > trough > block { min-width: 8px; margin-bottom: 2px; min-height: 26px; border-radius: 0; }

levelbar.vertical.discrete > trough > block:first-child { border-radius: 99px 99px 0 0; }

levelbar.vertical.discrete > trough > block:last-child { border-radius: 0 0 99px 99px; margin-bottom: 0; }

levelbar > trough { padding: 0; }

levelbar > trough > block.low { background-color: var(--warning-bg-color); }

levelbar > trough > block.high, levelbar > trough > block:not(.empty) { background-color: var(--accent-bg-color); }

levelbar > trough > block.full { background-color: var(--success-bg-color); }

levelbar > trough > block.empty { background-color: color-mix(in srgb, currentColor 15%, transparent); }

.linked:not(.vertical) > button:dir(ltr):not(:first-child), .linked:not(.vertical) > button:dir(rtl):not(:last-child) { border-top-left-radius: 0; border-bottom-left-radius: 0; margin-left: -1px; }

.linked:not(.vertical) > button:dir(ltr):not(:last-child), .linked:not(.vertical) > button:dir(rtl):not(:first-child) { border-top-right-radius: 0; border-bottom-right-radius: 0; }

.linked.vertical button:not(:first-child) { border-top-left-radius: 0; border-top-right-radius: 0; margin-top: -1px; }

.linked.vertical button:not(:last-child) { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }

.linked:not(.vertical) > menubutton:dir(ltr):not(:first-child) > button, .linked:not(.vertical) > menubutton:dir(rtl):not(:last-child) > button { border-top-left-radius: 0; border-bottom-left-radius: 0; margin-left: -1px; }

.linked:not(.vertical) > menubutton:dir(ltr):not(:last-child) > button, .linked:not(.vertical) > menubutton:dir(rtl):not(:first-child) > button { border-top-right-radius: 0; border-bottom-right-radius: 0; }

.linked.vertical menubutton:not(:first-child) > button { border-top-left-radius: 0; border-top-right-radius: 0; margin-top: -1px; }

.linked.vertical menubutton:not(:last-child) > button { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }

.linked:not(.vertical) > dropdown:dir(ltr):not(:first-child) > button, .linked:not(.vertical) > combobox:dir(ltr):not(:first-child) > button, .linked:not(.vertical) > dropdown:dir(rtl):not(:last-child) > button, .linked:not(.vertical) > combobox:dir(rtl):not(:last-child) > button { border-top-left-radius: 0; border-bottom-left-radius: 0; margin-left: -1px; }

.linked:not(.vertical) > dropdown:dir(ltr):not(:last-child) > button, .linked:not(.vertical) > combobox:dir(ltr):not(:last-child) > button, .linked:not(.vertical) > dropdown:dir(rtl):not(:first-child) > button, .linked:not(.vertical) > combobox:dir(rtl):not(:first-child) > button { border-top-right-radius: 0; border-bottom-right-radius: 0; }

.linked.vertical dropdown:not(:first-child) > button, .linked.vertical combobox:not(:first-child) > button { border-top-left-radius: 0; border-top-right-radius: 0; margin-top: -1px; }

.linked.vertical dropdown:not(:last-child) > button, .linked.vertical combobox:not(:last-child) > button { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }

.linked:not(.vertical) > colorbutton:dir(ltr):not(:first-child) > button, .linked:not(.vertical) > colorbutton:dir(rtl):not(:last-child) > button { border-top-left-radius: 0; border-bottom-left-radius: 0; margin-left: -1px; }

.linked:not(.vertical) > colorbutton:dir(ltr):not(:last-child) > button, .linked:not(.vertical) > colorbutton:dir(rtl):not(:first-child) > button { border-top-right-radius: 0; border-bottom-right-radius: 0; }

.linked.vertical colorbutton:not(:first-child) > button { border-top-left-radius: 0; border-top-right-radius: 0; margin-top: -1px; }

.linked.vertical colorbutton:not(:last-child) > button { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }

.linked:not(.vertical) > fontbutton:dir(ltr):not(:first-child) > button, .linked:not(.vertical) > fontbutton:dir(rtl):not(:last-child) > button { border-top-left-radius: 0; border-bottom-left-radius: 0; margin-left: -1px; }

.linked:not(.vertical) > fontbutton:dir(ltr):not(:last-child) > button, .linked:not(.vertical) > fontbutton:dir(rtl):not(:first-child) > button { border-top-right-radius: 0; border-bottom-right-radius: 0; }

.linked.vertical fontbutton:not(:first-child) > button { border-top-left-radius: 0; border-top-right-radius: 0; margin-top: -1px; }

.linked.vertical fontbutton:not(:last-child) > button { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }

.linked:not(.vertical) > tabbutton:dir(ltr):not(:first-child) > button, .linked:not(.vertical) > tabbutton:dir(rtl):not(:last-child) > button { border-top-left-radius: 0; border-bottom-left-radius: 0; margin-left: -1px; }

.linked:not(.vertical) > tabbutton:dir(ltr):not(:last-child) > button, .linked:not(.vertical) > tabbutton:dir(rtl):not(:first-child) > button { border-top-right-radius: 0; border-bottom-right-radius: 0; }

.linked.vertical tabbutton:not(:first-child) > button { border-top-left-radius: 0; border-top-right-radius: 0; margin-top: -1px; }

.linked.vertical tabbutton:not(:last-child) > button { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }

.linked:not(.vertical) > spinbutton:dir(ltr):not(:first-child), .linked:not(.vertical) > spinbutton:dir(rtl):not(:last-child) { border-top-left-radius: 0; border-bottom-left-radius: 0; margin-left: -1px; }

.linked:not(.vertical) > spinbutton:dir(ltr):not(:last-child), .linked:not(.vertical) > spinbutton:dir(rtl):not(:first-child) { border-top-right-radius: 0; border-bottom-right-radius: 0; }

.linked.vertical spinbutton:not(:first-child) { border-top-left-radius: 0; border-top-right-radius: 0; margin-top: -1px; }

.linked.vertical spinbutton:not(:last-child) { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }

.linked:not(.vertical) > entry:dir(ltr):not(:first-child), .linked:not(.vertical) > entry:dir(rtl):not(:last-child) { border-top-left-radius: 0; border-bottom-left-radius: 0; margin-left: -1px; }

.linked:not(.vertical) > entry:dir(ltr):not(:last-child), .linked:not(.vertical) > entry:dir(rtl):not(:first-child) { border-top-right-radius: 0; border-bottom-right-radius: 0; }

.linked.vertical entry:not(:first-child) { border-top-left-radius: 0; border-top-right-radius: 0; margin-top: -1px; }

.linked.vertical entry:not(:last-child) { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }

.linked:not(.vertical) > combobox:dir(ltr):not(:first-child) > box > button.combo, .linked:not(.vertical) > combobox:dir(rtl):not(:last-child) > box > button.combo { border-top-left-radius: 0; border-bottom-left-radius: 0; margin-left: -1px; }

.linked:not(.vertical) > combobox:dir(ltr):not(:last-child) > box > button.combo, .linked:not(.vertical) > combobox:dir(rtl):not(:first-child) > box > button.combo { border-top-right-radius: 0; border-bottom-right-radius: 0; }

.linked.vertical combobox:not(:first-child) > box > button.combo { border-top-left-radius: 0; border-top-right-radius: 0; margin-top: -1px; }

.linked.vertical combobox:not(:last-child) > box > button.combo { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }

.linked:not(.vertical) > appchooserbutton:dir(ltr):not(:first-child) > combobox > box > button.combo, .linked:not(.vertical) > appchooserbutton:dir(rtl):not(:last-child) > combobox > box > button.combo { border-top-left-radius: 0; border-bottom-left-radius: 0; margin-left: -1px; }

.linked:not(.vertical) > appchooserbutton:dir(ltr):not(:last-child) > combobox > box > button.combo, .linked:not(.vertical) > appchooserbutton:dir(rtl):not(:first-child) > combobox > box > button.combo { border-top-right-radius: 0; border-bottom-right-radius: 0; }

.linked.vertical appchooserbutton:not(:first-child) > combobox > box > button.combo { border-top-left-radius: 0; border-top-right-radius: 0; margin-top: -1px; }

.linked.vertical appchooserbutton:not(:last-child) > combobox > box > button.combo { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }

link, button.link { color: var(--accent-color); text-decoration: underline; font-weight: inherit; }

link:visited, button.link:visited { color: color-mix(in srgb, var(--accent-color) 80%, var(--view-fg-color)); }

link:hover, button.link:hover { color: HSL(from var(--accent-color) h calc(s * 1.1) calc(l * 1.1)); }

link:active, button.link:active { color: var(--accent-color); }

link:disabled, button.link:disabled { color: color-mix(in srgb, currentColor var(--disabled-opacity), transparent); }

.osd link, .osd button.link { color: color-mix(in srgb, var(--accent-bg-color) 50%, white); }

.osd link:visited, .osd button.link:visited { color: color-mix(in srgb, var(--accent-bg-color) 75%, white); }

.osd link:active, .osd button.link:active { color: color-mix(in srgb, var(--accent-bg-color) 50%, white); }

link { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

link:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

button.link, button.link:hover, button.link:active, button.link:checked { background-color: transparent; }

button.link > label { text-decoration: underline; }

listview, list { color: var(--view-fg-color); background-color: var(--view-bg-color); background-clip: padding-box; border-color: color-mix(in srgb, currentColor var(--border-opacity), transparent); }

listview.view:disabled, window.print:not(.ssd-frame) listview.dialog-action-box:disabled, list.view:disabled, window.print:not(.ssd-frame) list.dialog-action-box:disabled { color: var(--view-fg-color); }

listview > row, list > row { padding: 2px; background-clip: padding-box; }

listview > row.expander, list > row.expander { padding: 0px; }

listview > row.expander .row-header, list > row.expander .row-header { padding: 2px; }

listview.horizontal row.separator, listview.separators.horizontal > row:not(.separator), list.horizontal row.separator, list.separators.horizontal > row:not(.separator) { border-left: 1px solid color-mix(in srgb, currentColor var(--border-opacity), transparent); }

listview:not(.horizontal) row.separator, listview.separators:not(.horizontal) > row:not(.separator), list:not(.horizontal) row.separator, list.separators:not(.horizontal) > row:not(.separator) { border-bottom: 1px solid color-mix(in srgb, currentColor var(--border-opacity), transparent); }

listview:drop(active):focus, listview:drop(active), list:drop(active):focus, list:drop(active) { box-shadow: none; }

listview > header { padding: 2px; padding-top: 18px; padding-bottom: 6px; }

row { background-clip: padding-box; }

row { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

row:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

.osd row.activatable:hover { background-color: color-mix(in srgb, currentColor 7%, transparent); }

.osd row.activatable:active { background-color: color-mix(in srgb, currentColor 16%, transparent); }

.osd row.activatable.has-open-popup { background-color: color-mix(in srgb, currentColor 7%, transparent); }

.osd row.activatable:selected:hover { background-color: color-mix(in srgb, currentColor 13%, transparent); }

.osd row.activatable:selected:active { background-color: color-mix(in srgb, currentColor 19%, transparent); }

.osd row.activatable:selected.has-open-popup { background-color: color-mix(in srgb, currentColor 13%, transparent); }

.osd row:selected { background-color: color-mix(in srgb, currentColor 10%, transparent); }

row.activatable:hover { background-color: color-mix(in srgb, currentColor 4%, transparent); }

row.activatable:active { background-color: color-mix(in srgb, currentColor 8%, transparent); }

row.activatable.has-open-popup { background-color: color-mix(in srgb, currentColor 4%, transparent); }

row.activatable:selected:hover { background-color: color-mix(in srgb, var(--accent-bg-color) 32%, transparent); }

row.activatable:selected:active { background-color: color-mix(in srgb, var(--accent-bg-color) 39%, transparent); }

row.activatable:selected.has-open-popup { background-color: color-mix(in srgb, var(--accent-bg-color) 32%, transparent); }

row:selected { background-color: color-mix(in srgb, var(--accent-bg-color) 25%, transparent); }

/******************************************************* Rich Lists                                          * Large list usually containing lots of widgets       * https://gitlab.gnome.org/GNOME/gtk/-/issues/3073    * */
.rich-list { /* rich lists usually containing other widgets than just labels/text */ }

.rich-list > row { padding: 8px 12px; min-height: 32px; /* should be tall even when only containing a label */ }

.rich-list > row > box { border-spacing: 12px; }

.rich-list > header { padding-left: 12px; padding-right: 12px; }

/**************** AdwActionRow * */
row label.subtitle { font-size: smaller; }

row > box.header { margin-left: 12px; margin-right: 12px; border-spacing: 6px; min-height: 50px; }

row > box.header > .icon:disabled { filter: Opacity(var(--disabled-opacity)); }

row > box.header > box.title { margin-top: 6px; margin-bottom: 6px; border-spacing: 3px; padding: 0; }

row > box.header > box.title, row > box.header > box.title > .title, row > box.header > box.title > .subtitle { padding: 0; font-weight: inherit; }

row > box.header > .prefixes, row > box.header > .suffixes { border-spacing: 6px; }

row > box.header > .prefixes > .suffixes, row > box.header > .suffixes > .suffixes { border-spacing: 6px; }

row > box.header > .icon:dir(ltr), row > box.header > .prefixes:dir(ltr) { margin-right: 6px; }

row > box.header > .icon:dir(rtl), row > box.header > .prefixes:dir(rtl) { margin-left: 6px; }

/****************************** AdwEntryRow and AdwSpinRow * */
row.entry:disabled text { opacity: var(--disabled-opacity); }

row.entry:disabled .dimmed, row.entry:disabled dialog.shortcuts .shortcut-row .title-box > .subtitle, dialog.shortcuts .shortcut-row row.entry:disabled .title-box > .subtitle, row.entry:disabled scale > value, row.entry:disabled progressbar > text, row.entry:disabled row.property > box.header > box.title > .title, row.entry:disabled row.property.expander > box > list > row.header > box.header > box.title > .title, row.entry:disabled row.expander image.expander-row-arrow, row.expander row.entry:disabled image.expander-row-arrow, row.entry:disabled spinbutton > text > placeholder, row.entry:disabled entry > text > placeholder, row.entry:disabled label.separator, row.entry:disabled .dim-label, row.entry:disabled .subtitle { opacity: 1; }

row.entry > box.header { border-spacing: 0; margin-left: 6px; margin-right: 6px; }

row.entry > box.header > .editable-area { padding: 0 6px; }

row.entry > box.header > .editable-area > .edit-icon, row.entry > box.header > .editable-area > .indicator { min-width: 24px; min-height: 24px; padding: 5px; }

row.entry > box.header > .editable-area > .edit-icon:dir(ltr), row.entry > box.header > .editable-area > .indicator:dir(ltr), row.entry > box.header > .editable-area > .apply-button:dir(ltr) { margin-left: 6px; }

row.entry > box.header > .editable-area > .edit-icon:dir(rtl), row.entry > box.header > .editable-area > .indicator:dir(rtl), row.entry > box.header > .editable-area > .apply-button:dir(rtl) { margin-right: 6px; }

row.entry > box.header > .editable-area > .edit-icon:disabled { opacity: 30%; }

row.entry > box.header > .editable-area > .indicator { opacity: 30%; }

row.entry > box.header > .prefixes:dir(ltr) { margin-left: 6px; }

row.entry > box.header > .prefixes:dir(rtl) { margin-right: 6px; }

row.entry > box.header > .suffixes:dir(ltr) { margin-right: 6px; }

row.entry > box.header > .suffixes:dir(rtl) { margin-left: 6px; }

row.entry.monospace { font-family: inherit; font-size: inherit; }

row.entry.monospace text { font-family: var(--monospace-font-family); font-size: var(--monospace-font-size); }

row.spin spinbutton { background: none; border-spacing: 6px; box-shadow: none; }

row.spin spinbutton, row.spin spinbutton:focus { outline: none; }

row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child, row.spin spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, row.spin spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child { min-width: 30px; min-height: 30px; margin: 10px 2px; border: none; }

row.spin:disabled spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:disabled, row.spin:disabled spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(ltr):last-child:disabled, row.spin:disabled spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child:dir(rtl):first-child:disabled, row.spin:disabled spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled, row.spin:disabled spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child:disabled, row.spin:disabled spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child:disabled { filter: none; }

row.entry, row.spin { outline: 0 solid transparent; outline-offset: 5px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-image 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), border-radius 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

row.entry.focused, row.spin.focused { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -1px; }

row.entry:not(:selected).activatable.focused:hover, row.entry:not(:selected).activatable.focused:active, row.spin:not(:selected).activatable.focused:hover, row.spin:not(:selected).activatable.focused:active { background-color: transparent; }

row.entry.error, row.spin.error { color: var(--accent-color); }

row.entry.error .dimmed, row.entry.error dialog.shortcuts .shortcut-row .title-box > .subtitle, dialog.shortcuts .shortcut-row row.entry.error .title-box > .subtitle, row.entry.error scale > value, row.entry.error progressbar > text, row.entry.error row.property > box.header > box.title > .title, row.entry.error row.property.expander > box > list > row.header > box.header > box.title > .title, row.entry.error row.expander image.expander-row-arrow, row.expander row.entry.error image.expander-row-arrow, row.entry.error spinbutton > text > placeholder, row.entry.error entry > text > placeholder, row.entry.error label.separator, row.entry.error .dim-label, row.entry.error .subtitle, row.spin.error .dimmed, row.spin.error dialog.shortcuts .shortcut-row .title-box > .subtitle, dialog.shortcuts .shortcut-row row.spin.error .title-box > .subtitle, row.spin.error scale > value, row.spin.error progressbar > text, row.spin.error row.property > box.header > box.title > .title, row.spin.error row.property.expander > box > list > row.header > box.header > box.title > .title, row.spin.error row.expander image.expander-row-arrow, row.expander row.spin.error image.expander-row-arrow, row.spin.error spinbutton > text > placeholder, row.spin.error entry > text > placeholder, row.spin.error label.separator, row.spin.error .dim-label, row.spin.error .subtitle { opacity: 1; }

row.entry.warning, row.spin.warning { color: var(--accent-color); }

row.entry.warning .dimmed, row.entry.warning dialog.shortcuts .shortcut-row .title-box > .subtitle, dialog.shortcuts .shortcut-row row.entry.warning .title-box > .subtitle, row.entry.warning scale > value, row.entry.warning progressbar > text, row.entry.warning row.property > box.header > box.title > .title, row.entry.warning row.property.expander > box > list > row.header > box.header > box.title > .title, row.entry.warning row.expander image.expander-row-arrow, row.expander row.entry.warning image.expander-row-arrow, row.entry.warning spinbutton > text > placeholder, row.entry.warning entry > text > placeholder, row.entry.warning label.separator, row.entry.warning .dim-label, row.entry.warning .subtitle, row.spin.warning .dimmed, row.spin.warning dialog.shortcuts .shortcut-row .title-box > .subtitle, dialog.shortcuts .shortcut-row row.spin.warning .title-box > .subtitle, row.spin.warning scale > value, row.spin.warning progressbar > text, row.spin.warning row.property > box.header > box.title > .title, row.spin.warning row.property.expander > box > list > row.header > box.header > box.title > .title, row.spin.warning row.expander image.expander-row-arrow, row.expander row.spin.warning image.expander-row-arrow, row.spin.warning spinbutton > text > placeholder, row.spin.warning entry > text > placeholder, row.spin.warning label.separator, row.spin.warning .dim-label, row.spin.warning .subtitle { opacity: 1; }

row.entry.success, row.spin.success { color: var(--accent-color); }

row.entry.success .dimmed, row.entry.success dialog.shortcuts .shortcut-row .title-box > .subtitle, dialog.shortcuts .shortcut-row row.entry.success .title-box > .subtitle, row.entry.success scale > value, row.entry.success progressbar > text, row.entry.success row.property > box.header > box.title > .title, row.entry.success row.property.expander > box > list > row.header > box.header > box.title > .title, row.entry.success row.expander image.expander-row-arrow, row.expander row.entry.success image.expander-row-arrow, row.entry.success spinbutton > text > placeholder, row.entry.success entry > text > placeholder, row.entry.success label.separator, row.entry.success .dim-label, row.entry.success .subtitle, row.spin.success .dimmed, row.spin.success dialog.shortcuts .shortcut-row .title-box > .subtitle, dialog.shortcuts .shortcut-row row.spin.success .title-box > .subtitle, row.spin.success scale > value, row.spin.success progressbar > text, row.spin.success row.property > box.header > box.title > .title, row.spin.success row.property.expander > box > list > row.header > box.header > box.title > .title, row.spin.success row.expander image.expander-row-arrow, row.expander row.spin.success image.expander-row-arrow, row.spin.success spinbutton > text > placeholder, row.spin.success entry > text > placeholder, row.spin.success label.separator, row.spin.success .dim-label, row.spin.success .subtitle { opacity: 1; }

/*************** AdwComboRow * */
row.combo image.dropdown-arrow:disabled { filter: Opacity(var(--disabled-opacity)); }

row.combo listview.inline { background: none; border: none; box-shadow: none; color: inherit; }

row.combo listview.inline, row.combo listview.inline:disabled { background: none; color: inherit; }

row.combo popover > contents { min-width: 120px; }

row.combo popover > contents .combo-searchbar { margin: 6px; }

row.combo popover > contents .combo-searchbar + scrolledwindow > undershoot.top { box-shadow: inset 0 1px color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to bottom, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

/****************** AdwExpanderRow * */
list.boxed-list-separate > row.expander row.header, list.boxed-list > row, list.content > row, list.boxed-list > row.expander row.header, list.content > row.expander row.header, row.expander list.nested > row { border-bottom: 1px solid var(--card-shade-color); }

list.boxed-list-separate > row.expander row.header, list.boxed-list > row, list.content > row, list.boxed-list > row.expander row.header, list.content > row.expander row.header, row.expander list.nested > row { outline: 0 solid transparent; outline-offset: 5px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-image 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), border-radius 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

list.boxed-list-separate > row.expander row.header:focus:focus-visible, list.boxed-list > row:focus:focus-visible, list.content > row:focus:focus-visible, list.boxed-list > row.expander row.header:focus:focus-visible, list.content > row.expander row.header:focus:focus-visible, row.expander list.nested > row:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -1px; }

list.boxed-list-separate > row.expander row.header:not(:selected).activatable:hover, list.boxed-list > row:not(:selected).activatable:hover, list.content > row:not(:selected).activatable:hover, list.boxed-list > row.expander row.header:not(:selected).activatable:hover, list.content > row.expander row.header:not(:selected).activatable:hover, row.expander list.nested > row:not(:selected).activatable:hover { background-color: color-mix(in srgb, currentColor 3%, transparent); }

list.boxed-list-separate > row.expander row.header:not(:selected).activatable:active, list.boxed-list > row:not(:selected).activatable:active, list.content > row:not(:selected).activatable:active, list.boxed-list > row.expander row.header:not(:selected).activatable:active, list.content > row.expander row.header:not(:selected).activatable:active, row.expander list.nested > row:not(:selected).activatable:active { background-color: color-mix(in srgb, currentColor 8%, transparent); }

list.boxed-list-separate > row.expander row.header:not(:selected).activatable.has-open-popup, list.boxed-list > row:not(:selected).activatable.has-open-popup, list.content > row:not(:selected).activatable.has-open-popup, list.boxed-list > row.expander row.header:not(:selected).activatable.has-open-popup, list.content > row.expander row.header:not(:selected).activatable.has-open-popup, row.expander list.nested > row:not(:selected).activatable.has-open-popup { background-color: color-mix(in srgb, currentColor 3%, transparent); }

row.expander { background: none; padding: 0px; }

row.expander > box > list { background: none; color: inherit; }

row.expander list.nested { background-color: color-mix(in srgb, var(--card-shade-color) 50%, transparent); color: inherit; }

row.expander image.expander-row-arrow { transition: -gtk-icon-transform 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

row.expander image.expander-row-arrow:dir(ltr) { margin-left: 3px; }

row.expander image.expander-row-arrow:dir(rtl) { margin-right: 3px; }

row.expander image.expander-row-arrow:dir(ltr) { -gtk-icon-transform: rotate(0.5turn); }

row.expander image.expander-row-arrow:dir(rtl) { -gtk-icon-transform: rotate(-0.5turn); }

row.expander image.expander-row-arrow:disabled { filter: Opacity(var(--disabled-opacity)); }

row.expander:checked image.expander-row-arrow { -gtk-icon-transform: rotate(0turn); opacity: 1; }

row.expander:checked image.expander-row-arrow:not(:disabled) { color: var(--accent-color); }

.osd row.expander:checked image.expander-row-arrow:not(:disabled) { color: inherit; }

/***************** Property rows * */
row.property > box.header > box.title > .title, row.property.expander > box > list > row.header > box.header > box.title > .title { font-size: smaller; }

row.property > box.header > box.title > .subtitle, row.property.expander > box > list > row.header > box.header > box.title > .subtitle { font-size: inherit; opacity: 1; }

row.property.monospace, row.property.monospace.expander > box > list > row.header { font-family: inherit; font-size: inherit; }

row.property.monospace > box.header > box.title > .subtitle, row.property.monospace.expander > box > list > row.header > box.header > box.title > .subtitle { font-family: var(--monospace-font-family); font-size: var(--monospace-font-size); }

/*************** AdwButtonRow * */
row.button > box { margin-left: 12px; margin-right: 12px; border-spacing: 6px; min-height: 40px; }

row.button > box > .icon:disabled { filter: Opacity(var(--disabled-opacity)); }

row.button.suggested-action { background-color: var(--accent-bg-color); color: var(--accent-fg-color); border-bottom: none; }

row.button.suggested-action { outline: 0 solid transparent; outline-offset: 5px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-image 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), border-radius 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

row.button.suggested-action:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: 1px; }

row.button.suggested-action:not(.expander):not(:selected).activatable:hover { background-color: var(--accent-bg-color); background-image: image(color-mix(in srgb, currentColor 10%, transparent)); }

row.button.suggested-action:not(.expander):not(:selected).activatable:active { background-color: var(--accent-bg-color); background-image: image(RGB(0 0 6/20%)); }

row.button.suggested-action:not(.expander):not(:selected).activatable.has-open-popup { background-color: var(--accent-bg-color); background-image: image(color-mix(in srgb, currentColor 10%, transparent)); }

row.button.suggested-action:disabled { opacity: var(--disabled-opacity); }

row.button.suggested-action:disabled > box > .icon:disabled, row.button.suggested-action:disabled > box > label:disabled { filter: none; }

row.button.destructive-action { color: var(--accent-color); --accent-bg-color: var(--destructive-bg-color); --accent-fg-color: var(--destructive-fg-color); --accent-color: var(--destructive-color); }

/***************** Boxed Lists * */
list.boxed-list > row.expander, list.content > row.expander { border: none; }

list.boxed-list > row:first-child, list.content > row:first-child, list.boxed-list > row:first-child.expander row.header, list.content > row:first-child.expander row.header { border-top-left-radius: 12px; border-top-right-radius: 12px; }

list.boxed-list > row:last-child, list.content > row:last-child, list.boxed-list > row:last-child.expander:not(:checked), list.boxed-list > row:last-child.expander:not(:checked) row.header, list.content > row:last-child.expander:not(:checked) row.header, list.boxed-list > row:last-child.expander:checked list.nested, list.content > row:last-child.expander:checked list.nested, list.boxed-list > row:last-child.expander:checked list.nested > row:last-child, list.content > row:last-child.expander:checked list.nested > row:last-child { border-bottom-left-radius: 12px; border-bottom-right-radius: 12px; border-bottom-width: 0; }

list.boxed-list-separate { background: none; color: var(--card-fg-color); }

list.boxed-list-separate > row { border: none; margin-bottom: 12px; }

list.boxed-list-separate > row:drop(active):focus, list.boxed-list-separate > row:drop(active) { box-shadow: 0 0 0 1px RGB(0 0 6/3%), 0 1px 3px 1px RGB(0 0 6/7%), 0 2px 6px 2px RGB(0 0 6/3%), inset 0 0 0 1px var(--accent-bg-color); }

list.boxed-list-separate > row:selected { background-color: color-mix(in srgb, var(--accent-bg-color) 25%, transparent); }

list.boxed-list-separate > row:last-child { margin-bottom: 0; }

list.boxed-list-separate > row { outline: 0 solid transparent; outline-offset: 5px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-image 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), border-radius 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

list.boxed-list-separate > row:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -1px; }

list.boxed-list-separate > row:not(.expander):not(:selected).activatable:hover { background-color: var(--card-bg-color); background-image: image(color-mix(in srgb, currentColor 3%, transparent)); }

list.boxed-list-separate > row:not(.expander):not(:selected).activatable:active { background-color: var(--card-bg-color); background-image: image(color-mix(in srgb, currentColor 8%, transparent)); }

list.boxed-list-separate > row:not(.expander):not(:selected).activatable.has-open-popup { background-color: var(--card-bg-color); background-image: image(color-mix(in srgb, currentColor 3%, transparent)); }

list.boxed-list-separate > row.entry:not(:selected).activatable.focused:hover, list.boxed-list-separate > row.entry:not(:selected).activatable.focused:active, list.boxed-list-separate > row.spin:not(:selected).activatable.focused:hover, list.boxed-list-separate > row.spin:not(:selected).activatable.focused:active { background-color: var(--card-bg-color); background-image: none; }

list.boxed-list-separate > row.expander row.header { border-top-left-radius: 12px; border-top-right-radius: 12px; }

list.boxed-list-separate > row.expander:not(:checked) row.header, list.boxed-list-separate > row.expander.expander:checked list.nested, list.boxed-list-separate > row.expander.expander:checked list.nested > row:last-child { border-bottom-left-radius: 12px; border-bottom-right-radius: 12px; border-bottom: none; }

popover.menu > contents { min-width: 120px; }

popover.menu scrollbar.vertical > range > trough > slider { min-height: 26px; }

popover.menu box.inline-buttons { padding: 0 12px; }

popover.menu box.inline-buttons button.image-button.model { min-height: 32px; min-width: 32px; padding: 0; border: none; outline: none; transition: none; }

popover.menu box.inline-buttons button.image-button.model:selected { background-color: color-mix(in srgb, currentColor 10%, transparent); }

popover.menu box.inline-buttons button.image-button.model:selected:active { background-color: color-mix(in srgb, currentColor 19%, transparent); }

popover.menu box.circular-buttons { padding: 12px 12px 6px; }

popover.menu box.circular-buttons button.circular.image-button.model { outline: none; padding: 11px; box-shadow: inset 0 0 0 1px color-mix(in srgb, currentColor var(--border-opacity), transparent); }

popover.menu box.circular-buttons button.circular.image-button.model:selected { background-color: color-mix(in srgb, currentColor 13%, transparent); box-shadow: none; }

popover.menu box.circular-buttons button.circular.image-button.model:selected:active { background-color: color-mix(in srgb, currentColor 19%, transparent); }

popover.menu > contents { padding: 0; }

popover.menu > contents > stack > box, popover.menu > contents > scrolledwindow > viewport > stack > box { padding: 6px; }

popover.menu separator { margin: 6px 0; }

popover.menu list separator { margin: 0; }

popover.menu accelerator { color: color-mix(in srgb, currentColor var(--dim-opacity), transparent); }

popover.menu accelerator:dir(ltr) { margin-left: 12px; }

popover.menu accelerator:dir(rtl) { margin-right: 12px; }

popover.menu check, popover.menu radio { min-width: 14px; min-height: 14px; -gtk-icon-size: 14px; padding: 2px; }

popover.menu check, popover.menu check:hover:checked, popover.menu check:hover:indeterminate, popover.menu check:hover:not(:checked):not(:indeterminate), popover.menu check:active:checked, popover.menu check:active:indeterminate, popover.menu check:active:not(:checked):not(:indeterminate), popover.menu radio, popover.menu radio:hover:checked, popover.menu radio:hover:indeterminate, popover.menu radio:hover:not(:checked):not(:indeterminate), popover.menu radio:active:checked, popover.menu radio:active:indeterminate, popover.menu radio:active:not(:checked):not(:indeterminate) { background: none; box-shadow: none; color: inherit; }

.osd popover.menu check, .osd popover.menu radio { background: none; color: inherit; }

popover.menu radio { padding: 1px; border: 1px solid color-mix(in srgb, currentColor 30%, transparent); }

popover.menu check.left, popover.menu radio.left, popover.menu arrow.left { margin-left: -2px; margin-right: 6px; }

popover.menu check.right, popover.menu radio.right, popover.menu arrow.right { margin-left: 6px; margin-right: -2px; }

popover.menu modelbutton { min-height: 32px; min-width: 40px; padding: 0 12px; border-radius: 9px; background-color: transparent; }

popover.menu modelbutton:hover, popover.menu modelbutton:selected { background-color: color-mix(in srgb, currentColor 10%, transparent); }

popover.menu modelbutton:active { background-color: color-mix(in srgb, currentColor 19%, transparent); }

popover.menu modelbutton arrow { background: none; min-width: 16px; min-height: 16px; opacity: 30%; }

popover.menu modelbutton arrow:hover { background: none; }

popover.menu modelbutton arrow:disabled { filter: Opacity(var(--disabled-opacity)); }

popover.menu modelbutton arrow.left { -gtk-icon-source: -gtk-icontheme("go-previous-symbolic"); }

popover.menu modelbutton arrow.right { -gtk-icon-source: -gtk-icontheme("go-next-symbolic"); }

popover.menu label.title { font-weight: bold; padding: 4px 32px; }

popover.menu list, popover.menu listview { background: none; color: inherit; }

popover.menu list > row, popover.menu listview > row { border-radius: 9px; padding: 0 12px; min-height: 32px; min-width: 40px; }

popover.menu list > row:selected, popover.menu listview > row:selected { background: none; }

popover.menu list > row:hover, popover.menu list > row:hover:selected.activatable, popover.menu listview > row:hover, popover.menu listview > row:hover:selected.activatable { background-color: color-mix(in srgb, currentColor 10%, transparent); }

popover.menu list > row:active, popover.menu list > row:active:selected.activatable, popover.menu listview > row:active, popover.menu listview > row:active:selected.activatable { background-color: color-mix(in srgb, currentColor 19%, transparent); }

popover.menu list > row.has-open-popup, popover.menu list > row.has-open-popup:selected.activatable, popover.menu listview > row.has-open-popup, popover.menu listview > row.has-open-popup:selected.activatable { background-color: color-mix(in srgb, currentColor 10%, transparent); }

popover.menu list > row > box, popover.menu listview > row > box { border-spacing: 6px; }

popover.menu contents > list, popover.menu contents > listview, popover.menu scrolledwindow > viewport > list, popover.menu scrolledwindow > listview { padding: 6px 0; }

popover.menu contents > list > row, popover.menu contents > listview > row, popover.menu scrolledwindow > viewport > list > row, popover.menu scrolledwindow > listview > row { margin: 0 6px; padding: 9px 12px; min-height: 0; }

menubar { box-shadow: inset 0 -1px color-mix(in srgb, currentColor var(--border-opacity), transparent); padding-bottom: 1px; }

menubar > item { min-height: 16px; padding: 4px 8px; border-radius: 9px; }

menubar > item:selected { background-color: color-mix(in srgb, currentColor 10%, transparent); }

menubar > item popover.menu popover.menu { padding: 0 0 4px 0; }

menubar > item popover.menu popover.menu > contents { margin: 0; border-radius: 15px; }

toolbarview > .top-bar menubar, toolbarview > .bottom-bar menubar { box-shadow: none; padding-bottom: 0; }

/******************** GtkMessageDialog * */
window.dialog.message { background-color: var(--dialog-bg-color); color: var(--dialog-fg-color); }

window.dialog.message.csd { outline: none; }

window.dialog.message .titlebar { min-height: 32px; background: none; box-shadow: none; }

window.dialog.message.csd:not(.solid-csd) { border-radius: 18px; }

window.dialog.message.csd .dialog-action-area { margin: 0; padding: 24px; padding-top: 21px; border-spacing: 12px; }

window.dialog.message.csd .dialog-action-area > button { min-height: 24px; padding: 10px 20px; border-radius: 12px; }

/******************** AdwMessageDialog * */
window.messagedialog, dialog-host > dialog.alert sheet, window.dialog-window.alert { background-color: var(--dialog-bg-color); color: var(--dialog-fg-color); }

dialog-host > dialog.alert sheet { border-radius: 18px; outline: none; }

window.messagedialog.csd:not(.solid-csd), window.dialog-window.alert.csd:not(.solid-csd) { border-radius: 18px; }

window.messagedialog.csd, window.dialog-window.alert.csd { outline: none; }

dialog-host > dialog.alert sheet .body-scrolled-window scrollbar.vertical, window.dialog-window.alert .body-scrolled-window scrollbar.vertical { padding-top: 6px; }

dialog-host > dialog.alert sheet .body-scrolled-window > viewport, window.dialog-window.alert .body-scrolled-window > viewport { border-top-left-radius: 18px; border-top-right-radius: 18px; }

window.messagedialog .message-area, dialog.alert .message-area { padding-top: 32px; padding-bottom: 9px; border-spacing: 24px; }

window.messagedialog .message-area.has-heading.has-body, dialog.alert .message-area.has-heading.has-body { border-spacing: 10px; }

window.messagedialog .message-area.has-heading.has-body > .child, dialog.alert .message-area.has-heading.has-body > .child { margin-top: 8px; }

window.messagedialog .message-area > .heading-bin, window.messagedialog .message-area > .body, window.messagedialog .message-area > .child, dialog.alert .message-area > .heading-bin, dialog.alert .message-area > .body, dialog.alert .message-area > .child { padding-left: 24px; padding-right: 24px; }

window.messagedialog .response-area, dialog.alert .response-area { padding: 24px; padding-top: 12px; border-spacing: 12px; }

window.messagedialog .response-area > button, dialog.alert .response-area > button { min-height: 24px; min-width: 60px; padding: 10px 20px; border-radius: 12px; }

window.messagedialog.short .message-area, dialog.alert.short .message-area { padding-top: 24px; border-spacing: 18px; }

window.messagedialog.short .message-area > .heading-bin, window.messagedialog.short .message-area > .body, window.messagedialog.short .message-area > .child, dialog.alert.short .message-area > .heading-bin, dialog.alert.short .message-area > .body, dialog.alert.short .message-area > .child { padding-left: 18px; padding-right: 18px; }

window.messagedialog.short .message-area.has-heading.has-body, dialog.alert.short .message-area.has-heading.has-body { border-spacing: 6px; }

window.messagedialog.short .response-area, dialog.alert.short .response-area { padding: 18px; padding-top: 9px; }

window.messagedialog.short .response-area > button, dialog.alert.short .response-area > button { min-width: 0; padding: 8px 16px; }

/********** Frames * */
frame, .frame { border: 1px solid color-mix(in srgb, currentColor var(--border-opacity), transparent); }

frame { border-radius: 12px; }

frame > label { margin: 4px; }

/************** Separators * */
separator { background: color-mix(in srgb, currentColor var(--border-opacity), transparent); min-width: 1px; min-height: 1px; }

separator.spacer { background: none; }

separator.spacer.horizontal { min-width: 12px; }

separator.spacer.vertical { min-height: 12px; }

/********** Toasts * */
toast { background: #505053; color: white; box-shadow: 0 1px 3px 1px RGB(0 0 6/7%), 0 2px 6px 2px RGB(0 0 6/3%); --standalone-color-oklab: Max(l, 0.85) a b; --accent-color: oklab(from var(--accent-bg-color) var(--standalone-color-oklab)); --destructive-color: oklab(from var(--destructive-bg-color) var(--standalone-color-oklab)); --success-color: oklab(from var(--success-bg-color) var(--standalone-color-oklab)); --warning-color: oklab(from var(--warning-bg-color) var(--standalone-color-oklab)); --error-color: oklab(from var(--error-bg-color) var(--standalone-color-oklab)); margin: 12px; margin-bottom: 24px; border-radius: 150px; border-spacing: 6px; padding: 6px; }

toast:dir(ltr) { padding-left: 12px; }

toast:dir(rtl) { padding-right: 12px; }

toast > widget { margin: 0 6px; }

/************** GtkVideo * */
video image.osd { min-width: 64px; min-height: 64px; border-radius: 32px; }

/****************** AdwAboutWindow * */
window.about .main-page > viewport > clamp > box, dialog.about .main-page > viewport > clamp > box { margin: 12px; border-spacing: 6px; }

window.about .main-page > viewport > clamp > box > box, dialog.about .main-page > viewport > clamp > box > box { margin-top: 18px; border-spacing: 18px; margin-bottom: 6px; }

window.about .main-page .app-version, dialog.about .main-page .app-version { padding: 3px 18px; color: var(--accent-color); border-radius: 999px; margin-top: 3px; }

window.about .subpage > viewport > clamp > box, dialog.about .subpage > viewport > clamp > box { margin: 18px 12px; border-spacing: 18px; }

window.about .subpage > clamp > textview, dialog.about .subpage > clamp > textview { background: none; color: inherit; }

/***************** AdwStatusPage * */
statuspage > scrolledwindow > viewport > box { margin: 36px 12px; border-spacing: 36px; }

statuspage > scrolledwindow > viewport > box > clamp > box { border-spacing: 12px; }

statuspage > scrolledwindow > viewport > box > clamp > box > .icon { color: color-mix(in srgb, currentColor var(--dim-opacity), transparent); -gtk-icon-size: 128px; }

statuspage > scrolledwindow > viewport > box > clamp > box > .icon:disabled { opacity: var(--disabled-opacity); }

statuspage > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) { margin-bottom: 24px; }

statuspage.compact > scrolledwindow > viewport > box { margin: 24px 12px; border-spacing: 24px; }

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .icon { -gtk-icon-size: 96px; }

statuspage.compact > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) { margin-bottom: 12px; }

statuspage.spinner > scrolledwindow > viewport > box { margin: 24px 12px; border-spacing: 24px; }

statuspage.spinner > scrolledwindow > viewport > box > clamp > box > .icon { -gtk-icon-size: 64px; }

statuspage.spinner > scrolledwindow > viewport > box > clamp > box > .icon:not(:last-child) { margin-bottom: 12px; }

/* Cards */
list.boxed-list, list.content, list.boxed-list-separate > row, .card { background-color: var(--card-bg-color); color: var(--card-fg-color); border-radius: 12px; box-shadow: 0 0 0 1px RGB(0 0 6/3%), 0 1px 3px 1px RGB(0 0 6/7%), 0 2px 6px 2px RGB(0 0 6/3%); }

.osd list.boxed-list, .osd list.content, .osd list.boxed-list-separate > row, list.osd.boxed-list, list.osd.content, list.boxed-list-separate > row.osd, .osd .card, .card.osd { background-color: color-mix(in srgb, currentColor 10%, transparent); color: RGB(255 255 255/90%); box-shadow: none; }

.card { outline: 0 solid transparent; outline-offset: 5px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

.card:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -1px; }

.card.activatable { transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

.card.activatable:hover { background-image: image(color-mix(in srgb, currentColor 3%, transparent)); }

.card.activatable:active { background-image: image(color-mix(in srgb, currentColor 8%, transparent)); }

/* Transition shadows */
navigation-view > dimming, overlay-split-view > dimming { background: var(--shade-color); }

navigation-view > shadow, overlay-split-view > shadow { min-width: 56px; min-height: 56px; }

navigation-view > shadow.left, overlay-split-view > shadow.left { background-image: linear-gradient(to right, color-mix(in srgb, var(--shade-color) 70%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 40px, RGB(from var(--shade-color) r g b/0) 56px), linear-gradient(to right, color-mix(in srgb, var(--shade-color) 40%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 7px, RGB(from var(--shade-color) r g b/0) 24px); }

navigation-view > shadow.right, overlay-split-view > shadow.right { background-image: linear-gradient(to left, color-mix(in srgb, var(--shade-color) 70%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 40px, RGB(from var(--shade-color) r g b/0) 56px), linear-gradient(to left, color-mix(in srgb, var(--shade-color) 40%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 7px, RGB(from var(--shade-color) r g b/0) 24px); }

navigation-view > shadow.up, overlay-split-view > shadow.up { background-image: linear-gradient(to bottom, color-mix(in srgb, var(--shade-color) 70%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 40px, RGB(from var(--shade-color) r g b/0) 56px), linear-gradient(to bottom, color-mix(in srgb, var(--shade-color) 40%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 7px, RGB(from var(--shade-color) r g b/0) 24px); }

navigation-view > shadow.down, overlay-split-view > shadow.down { background-image: linear-gradient(to top, color-mix(in srgb, var(--shade-color) 70%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 40px, RGB(from var(--shade-color) r g b/0) 56px), linear-gradient(to top, color-mix(in srgb, var(--shade-color) 40%, transparent), color-mix(in srgb, var(--shade-color) 14%, transparent) 7px, RGB(from var(--shade-color) r g b/0) 24px); }

notebook > header > tabs > tab:checked { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

notebook:focus:focus-visible > header > tabs > tab:checked { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

notebook > header { padding: 1px; border-color: color-mix(in srgb, currentColor var(--border-opacity), transparent); border-width: 1px; background-clip: padding-box; }

notebook > header > tabs { margin: -1px; }

notebook > header.top { border-bottom-style: solid; }

notebook > header.top > tabs { margin-bottom: -2px; }

notebook > header.top > tabs > tab:hover { box-shadow: inset 0 -4px color-mix(in srgb, currentColor var(--border-opacity), transparent); }

notebook > header.top > tabs > tab:checked { box-shadow: inset 0 -4px var(--accent-bg-color); }

notebook > header.bottom { border-top-style: solid; }

notebook > header.bottom > tabs { margin-top: -2px; }

notebook > header.bottom > tabs > tab:hover { box-shadow: inset 0 4px color-mix(in srgb, currentColor var(--border-opacity), transparent); }

notebook > header.bottom > tabs > tab:checked { box-shadow: inset 0 4px var(--accent-bg-color); }

notebook > header.left { border-right-style: solid; }

notebook > header.left > tabs { margin-right: -2px; }

notebook > header.left > tabs > tab:hover { box-shadow: inset -4px 0 color-mix(in srgb, currentColor var(--border-opacity), transparent); }

notebook > header.left > tabs > tab:checked { box-shadow: inset -4px 0 var(--accent-bg-color); }

notebook > header.right { border-left-style: solid; }

notebook > header.right > tabs { margin-left: -2px; }

notebook > header.right > tabs > tab:hover { box-shadow: inset 4px 0 color-mix(in srgb, currentColor var(--border-opacity), transparent); }

notebook > header.right > tabs > tab:checked { box-shadow: inset 4px 0 var(--accent-bg-color); }

notebook > header.top > tabs > arrow { border-top-style: none; }

notebook > header.bottom > tabs > arrow { border-bottom-style: none; }

notebook > header.top > tabs > arrow, notebook > header.bottom > tabs > arrow { margin-left: -5px; margin-right: -5px; padding-left: 4px; padding-right: 4px; }

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down { -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

notebook > header.left > tabs > arrow { border-left-style: none; }

notebook > header.right > tabs > arrow { border-right-style: none; }

notebook > header.left > tabs > arrow, notebook > header.right > tabs > arrow { margin-top: -5px; margin-bottom: -5px; padding-top: 4px; padding-bottom: 4px; }

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down { -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

notebook > header > tabs > arrow { min-height: 16px; min-width: 16px; border-radius: 0; }

notebook > header > tabs > arrow:hover:not(:active) { box-shadow: none; }

notebook > header > tabs > tab { transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); min-height: 30px; min-width: 30px; padding: 3px 12px; font-weight: normal; }

notebook > header > tabs > tab:hover, notebook > header > tabs > tab:active { background-color: color-mix(in srgb, currentColor 7%, transparent); }

notebook > header > tabs > tab:not(:checked) { outline-color: transparent; }

notebook > header > tabs > tab:disabled { filter: Opacity(var(--disabled-opacity)); }

notebook > header > tabs > tab:disabled a label, notebook > header > tabs > tab:disabled button { filter: none; }

notebook > header > tabs > tab button.flat { color: color-mix(in srgb, currentColor 30%, transparent); padding: 0; margin-top: 4px; margin-bottom: 4px; min-width: 20px; min-height: 20px; }

notebook > header > tabs > tab button.flat:hover, notebook > header > tabs > tab button.flat:active { color: currentColor; }

notebook > header > tabs > tab button.flat:last-child { margin-left: 4px; margin-right: -4px; }

notebook > header > tabs > tab button.flat:first-child { margin-left: -4px; margin-right: 4px; }

notebook > header.top > tabs, notebook > header.bottom > tabs { padding-left: 4px; padding-right: 4px; }

notebook > header.top > tabs:not(:only-child), notebook > header.bottom > tabs:not(:only-child) { margin-left: 3px; margin-right: 3px; }

notebook > header.top > tabs:not(:only-child):first-child, notebook > header.bottom > tabs:not(:only-child):first-child { margin-left: -1px; }

notebook > header.top > tabs:not(:only-child):last-child, notebook > header.bottom > tabs:not(:only-child):last-child { margin-right: -1px; }

notebook > header.top > tabs > tab, notebook > header.bottom > tabs > tab { margin-left: 4px; margin-right: 4px; }

notebook > header.left > tabs, notebook > header.right > tabs { padding-top: 4px; padding-bottom: 4px; }

notebook > header.left > tabs:not(:only-child), notebook > header.right > tabs:not(:only-child) { margin-top: 3px; margin-bottom: 3px; }

notebook > header.left > tabs:not(:only-child):first-child, notebook > header.right > tabs:not(:only-child):first-child { margin-top: -1px; }

notebook > header.left > tabs:not(:only-child):last-child, notebook > header.right > tabs:not(:only-child):last-child { margin-bottom: -1px; }

notebook > header.left > tabs > tab, notebook > header.right > tabs > tab { margin-top: 4px; margin-bottom: 4px; }

notebook > header.top > tabs > tab { padding-bottom: 4px; }

notebook > header.bottom > tabs > tab { padding-top: 4px; }

notebook > stack:not(:only-child) { background-color: var(--view-bg-color); }

paned > separator { min-width: 1px; min-height: 1px; background: none; background-size: 1px 1px; }

paned > separator.wide { min-width: 5px; min-height: 5px; }

paned.horizontal > separator:dir(ltr) { box-shadow: inset 1px 0 color-mix(in srgb, currentColor var(--border-opacity), transparent); }

paned.horizontal > separator:dir(rtl) { box-shadow: inset -1px 0 color-mix(in srgb, currentColor var(--border-opacity), transparent); }

paned.horizontal > separator.wide { box-shadow: inset 1px 0 color-mix(in srgb, currentColor var(--border-opacity), transparent), inset -1px 0 color-mix(in srgb, currentColor var(--border-opacity), transparent); }

paned.vertical > separator { box-shadow: inset 0 1px color-mix(in srgb, currentColor var(--border-opacity), transparent); }

paned.vertical > separator.wide { box-shadow: inset 0 1px color-mix(in srgb, currentColor var(--border-opacity), transparent), inset 0 -1px color-mix(in srgb, currentColor var(--border-opacity), transparent); }

toolbarview.undershoot-top popover scrolledwindow:not(.undershoot-top) undershoot.top, toolbarview.undershoot-bottom popover scrolledwindow:not(.undershoot-bottom) undershoot.bottom { background: none; box-shadow: none; }

popover { --shade-color: var(--popover-shade-color); }

popover.background { background-color: transparent; font: initial; }

popover > arrow, popover > contents { background-color: var(--popover-bg-color); color: var(--popover-fg-color); background-clip: padding-box; border: 1px solid RGB(0 0 0/14%); box-shadow: 0 1px 5px 1px RGB(0 0 0/9%), 0 2px 14px 3px RGB(0 0 0/5%); }

popover > contents { padding: 8px; border-radius: 15px; }

popover > contents > list, popover > contents > .view, window.print:not(.ssd-frame) popover > contents > .dialog-action-box, popover > contents > toolbar { border-style: none; background-color: transparent; }

.solid-csd popover { background: var(--popover-bg-color); color: var(--popover-fg-color); border: 1px solid var(--border-color); }

.solid-csd popover > arrow, .solid-csd popover > contents { box-shadow: none; border-radius: 0; background-clip: border-box; border: none; }

.osd popover, popover.touch-selection, popover.magnifier { background-color: transparent; color: RGB(255 255 255/90%); }

.osd popover > arrow, .osd popover > contents, popover.touch-selection > arrow, popover.touch-selection > contents, popover.magnifier > arrow, popover.magnifier > contents { border-color: RGB(255 255 255/10%); box-shadow: none; }

preferencespage > scrolledwindow > viewport > clamp > box { margin: 24px 12px; border-spacing: 24px; }

preferencesgroup > box, preferencesgroup > box box.labels { border-spacing: 6px; }

preferencesgroup > box > box.header:not(.single-line) { margin-bottom: 6px; }

preferencesgroup > box > box.single-line { min-height: 34px; }

progressbar.horizontal > trough { min-width: 150px; }

progressbar.horizontal > trough, progressbar.horizontal > trough > progress { min-height: 8px; }

progressbar.vertical > trough { min-height: 80px; }

progressbar.vertical > trough, progressbar.vertical > trough > progress { min-width: 8px; }

progressbar > text { font-size: smaller; }

progressbar:disabled { filter: Opacity(var(--disabled-opacity)); }

progressbar > trough > progress { /* share most of scales' */ border-radius: 99px; }

progressbar > trough > progress.left { border-top-left-radius: 99px; border-bottom-left-radius: 99px; }

progressbar > trough > progress.right { border-top-right-radius: 99px; border-bottom-right-radius: 99px; }

progressbar > trough > progress.top { border-top-right-radius: 99px; border-top-left-radius: 99px; }

progressbar > trough > progress.bottom { border-bottom-right-radius: 99px; border-bottom-left-radius: 99px; }

progressbar.osd { min-width: 2px; min-height: 2px; }

progressbar.osd > trough { border-style: none; border-radius: 0; background-color: transparent; box-shadow: none; }

progressbar.osd > trough > progress { border-style: none; border-radius: 0; }

progressbar.osd.horizontal > trough, progressbar.osd.horizontal > trough > progress { min-height: 2px; }

progressbar.osd.vertical > trough, progressbar.osd.vertical > trough > progress { min-width: 2px; }

progressbar > trough.empty > progress { all: unset; }

scale > trough > fill, scale > trough, progressbar > trough { transition: background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); border-radius: 99px; background-color: color-mix(in srgb, currentColor 15%, transparent); }

scale > trough > highlight, progressbar > trough > progress { transition: background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); border-radius: 99px; background-color: var(--accent-bg-color); color: var(--accent-fg-color); }

scale { min-height: 10px; min-width: 10px; padding: 12px; }

scale > trough > slider { outline: 0 solid transparent; outline-offset: 6px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

scale:focus:focus-visible > trough > slider { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: 0; }

scale > trough > slider { background-color: color-mix(in srgb, white 80%, var(--view-bg-color)); box-shadow: 0 0 0 1px RGB(0 0 6 / 10%), 0 2px 4px RGB(0 0 6/20%); border-radius: 100%; min-width: 20px; min-height: 20px; margin: -8px; }

scale:hover > trough, scale:active > trough { background-color: color-mix(in srgb, currentColor 20%, transparent); }

scale:hover > trough > highlight, scale:active > trough > highlight { background-image: image(color-mix(in srgb, currentColor 10%, transparent)); }

scale:hover > trough > slider, scale:active > trough > slider { background-color: white; }

scale:disabled { filter: Opacity(var(--disabled-opacity)); }

scale:disabled > trough > slider { box-shadow: 0 0 0 1px RGB(0 0 6 / 10%), 0 2px 4px transparent; outline-color: RGB(0 0 6 / 20%); }

scale.marks-before:not(.marks-after) > trough > slider, scale.marks-after:not(.marks-before) > trough > slider { transform: rotate(45deg); box-shadow: 0 0 0 1px RGB(0 0 6 / 10%), 1px 1px 4px RGB(0 0 6/20%); }

scale.marks-before:not(.marks-after) > trough > slider:disabled, scale.marks-after:not(.marks-before) > trough > slider:disabled { box-shadow: 0 0 0 1px RGB(0 0 6 / 10%), 1px 1px 4px transparent; }

scale.horizontal > marks { color: color-mix(in srgb, currentColor var(--dim-opacity), transparent); }

scale.horizontal > marks.top { margin-bottom: 6px; }

scale.horizontal > marks.bottom { margin-top: 6px; }

scale.horizontal > marks indicator { background-color: currentColor; min-height: 6px; min-width: 1px; }

scale.horizontal:not(.marks-before) > value.top { margin-bottom: 12px; }

scale.horizontal:not(.marks-after) > value.bottom { margin-top: 12px; }

scale.horizontal > value.left { margin-right: 9px; }

scale.horizontal > value.right { margin-left: 9px; }

scale.horizontal.fine-tune > trough { margin: -3px 0px; }

scale.horizontal.fine-tune > trough > slider { margin: -5px -8px; }

scale.horizontal.fine-tune > marks.top { margin-top: 3px; }

scale.horizontal.fine-tune > marks.bottom { margin-bottom: 3px; }

scale.horizontal.fine-tune > marks indicator { min-height: 3px; }

scale.horizontal.marks-before { padding-top: 0; }

scale.horizontal.marks-before > trough > slider { border-top-left-radius: 0; }

scale.horizontal.marks-after { padding-bottom: 0; }

scale.horizontal.marks-after > trough > slider { border-bottom-right-radius: 0; }

scale.horizontal.marks-before.marks-after > trough > slider { border-radius: 100%; }

scale.vertical > marks { color: color-mix(in srgb, currentColor var(--dim-opacity), transparent); }

scale.vertical > marks.top { margin-right: 6px; }

scale.vertical > marks.bottom { margin-left: 6px; }

scale.vertical > marks indicator { background-color: currentColor; min-height: 1px; min-width: 6px; }

scale.vertical:not(.marks-before) > value.left { margin-right: 12px; }

scale.vertical:not(.marks-after) > value.right { margin-left: 12px; }

scale.vertical > value.top { margin-bottom: 9px; }

scale.vertical > value.bottom { margin-top: 9px; }

scale.vertical.fine-tune > trough { margin: 0px -3px; }

scale.vertical.fine-tune > trough > slider { margin: -8px -5px; }

scale.vertical.fine-tune > marks.top { margin-left: 3px; }

scale.vertical.fine-tune > marks.bottom { margin-right: 3px; }

scale.vertical.fine-tune > marks indicator { min-width: 3px; }

scale.vertical.marks-before { padding-left: 0; }

scale.vertical.marks-before > trough > slider { border-bottom-left-radius: 0; }

scale.vertical.marks-after { padding-right: 0; }

scale.vertical.marks-after > trough > slider { border-top-right-radius: 0; }

scale.color { padding: 0; }

scale.color > trough { border: none; background: none; border-radius: 10px; }

scale.color > trough > slider { margin: 0; background-color: RGB(255 255 255/80%); }

scale.color.fine-tune { padding: 2px; }

scale.color.fine-tune > trough > slider { margin: -2px; }

scrollbar > range > trough { margin: 9px; transition: all 200ms linear; border-radius: 99px; }

scrollbar > range > trough > slider { min-width: 8px; min-height: 8px; margin: -8px; border: 8px solid transparent; border-radius: 99px; background-clip: padding-box; transition: all 200ms linear; background-color: color-mix(in srgb, currentColor 20%, transparent); }

scrollbar > range > trough > slider:hover { background-color: color-mix(in srgb, currentColor 40%, transparent); }

scrollbar > range > trough > slider:active { background-color: color-mix(in srgb, currentColor 60%, transparent); }

scrollbar > range > trough > slider:disabled { opacity: 0; }

scrollbar.horizontal > range > trough { margin-top: 8px; margin-bottom: 8px; }

scrollbar.vertical > range > trough { margin-left: 8px; margin-right: 8px; }

scrollbar.overlay-indicator { background: none; color: inherit; box-shadow: none; padding: 0; }

scrollbar.overlay-indicator > range > trough { outline: 1px solid transparent; }

scrollbar.overlay-indicator > range > trough > slider { outline: 1px solid color-mix(in srgb, var(--scrollbar-outline-color) 60%, transparent); outline-offset: -8px; }

scrollbar.overlay-indicator:not(.hovering) > range > trough > slider { min-width: 3px; min-height: 3px; outline-color: color-mix(in srgb, var(--scrollbar-outline-color) 35%, transparent); }

scrollbar.overlay-indicator.hovering > range > trough { background-color: color-mix(in srgb, currentColor 10%, transparent); }

scrollbar.overlay-indicator.horizontal > range > trough > slider { min-width: 40px; }

scrollbar.overlay-indicator.horizontal.hovering > range > trough > slider { min-height: 8px; }

scrollbar.overlay-indicator.horizontal:not(.hovering) > range > trough { margin-top: 4px; margin-bottom: 4px; }

scrollbar.overlay-indicator.vertical > range > trough > slider { min-height: 40px; }

scrollbar.overlay-indicator.vertical.hovering > range > trough > slider { min-width: 8px; }

scrollbar.overlay-indicator.vertical:not(.hovering) > range > trough { margin-left: 4px; margin-right: 4px; }

scrollbar.horizontal > range > trough > slider { min-width: 40px; }

scrollbar.vertical > range > trough > slider { min-height: 40px; }

scrollbar > range.fine-tune > trough > slider, scrollbar > range.fine-tune > trough > slider:hover, scrollbar > range.fine-tune > trough > slider:active { background-color: color-mix(in srgb, var(--accent-color) 60%, transparent); }

scrolledwindow > overshoot.top { background-image: radial-gradient(farthest-side at top, color-mix(in srgb, currentColor 12%, transparent) 85%, RGB(from currentColor r g b/0)), radial-gradient(farthest-side at top, color-mix(in srgb, currentColor 5%, transparent), RGB(from currentColor r g b/0)); background-size: 100% 3%, 100% 50%; background-repeat: no-repeat; background-position: top; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow > overshoot.bottom { background-image: radial-gradient(farthest-side at bottom, color-mix(in srgb, currentColor 12%, transparent) 85%, RGB(from currentColor r g b/0)), radial-gradient(farthest-side at bottom, color-mix(in srgb, currentColor 5%, transparent), RGB(from currentColor r g b/0)); background-size: 100% 3%, 100% 50%; background-repeat: no-repeat; background-position: bottom; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow > overshoot.left { background-image: radial-gradient(farthest-side at left, color-mix(in srgb, currentColor 12%, transparent) 85%, RGB(from currentColor r g b/0)), radial-gradient(farthest-side at left, color-mix(in srgb, currentColor 5%, transparent), RGB(from currentColor r g b/0)); background-size: 3% 100%, 50% 100%; background-repeat: no-repeat; background-position: left; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow > overshoot.right { background-image: radial-gradient(farthest-side at right, color-mix(in srgb, currentColor 12%, transparent) 85%, RGB(from currentColor r g b/0)), radial-gradient(farthest-side at right, color-mix(in srgb, currentColor 5%, transparent), RGB(from currentColor r g b/0)); background-size: 3% 100%, 50% 100%; background-repeat: no-repeat; background-position: right; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow.undershoot-top > undershoot.top { box-shadow: inset 0 1px color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to bottom, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

scrolledwindow.undershoot-bottom > undershoot.bottom { box-shadow: inset 0 -1px color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to top, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

scrolledwindow.undershoot-start:dir(ltr) > undershoot.left { box-shadow: inset 1px 0 color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to right, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

scrolledwindow.undershoot-start:dir(rtl) > undershoot.right { box-shadow: inset -1px 0 color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to left, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

scrolledwindow.undershoot-end:dir(ltr) > undershoot.right { box-shadow: inset -1px 0 color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to left, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

scrolledwindow.undershoot-end:dir(rtl) > undershoot.left { box-shadow: inset 1px 0 color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to right, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

dialog.shortcuts preferencespage > scrolledwindow > viewport > clamp > box { border-spacing: 18px; }

dialog.shortcuts preferencespage > scrolledwindow > viewport > clamp > box preferencesgroup + preferencesgroup box.header { margin-top: 6px; }

dialog.shortcuts .navigation-box { margin-top: -12px; }

dialog.shortcuts .navigation-box > button { border-radius: 99px; padding: 3px 12px; }

dialog.shortcuts .shortcut-row { padding: 9px 12px; min-height: 36px; }

dialog.shortcuts .shortcut-row .title-box { border-spacing: 3px; }

shortcut-label, shortcut-label > box { border-spacing: 6px; }

shortcut-label .keycap { background: color-mix(in srgb, currentColor 10%, transparent); box-shadow: inset 0 -2px var(--card-shade-color); border-radius: 6px; padding: 6px; min-width: 20px; }

shortcut-label > .dimmed, shortcut-label > .dim-label, headerbar shortcut-label > .subtitle, windowtitle shortcut-label > .subtitle, shortcut-label > label.separator, row shortcut-label > label.subtitle, row.expander shortcut-label > image.expander-row-arrow, dialog.shortcuts .shortcut-row shortcut-label.title-box > .subtitle { padding: 6px 0; }

.sidebar-pane { background-color: var(--sidebar-bg-color); color: var(--sidebar-fg-color); --shade-color: var(--sidebar-shade-color); }

.sidebar-pane:backdrop { background-color: var(--sidebar-backdrop-color); transition: background-color 200ms ease-out; }

.sidebar-pane banner > revealer > widget { background-color: color-mix(in srgb, var(--banner-color) 30%, var(--sidebar-bg-color)); color: var(--sidebar-fg-color); }

.sidebar-pane banner > revealer > widget:backdrop { background-color: color-mix(in srgb, var(--banner-color) 15%, var(--sidebar-bg-color)); }

.sidebar-pane:dir(ltr), .sidebar-pane:dir(ltr) banner > revealer > widget, .sidebar-pane.end:dir(rtl), .sidebar-pane.end:dir(rtl) banner > revealer > widget { box-shadow: inset -1px 0 var(--sidebar-border-color); }

.sidebar-pane:dir(rtl), .sidebar-pane:dir(rtl) banner > revealer > widget, .sidebar-pane.end:dir(ltr), .sidebar-pane.end:dir(ltr) banner > revealer > widget { box-shadow: inset 1px 0 var(--sidebar-border-color); }

/* Middle pane in three-pane setups */
:not(.isolated) > .content-pane :not(.isolated) > .sidebar-pane, :not(.isolated) > .sidebar-pane :not(.isolated) > .content-pane { background-color: var(--secondary-sidebar-bg-color); color: var(--secondary-sidebar-fg-color); --shade-color: var(--secondary-sidebar-shade-color); }

:not(.isolated) > .content-pane :not(.isolated) > .sidebar-pane:backdrop, :not(.isolated) > .sidebar-pane :not(.isolated) > .content-pane:backdrop { background-color: var(--secondary-sidebar-backdrop-color); transition: background-color 200ms ease-out; }

:not(.isolated) > .content-pane :not(.isolated) > .sidebar-pane banner > revealer > widget, :not(.isolated) > .sidebar-pane :not(.isolated) > .content-pane banner > revealer > widget { background-color: color-mix(in srgb, var(--banner-color) 30%, var(--secondary-sidebar-bg-color)); color: var(--secondary-sidebar-fg-color); }

:not(.isolated) > .content-pane :not(.isolated) > .sidebar-pane banner > revealer > widget:backdrop, :not(.isolated) > .sidebar-pane :not(.isolated) > .content-pane banner > revealer > widget:backdrop { background-color: color-mix(in srgb, var(--banner-color) 15%, var(--secondary-sidebar-bg-color)); }

:not(.isolated) > .content-pane :not(.isolated) > .sidebar-pane:dir(ltr), :not(.isolated) > .content-pane :not(.isolated) > .sidebar-pane:dir(ltr) banner > revealer > widget, :not(.isolated) > .content-pane :not(.isolated) > .sidebar-pane.end:dir(rtl), :not(.isolated) > .content-pane :not(.isolated) > .sidebar-pane.end:dir(rtl) banner > revealer > widget, :not(.isolated) > .sidebar-pane :not(.isolated) > .content-pane:dir(ltr), :not(.isolated) > .sidebar-pane :not(.isolated) > .content-pane:dir(ltr) banner > revealer > widget, :not(.isolated) > .sidebar-pane :not(.isolated) > .content-pane.end:dir(rtl), :not(.isolated) > .sidebar-pane :not(.isolated) > .content-pane.end:dir(rtl) banner > revealer > widget { box-shadow: inset -1px 0 var(--secondary-sidebar-border-color); }

:not(.isolated) > .content-pane :not(.isolated) > .sidebar-pane:dir(rtl), :not(.isolated) > .content-pane :not(.isolated) > .sidebar-pane:dir(rtl) banner > revealer > widget, :not(.isolated) > .content-pane :not(.isolated) > .sidebar-pane.end:dir(ltr), :not(.isolated) > .content-pane :not(.isolated) > .sidebar-pane.end:dir(ltr) banner > revealer > widget, :not(.isolated) > .sidebar-pane :not(.isolated) > .content-pane:dir(rtl), :not(.isolated) > .sidebar-pane :not(.isolated) > .content-pane:dir(rtl) banner > revealer > widget, :not(.isolated) > .sidebar-pane :not(.isolated) > .content-pane.end:dir(ltr), :not(.isolated) > .sidebar-pane :not(.isolated) > .content-pane.end:dir(ltr) banner > revealer > widget { box-shadow: inset 1px 0 var(--secondary-sidebar-border-color); }

.sidebar-pane .sidebar-pane { background-color: transparent; color: inherit; }

stacksidebar row { padding: 10px 4px; }

stacksidebar row > label { padding-left: 6px; padding-right: 6px; }

stacksidebar row.needs-attention > label { background-size: 6px 6px, 0 0; }

/********************** Navigation Sidebar * */
.navigation-sidebar { padding: 6px 0; }

.navigation-sidebar, .navigation-sidebar.view, window.print:not(.ssd-frame) .navigation-sidebar.dialog-action-box, .navigation-sidebar.view:disabled { background-color: transparent; color: inherit; }

.navigation-sidebar.background, .navigation-sidebar.background:disabled { background-color: var(--window-bg-color); color: var(--window-fg-color); }

.navigation-sidebar row.activatable:hover, .navigation-sidebar child.activatable:hover, .navigation-sidebar flowboxchild:hover { background-color: color-mix(in srgb, currentColor 7%, transparent); }

.navigation-sidebar row.activatable:active, .navigation-sidebar child.activatable:active, .navigation-sidebar flowboxchild:active { background-color: color-mix(in srgb, currentColor 16%, transparent); }

.navigation-sidebar row.activatable.has-open-popup, .navigation-sidebar child.activatable.has-open-popup, .navigation-sidebar flowboxchild.has-open-popup { background-color: color-mix(in srgb, currentColor 7%, transparent); }

.navigation-sidebar row.activatable:selected:hover, .navigation-sidebar child.activatable:selected:hover, .navigation-sidebar flowboxchild:selected:hover { background-color: color-mix(in srgb, currentColor 13%, transparent); }

.navigation-sidebar row.activatable:selected:active, .navigation-sidebar child.activatable:selected:active, .navigation-sidebar flowboxchild:selected:active { background-color: color-mix(in srgb, currentColor 19%, transparent); }

.navigation-sidebar row.activatable:selected.has-open-popup, .navigation-sidebar child.activatable:selected.has-open-popup, .navigation-sidebar flowboxchild:selected.has-open-popup { background-color: color-mix(in srgb, currentColor 13%, transparent); }

.navigation-sidebar row:selected, .navigation-sidebar child:selected, .navigation-sidebar flowboxchild:selected { background-color: color-mix(in srgb, currentColor 10%, transparent); }

.navigation-sidebar > separator { margin: 6px; }

.navigation-sidebar > row { border-radius: 9px; min-height: 36px; padding: 0 8px; margin: 0 6px 2px; }

.navigation-sidebar > child, .navigation-sidebar > flowboxchild { border-radius: 9px; margin: 3px; padding: 8px; }

gridview.navigation-sidebar, flowbox.navigation-sidebar { padding: 3px; }

@keyframes spin { to { transform: rotate(1turn); } }

spinner { background: none; opacity: 0; -gtk-icon-source: -gtk-icontheme("process-working-symbolic"); }

spinner:checked { opacity: 1; animation: spin 1s linear infinite; }

spinner:checked:disabled { opacity: var(--disabled-opacity); }

/************** AdwSpinner * */
image.spinner:disabled { opacity: var(--disabled-opacity); }

spinbutton { padding: 0; border-spacing: 0; /* :not here just to bump specificity above that of the list button styling */ }

spinbutton > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) { margin: 0; border-radius: 0; box-shadow: none; border-style: solid; border-color: color-mix(in srgb, currentColor 10%, transparent); }

spinbutton:not(.vertical) { /* :not here just to bump specificity above that of the list button styling */ }

spinbutton:not(.vertical) > text { min-width: 28px; padding: 6px; }

spinbutton:not(.vertical) > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), spinbutton:not(.vertical) > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) { min-height: 16px; min-width: 22px; padding-bottom: 0; padding-top: 0; border-left-width: 1px; }

spinbutton:not(.vertical) > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl), spinbutton:not(.vertical) > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl) { border-left-width: 0; border-right-width: 1px; }

spinbutton:not(.vertical) > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child, spinbutton:not(.vertical) > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(ltr):last-child { border-radius: 0 9px 9px 0; }

spinbutton:not(.vertical) > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child, spinbutton:not(.vertical) > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):dir(rtl):first-child { border-radius: 9px 0 0 9px; }

spinbutton.vertical { /* :not here just to bump specificity above that of the list button styling */ }

spinbutton.vertical > text { min-height: 30px; min-width: 30px; }

spinbutton.vertical > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child, spinbutton.vertical > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):last-child { border-top-width: 1px; border-radius: 0 0 9px 9px; }

spinbutton.vertical > button.image-button.up:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):first-child, spinbutton.vertical > button.image-button.down:not(.flat):not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):first-child { border-bottom-width: 1px; border-radius: 9px 9px 0 0; }

switch { border-radius: 14px; padding: 3px; background-color: color-mix(in srgb, currentColor 15%, transparent); }

switch:hover { background-color: color-mix(in srgb, currentColor 20%, transparent); }

switch:active { background-color: color-mix(in srgb, currentColor 25%, transparent); }

switch { outline: 0 solid transparent; outline-offset: 5px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

switch:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: 1px; }

switch:disabled { filter: Opacity(var(--disabled-opacity)); }

switch > slider { min-width: 20px; min-height: 20px; border-radius: 50%; background-color: color-mix(in srgb, white 80%, var(--view-bg-color)); box-shadow: 0 2px 4px RGB(0 0 6/20%); }

switch > slider:disabled { box-shadow: 0 2px 4px transparent; }

switch:hover > slider, switch:active > slider { background: white; }

switch:checked { color: var(--accent-fg-color); background-color: var(--accent-bg-color); }

switch:checked:hover { background-image: image(color-mix(in srgb, currentColor 10%, transparent)); }

switch:checked:active { background-image: image(RGB(0 0 6/20%)); }

switch:checked > slider { background-color: white; }

.osd switch:checked { background-color: RGB(255 255 255/60%); }

tabbar .box { background-color: var(--headerbar-bg-color); color: var(--headerbar-fg-color); box-shadow: inset 0 -1px var(--headerbar-shade-color); padding: 1px; padding-top: 0; }

tabbar .box:backdrop { background-color: var(--headerbar-backdrop-color); transition: background-color 200ms ease-out; }

tabbar .box:backdrop > scrolledwindow, tabbar .box:backdrop > .start-action, tabbar .box:backdrop > .end-action { filter: opacity(0.5); transition: filter 200ms ease-out; }

tabbar tabbox { padding-bottom: 6px; padding-top: 6px; min-height: 34px; }

tabbar tabbox > tabboxchild { border-radius: 9px; }

tabbar tabbox > tabboxchild { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

tabbar tabbox > tabboxchild:focus-within:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

tabbar tabbox > separator { margin-top: 3px; margin-bottom: 3px; transition: opacity 150ms ease-in-out; }

tabbar tabbox > separator.hidden { opacity: 0; }

tabbar tabbox > revealer > indicator { min-width: 2px; border-radius: 2px; margin: 3px 6px; background: color-mix(in srgb, var(--accent-color) 50%, transparent); }

tabbar tab { transition: background 150ms ease-in-out; }

tabbar tab:selected { background-color: color-mix(in srgb, currentColor 10%, transparent); }

tabbar tab:selected:hover { background-color: color-mix(in srgb, currentColor 13%, transparent); }

tabbar tab:selected:active { background-color: color-mix(in srgb, currentColor 19%, transparent); }

tabbar tab:hover { background-color: color-mix(in srgb, currentColor 7%, transparent); }

tabbar tab:active { background-color: color-mix(in srgb, currentColor 16%, transparent); }

tabbar tabbox.single-tab tab, tabbar tabbox.single-tab tab:hover, tabbar tabbox.single-tab tab:active { background: none; }

tabbar .start-action, tabbar .end-action { padding: 6px 5px; }

tabbar .start-action:dir(ltr), tabbar .end-action:dir(rtl) { padding-right: 0; }

tabbar .start-action:dir(rtl), tabbar .end-action:dir(ltr) { padding-left: 0; }

toolbarview > .top-bar tabbar .box, toolbarview > .bottom-bar tabbar .box, tabbar.inline .box { background-color: transparent; color: inherit; box-shadow: none; padding-bottom: 0; }

toolbarview > .top-bar tabbar .box:backdrop, toolbarview > .bottom-bar tabbar .box:backdrop, tabbar.inline .box:backdrop { background-color: transparent; transition: none; }

toolbarview > .top-bar tabbar .box:backdrop > scrolledwindow, toolbarview > .bottom-bar tabbar .box:backdrop > scrolledwindow, tabbar.inline .box:backdrop > scrolledwindow, toolbarview > .top-bar tabbar .box:backdrop > .start-action, toolbarview > .bottom-bar tabbar .box:backdrop > .start-action, tabbar.inline .box:backdrop > .start-action, toolbarview > .top-bar tabbar .box:backdrop > .end-action, toolbarview > .bottom-bar tabbar .box:backdrop > .end-action, tabbar.inline .box:backdrop > .end-action { filter: none; transition: none; }

toolbarview > .top-bar .collapse-spacing tabbar tabbox, toolbarview > .bottom-bar .collapse-spacing tabbar tabbox, toolbarview > .top-bar .collapse-spacing tabbar .start-action, toolbarview > .bottom-bar .collapse-spacing tabbar .start-action, toolbarview > .top-bar .collapse-spacing tabbar .end-action, toolbarview > .bottom-bar .collapse-spacing tabbar .end-action { padding-top: 3px; padding-bottom: 3px; }

dnd tab { background-color: var(--headerbar-bg-color); background-image: image(color-mix(in srgb, currentColor 19%, transparent)); color: var(--headerbar-fg-color); box-shadow: 0 0 0 1px RGB(0 0 0/3%), 0 1px 3px 1px RGB(0 0 0/7%), 0 2px 6px 2px RGB(0 0 0/3%); margin: 25px; }

tabbar tab, dnd tab { min-height: 26px; padding: 4px; border-radius: 9px; }

tabbar tab button.image-button, dnd tab button.image-button { padding: 0; margin: 0; min-width: 24px; min-height: 24px; border-radius: 99px; }

tabbar tab indicator, dnd tab indicator { min-height: 2px; border-radius: 2px; background: color-mix(in srgb, var(--accent-color) 50%, transparent); transform: translateY(4px); }

tabgrid > tabgridchild .card { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

tabgrid > tabgridchild:focus:focus-visible .card { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: 0; }

tabthumbnail { border-radius: 16px; transition: box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background-color cubic-bezier(0.25, 0.46, 0.45, 0.94); }

tabthumbnail > box { margin: 6px; }

tabthumbnail:drop(active) { box-shadow: inset 0 0 0 2px color-mix(in srgb, var(--accent-bg-color) 40%, transparent); background-color: color-mix(in srgb, var(--accent-bg-color) 10%, transparent); }

tabthumbnail .needs-attention:dir(ltr) { transform: translate(8px, -8px); }

tabthumbnail .needs-attention:dir(rtl) { transform: translate(-8px, -8px); }

tabthumbnail .needs-attention > widget { background: var(--accent-color); min-width: 12px; min-height: 12px; border-radius: 8px; margin: 3px; box-shadow: 0 1px 2px color-mix(in srgb, var(--accent-color) 40%, transparent); }

tabthumbnail .card { background: none; color: inherit; }

tabthumbnail .card picture { outline: 1px solid RGB(255 255 255/7%); outline-offset: -1px; border-radius: 12px; }

tabthumbnail.pinned .card { background-color: var(--thumbnail-bg-color); color: var(--thumbnail-fg-color); }

tabthumbnail .icon-title-box { border-spacing: 6px; }

tabthumbnail .tab-unpin-icon { margin: 6px; min-width: 24px; min-height: 24px; }

tabthumbnail button { border-radius: 99px; }

tabthumbnail button.image-button { padding: 0; }

tabthumbnail button, tabthumbnail button:hover, tabthumbnail button:active { background: none; box-shadow: none; }

tabthumbnail button > image { margin: 6px; background-color: color-mix(in srgb, var(--thumbnail-bg-color) 75%, transparent); min-width: 24px; min-height: 24px; border-radius: 9999px; transition: background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

tabthumbnail button:hover > image { background-color: color-mix(in srgb, var(--thumbnail-bg-color) calc(0.9 * 75%), currentColor calc(0.1 * 75%)); }

tabthumbnail button:active > image { background-color: color-mix(in srgb, var(--thumbnail-bg-color) calc(0.8 * 75%), currentColor calc(0.2 * 75%)); }

taboverview > .overview { color: var(--overview-fg-color); background-color: var(--overview-bg-color); }

taboverview > .overview .new-tab-button { margin: 18px; }

tabview:drop(active), tabbox:drop(active), tabgrid:drop(active) { box-shadow: none; }

cursor-handle { all: unset; padding: 24px 20px; }

cursor-handle > contents { min-width: 20px; min-height: 20px; border-radius: 50%; background-color: var(--accent-bg-color); }

cursor-handle.top > contents { border-top-right-radius: 0; }

cursor-handle.bottom > contents { border-top-left-radius: 0; transform: translateX(1px); }

cursor-handle.insertion-cursor > contents { border-top-left-radius: 0; transform: translateX(1px) translateY(4px) rotate(45deg); }

magnifier { background-color: var(--view-bg-color); }

/****************** AdwToggleGroup * */
toggle-group { ---group-padding: 3px; background: color-mix(in srgb, currentColor 10%, transparent); border-radius: 9px; padding: var(---group-padding); }

toggle-group:disabled { background-color: color-mix(in srgb, color-mix(in srgb, currentColor 10%, transparent) var(--disabled-opacity), transparent); }

toggle-group > toggle { border-radius: calc(9px - var(---group-padding)); font-weight: bold; min-width: 34px; min-height: calc(34px - var(---group-padding) * 2); }

toggle-group > toggle.image-button > image:disabled { filter: opacity(30%); }

toggle-group > toggle.text-button { min-width: calc(18px + var(---group-padding) * 2); padding-left: calc(11px - var(---group-padding)); padding-right: calc(11px - var(---group-padding)); }

toggle-group > toggle.text-button > label:disabled { filter: opacity(30%); }

toggle-group > toggle.image-text-button { min-width: calc(10px + var(---group-padding) * 2); padding-left: calc(11px - var(---group-padding)); padding-right: calc(11px - var(---group-padding)); }

toggle-group > toggle.image-text-button > buttoncontent > box > label { padding: 0; }

toggle-group > toggle.image-text-button > buttoncontent > box > image:disabled, toggle-group > toggle.image-text-button > buttoncontent > box > label:disabled { filter: opacity(30%); }

toggle-group > toggle { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

toggle-group > toggle:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: 0; }

toggle-group > toggle:hover { background-color: color-mix(in srgb, currentColor 7%, transparent); }

toggle-group > toggle:active, toggle-group > toggle.keyboard-activating { background-color: color-mix(in srgb, currentColor 16%, transparent); }

toggle-group > toggle:checked { background-color: var(--active-toggle-bg-color); color: var(--active-toggle-fg-color); box-shadow: 0 1px 3px 1px RGB(0 0 6/7%), 0 2px 6px 2px RGB(0 0 6/3%); }

toggle-group > toggle:checked:disabled { background-color: color-mix(in srgb, var(--active-toggle-bg-color) var(--disabled-opacity), transparent); }

toggle-group > toggle:checked:disabled { box-shadow: none; }

toggle-group.osd, .osd toggle-group { --active-toggle-bg-color: white; --active-toggle-fg-color: rgb(0 0 0 / 80%); }

toggle-group.osd:not(.flat) > toggle:checked, .osd toggle-group:not(.flat) > toggle:checked { --accent-bg-color: rgb(0 0 0 / 75%); --accent-fg-color: white; --standalone-color-oklab: Min(l, 0.5) a b; --accent-color: oklab(from var(--accent-bg-color) var(--standalone-color-oklab)); --destructive-color: oklab(from var(--destructive-bg-color) var(--standalone-color-oklab)); --success-color: oklab(from var(--success-bg-color) var(--standalone-color-oklab)); --warning-color: oklab(from var(--warning-bg-color) var(--standalone-color-oklab)); --error-color: oklab(from var(--error-bg-color) var(--standalone-color-oklab)); box-shadow: 0 1px 3px 1px RGB(0 0 6/7%), 0 2px 6px 2px RGB(0 0 6/3%); }

toggle-group.osd:not(.flat) > toggle:checked, .osd toggle-group:not(.flat) > toggle:checked { outline: 0 solid transparent; outline-offset: 5px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

toggle-group.osd:not(.flat) > toggle:checked:focus:focus-visible, .osd toggle-group:not(.flat) > toggle:checked:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: 1px; }

toggle-group.osd:not(.flat) > toggle:checked:focus:focus-visible, .osd toggle-group:not(.flat) > toggle:checked:focus:focus-visible { outline-color: color-mix(in srgb, RGB(255 255 255/75%) 50%, transparent); }

toggle-group.osd:not(.flat) > toggle:checked:disabled, .osd toggle-group:not(.flat) > toggle:checked:disabled { box-shadow: none; }

toggle-group.vertical > toggle:not(.text-button):not(.image-text-button) { min-width: calc(34px - var(---group-padding) * 2); }

toggle-group > separator { transition: opacity 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

toggle-group > separator.horizontal { margin: calc(6px - var(---group-padding)) 1px; }

toggle-group > separator.vertical { margin: 1px calc(6px - var(---group-padding)); }

toggle-group > separator.hidden { opacity: 0; }

toggle-group > separator:disabled { filter: Opacity(var(--disabled-opacity)); }

toggle-group.round { border-radius: 17px; }

toggle-group.round toggle { border-radius: calc(17px - var(---group-padding)); }

toggle-group.round toggle.text-button, toggle-group.round toggle.image-text-button { padding-left: calc(15px - var(---group-padding)); padding-right: calc(15px - var(---group-padding)); }

toggle-group.round separator.horizontal { margin: calc(9px - var(---group-padding)) 1px; }

toggle-group.round separator.vertical { margin: 1px calc(9px - var(---group-padding)); }

toggle-group.flat { ---group-padding: 0px; background: none; color: inherit; box-shadow: none; }

toggle-group.flat > toggle { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), background 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), box-shadow 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

toggle-group.flat > toggle:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

toggle-group.flat > toggle:checked { background-color: color-mix(in srgb, currentColor 10%, transparent); color: inherit; box-shadow: none; box-shadow: none; }

toggle-group.flat > toggle:checked:hover { background-color: color-mix(in srgb, currentColor 13%, transparent); }

toggle-group.flat > toggle:checked:active, toggle-group.flat > toggle:checked.keyboard-activating { background-color: color-mix(in srgb, currentColor 19%, transparent); }

toggle-group.flat > toggle:checked:disabled { background-color: color-mix(in srgb, color-mix(in srgb, currentColor 10%, transparent) var(--disabled-opacity), transparent); }

toggle-group.flat > separator { background: none; }

/************************* AdwInlineViewSwitcher * */
inline-view-switcher > toggle-group.icons > toggle { min-width: 34px; }

inline-view-switcher > toggle-group.labels > toggle { min-width: calc(18px + var(---group-padding) * 2); }

inline-view-switcher > toggle-group.labels > toggle > widget > indicatorbin { padding-left: calc(11px - var(---group-padding)); padding-right: calc(11px - var(---group-padding)); }

inline-view-switcher > toggle-group.labels > toggle > widget > indicatorbin > label { padding: 0 6px; }

inline-view-switcher > toggle-group.labels > toggle > widget > indicatorbin > indicator, inline-view-switcher > toggle-group.labels > toggle > widget > indicatorbin > mask { transform: translateY(2px); }

inline-view-switcher > toggle-group.both > toggle { min-width: calc(10px + var(---group-padding) * 2); }

inline-view-switcher > toggle-group.both > toggle > widget > box { padding-left: calc(15px - var(---group-padding)); padding-right: calc(15px - var(---group-padding)); border-spacing: 6px; }

actionbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled, searchbar > revealer > box menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled, .toolbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled, headerbar menubutton:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled { filter: none; }

actionbar > revealer > box menubutton.raised > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).arrow-button:disabled:not(:checked), searchbar > revealer > box menubutton.raised > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).arrow-button:disabled:not(:checked), .toolbar menubutton.raised > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).arrow-button:disabled:not(:checked), headerbar menubutton.raised > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).arrow-button:disabled:not(:checked), actionbar > revealer > box menubutton.raised > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button:disabled:not(:checked), searchbar > revealer > box menubutton.raised > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button:disabled:not(:checked), .toolbar menubutton.raised > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button:disabled:not(:checked), headerbar menubutton.raised > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-button:disabled:not(:checked), actionbar > revealer > box menubutton.raised > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-text-button:disabled:not(:checked), searchbar > revealer > box menubutton.raised > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-text-button:disabled:not(:checked), .toolbar menubutton.raised > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-text-button:disabled:not(:checked), headerbar menubutton.raised > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque).image-text-button:disabled:not(:checked) { filter: none; }

actionbar > revealer > box menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), actionbar > revealer > box menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), searchbar > revealer > box menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), .toolbar menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque), headerbar menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque) { color: inherit; background-color: transparent; }

actionbar > revealer > box menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled:not(:checked), searchbar > revealer > box menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled:not(:checked), .toolbar menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled:not(:checked), headerbar menubutton.suggested-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled:not(:checked), actionbar > revealer > box menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled:not(:checked), searchbar > revealer > box menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled:not(:checked), .toolbar menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled:not(:checked), headerbar menubutton.opaque > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled:not(:checked) { filter: none; }

actionbar > revealer > box menubutton.destructive-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled:not(:checked), searchbar > revealer > box menubutton.destructive-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled:not(:checked), .toolbar menubutton.destructive-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled:not(:checked), headerbar menubutton.destructive-action > button:not(.raised):not(.suggested-action):not(.destructive-action):not(.opaque):disabled:not(:checked) { filter: none; }

actionbar > revealer > box switch, searchbar > revealer > box switch, .toolbar switch, headerbar switch { margin-top: 4px; margin-bottom: 4px; }

.toolbar { padding: 6px; border-spacing: 6px; }

.toolbar.osd { padding: 12px; border-radius: 15px; }

toolbarview > .top-bar .collapse-spacing .toolbar, toolbarview > .bottom-bar .collapse-spacing .toolbar { padding-top: 3px; padding-bottom: 3px; }

/**************** GtkSearchBar * */
searchbar > revealer > box { padding: 6px 6px 7px 6px; background-color: var(--headerbar-bg-color); color: var(--headerbar-fg-color); box-shadow: inset 0 -1px var(--headerbar-shade-color); }

searchbar > revealer > box:backdrop { background-color: var(--headerbar-backdrop-color); transition: background-color 200ms ease-out; }

searchbar > revealer > box:backdrop > * { filter: opacity(0.5); transition: filter 200ms ease-out; }

searchbar > revealer > box .close { min-width: 18px; min-height: 18px; padding: 4px; border-radius: 50%; }

searchbar > revealer > box .close:dir(ltr) { margin-left: 10px; margin-right: 4px; }

searchbar > revealer > box .close:dir(rtl) { margin-left: 4px; margin-right: 10px; }

toolbarview > .top-bar searchbar > revealer > box, toolbarview > .bottom-bar searchbar > revealer > box, searchbar.inline > revealer > box, window.appchooser:not(.ssd-frame) searchbar > revealer > box, window.shortcuts:not(.ssd-frame) searchbar > revealer > box { background-color: transparent; color: inherit; box-shadow: none; padding-bottom: 6px; }

toolbarview > .top-bar searchbar > revealer > box:backdrop, toolbarview > .bottom-bar searchbar > revealer > box:backdrop, searchbar.inline > revealer > box:backdrop { background-color: transparent; transition: none; }

toolbarview > .top-bar searchbar > revealer > box:backdrop > *, toolbarview > .bottom-bar searchbar > revealer > box:backdrop > *, searchbar.inline > revealer > box:backdrop > * { filter: none; transition: none; }

toolbarview > .top-bar .collapse-spacing searchbar > revealer > box, toolbarview > .bottom-bar .collapse-spacing searchbar > revealer > box, window.appchooser.csd:not(.ssd-frame) searchbar > revealer > box, window.shortcuts:not(.ssd-frame) searchbar > revealer > box { padding-top: 3px; padding-bottom: 3px; }

/**************** GtkActionBar * */
actionbar > revealer > box { background-color: var(--headerbar-bg-color); color: var(--headerbar-fg-color); box-shadow: inset 0 1px var(--headerbar-shade-color); padding: 7px 6px 6px 6px; }

actionbar > revealer > box, actionbar > revealer > box > box.start, actionbar > revealer > box > box.end { border-spacing: 6px; }

actionbar > revealer > box:backdrop { background-color: var(--headerbar-backdrop-color); transition: background-color 200ms ease-out; }

actionbar > revealer > box:backdrop > * { filter: opacity(0.5); transition: filter 200ms ease-out; }

toolbarview > .top-bar actionbar > revealer > box, toolbarview > .bottom-bar actionbar > revealer > box { background-color: transparent; color: inherit; box-shadow: none; padding-top: 6px; }

toolbarview > .top-bar actionbar > revealer > box:backdrop, toolbarview > .bottom-bar actionbar > revealer > box:backdrop { background-color: transparent; transition: none; }

toolbarview > .top-bar actionbar > revealer > box:backdrop > *, toolbarview > .bottom-bar actionbar > revealer > box:backdrop > * { filter: none; transition: none; }

toolbarview > .top-bar .collapse-spacing actionbar > revealer > box, toolbarview > .bottom-bar .collapse-spacing actionbar > revealer > box { padding-top: 3px; padding-bottom: 3px; }

/************* AdwBanner * */
banner { --banner-color: #7d7d83; }

banner > revealer > widget { /* There are 2 more instances in _sidebars.css, keep in sync with that */ background-color: color-mix(in srgb, var(--banner-color) 30%, var(--window-bg-color)); color: var(--window-fg-color); padding: 6px; }

banner > revealer > widget:backdrop { background-color: color-mix(in srgb, var(--banner-color) 15%, var(--window-bg-color)); transition: background-color 200ms ease-out; }

banner > revealer > widget:backdrop > label, banner > revealer > widget:backdrop > button { filter: opacity(0.5); transition: filter 200ms ease-out; }

/****************** AdwToolbarView * */
toolbarview > .top-bar .collapse-spacing, toolbarview > .bottom-bar .collapse-spacing { padding-top: 3px; padding-bottom: 3px; }

toolbarview > .top-bar.raised, toolbarview > .bottom-bar.raised { background-color: var(--headerbar-bg-color); color: var(--headerbar-fg-color); }

toolbarview > .top-bar.raised:backdrop, toolbarview > .bottom-bar.raised:backdrop { background-color: var(--headerbar-backdrop-color); transition: background-color 200ms ease-out; }

toolbarview > .top-bar:backdrop > windowhandle, toolbarview > .bottom-bar:backdrop > windowhandle { filter: opacity(0.5); transition: filter 200ms ease-out; }

toolbarview > .top-bar.raised { box-shadow: 0 1px color-mix(in srgb, var(--headerbar-shade-color) 50%, transparent), 0 2px 4px color-mix(in srgb, var(--headerbar-shade-color) 50%, transparent); }

toolbarview > .top-bar.raised.border { box-shadow: 0 1px var(--headerbar-darker-shade-color); }

toolbarview > .bottom-bar.raised { box-shadow: 0 -1px color-mix(in srgb, var(--headerbar-shade-color) 50%, transparent), 0 -2px 4px color-mix(in srgb, var(--headerbar-shade-color) 50%, transparent); }

toolbarview > .bottom-bar.raised.border { box-shadow: 0 -1px var(--headerbar-darker-shade-color); }

toolbarview.undershoot-top scrolledwindow > undershoot.top { box-shadow: inset 0 1px color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to bottom, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

toolbarview.undershoot-bottom scrolledwindow > undershoot.bottom { box-shadow: inset 0 -1px color-mix(in srgb, var(--shade-color) 75%, transparent); background: linear-gradient(to top, color-mix(in srgb, var(--shade-color) 75%, transparent), transparent 4px); }

window.devel toolbarview > .top-bar { background-image: cross-fade(5% -gtk-recolor(url("assets/devel-symbolic.svg")), image(transparent)); background-repeat: repeat-x; }

window.devel sheet toolbarview > .top-bar { background-image: unset; background-repeat: unset; }

tooltip { padding: 6px 10px; border-radius: 9px; box-shadow: none; }

tooltip.background { background-color: RGB(0 0 6/80%); background-clip: padding-box; border: 1px solid RGB(255 255 255/10%); color: white; }

tooltip > box { border-spacing: 6px; }

.view, window.print:not(.ssd-frame) .dialog-action-box, textview > text, dialog-host > dialog.view sheet, window.print:not(.ssd-frame) dialog-host > dialog.dialog-action-box sheet, iconview { color: var(--view-fg-color); background-color: var(--view-bg-color); }

.view:disabled, window.print:not(.ssd-frame) .dialog-action-box:disabled, textview > text:disabled, dialog-host > dialog.view sheet:disabled, window.print:not(.ssd-frame) dialog-host > dialog.dialog-action-box sheet:disabled, iconview:disabled { color: color-mix(in srgb, var(--view-fg-color) var(--disabled-opacity), transparent); background-color: color-mix(in srgb, var(--window-bg-color) 60%, var(--view-bg-color)); }

.view:selected:focus, .view:selected, window.print:not(.ssd-frame) .dialog-action-box:selected, textview > text:selected, dialog-host > dialog.view sheet:selected, window.print:not(.ssd-frame) dialog-host > dialog.dialog-action-box sheet:selected, iconview:selected { background-color: color-mix(in srgb, var(--accent-bg-color) 25%, transparent); border-radius: 9px; }

textview { caret-color: currentColor; }

textview > text, textview > text:disabled { background-color: transparent; }

textview.inline, textview.inline:disabled, textview.inline > text { background-color: transparent; color: inherit; }

textview > border { background-color: color-mix(in srgb, var(--window-bg-color), var(--view-bg-color) 50%); }

textview:drop(active) { caret-color: var(--accent-bg-color); }

rubberband { border: 1px solid var(--accent-color); background-color: color-mix(in srgb, var(--accent-color) 20%, transparent); }

flowbox > flowboxchild, gridview > child { padding: 3px; border-radius: 9px; }

flowbox > flowboxchild, gridview > child { outline: 0 solid transparent; outline-offset: 4px; transition: outline-color 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-width 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94), outline-offset 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

flowbox > flowboxchild:focus:focus-visible, gridview > child:focus:focus-visible { outline-color: color-mix(in srgb, var(--accent-color) 50%, transparent); outline-width: 2px; outline-offset: -2px; }

flowbox > flowboxchild:selected, gridview > child:selected { background-color: color-mix(in srgb, var(--accent-bg-color) 25%, transparent); }

flowbox > flowboxchild:hover, gridview > child.activatable:hover { background-color: color-mix(in srgb, currentColor 4%, transparent); }

flowbox > flowboxchild:active, gridview > child.activatable:active { background-color: color-mix(in srgb, currentColor 8%, transparent); }

flowbox > flowboxchild:selected:hover, gridview > child.activatable:selected:hover { background-color: color-mix(in srgb, var(--accent-bg-color) 32%, transparent); }

flowbox > flowboxchild:selected:active, gridview > child.activatable:selected:active { background-color: color-mix(in srgb, var(--accent-bg-color) 39%, transparent); }

flowbox.view:disabled, window.print:not(.ssd-frame) flowbox.dialog-action-box:disabled, gridview.view:disabled, window.print:not(.ssd-frame) gridview.dialog-action-box:disabled { color: var(--view-fg-color); }

viewswitcher { border-spacing: 3px; min-height: 34px; }

viewswitcher.narrow { margin-top: -3px; margin-bottom: -3px; min-height: 6px; }

viewswitcher button.toggle { padding: 0; }

viewswitcher button.toggle > stack > box.narrow { font-size: 0.75rem; padding-top: 4px; }

viewswitcher button.toggle > stack > box.narrow > label { min-height: 18px; padding-left: 3px; padding-right: 3px; padding-bottom: 2px; }

viewswitcher button.toggle > stack > box.wide { padding: 2px 12px; border-spacing: 6px; }

/********************** AdwViewSwitcherBar * */
viewswitcherbar actionbar > revealer > box { padding-left: 0; padding-right: 0; padding-top: 7px; }

toolbarview > .top-bar .collapse-spacing viewswitcherbar actionbar > revealer > box, toolbarview > .bottom-bar .collapse-spacing viewswitcherbar actionbar > revealer > box { padding-top: 6px; }

/************************ AdwViewSwitcherTitle * */
viewswitchertitle { margin-top: -6px; margin-bottom: -6px; }

viewswitchertitle viewswitcher { margin-left: 12px; margin-right: 12px; }

viewswitchertitle viewswitcher.narrow { margin-top: 3px; margin-bottom: 3px; }

viewswitchertitle viewswitcher.wide { margin-top: 6px; margin-bottom: 6px; }

viewswitchertitle windowtitle { margin-top: 0; margin-bottom: 0; }

/******************* AdwIndicatorBin * */
indicatorbin > indicator, indicatorbin > mask { min-width: 6px; min-height: 6px; border-radius: 100px; }

indicatorbin > indicator { margin: 1px; background: color-mix(in srgb, currentColor 40%, transparent); }

indicatorbin > mask { padding: 1px; background: black; }

indicatorbin.needs-attention > indicator { background: var(--accent-color); }

indicatorbin.badge > indicator, indicatorbin.badge > mask { min-height: 13px; }

indicatorbin.badge > indicator > label { font-size: 0.6rem; font-weight: bold; padding-left: 4px; padding-right: 4px; color: white; }

indicatorbin.badge.needs-attention > indicator { background: var(--accent-bg-color); }

indicatorbin.badge.needs-attention > indicator > label { color: var(--accent-fg-color); }

window.csd { box-shadow: 0 0 14px 5px RGB(0 0 0/15%), 0 0 5px 2px RGB(0 0 0/10%), 0 0 0 1px RGB(0 0 0 / 5%); margin: 0px; border-radius: var(--window-radius); outline: 1px solid RGB(255 255 255/7%); outline-offset: -1px; }

window.csd:backdrop { box-shadow: 0 0 14px 5px transparent, 0 0 10px 5px RGB(0 0 0/8%), 0 0 0 1px RGB(0 0 0 / 5%); transition: box-shadow 200ms ease-out; }

window.csd.dialog.message, window.csd.messagedialog { box-shadow: 0 0 14px 2px RGB(0 0 6/3%), 0 0 5px 2px RGB(0 0 6/10%), 0 0 0 1px RGB(0 0 0 / 5%); }

window.csd.tiled, window.csd.tiled-top, window.csd.tiled-left, window.csd.tiled-right, window.csd.tiled-bottom { --window-radius: 0px; outline: none; box-shadow: 0 0 0 1px color-mix(in srgb, currentColor var(--border-opacity), transparent), 0 0 0 20px transparent; }

window.csd.tiled:backdrop, window.csd.tiled-top:backdrop, window.csd.tiled-left:backdrop, window.csd.tiled-right:backdrop, window.csd.tiled-bottom:backdrop { box-shadow: 0 0 0 1px color-mix(in srgb, currentColor var(--border-opacity), transparent), 0 0 0 20px transparent; }

window.csd.maximized, window.csd.fullscreen { --window-radius: 0px; outline: none; box-shadow: none; transition: none; }

window.csd.ssd-frame { border-bottom-left-radius: 0; border-bottom-right-radius: 0; }

window.solid-csd { margin: 0; padding: 5px; --window-radius: 0px; box-shadow: inset 0 0 0 5px color-mix(in srgb, currentColor var(--border-opacity), transparent), inset 0 0 0 4px var(--headerbar-bg-color), inset 0 0 0 1px color-mix(in srgb, currentColor var(--border-opacity), transparent); }

window.solid-csd:backdrop { box-shadow: inset 0 0 0 5px color-mix(in srgb, currentColor var(--border-opacity), transparent), inset 0 0 0 4px var(--headerbar-backdrop-color), inset 0 0 0 1px color-mix(in srgb, currentColor var(--border-opacity), transparent); }

window.ssd { box-shadow: 0 0 0 1px RGB(0 0 0 / 5%); }

/* Public colors from Default */
@define-color theme_bg_color @window_bg_color;
@define-color theme_fg_color @window_fg_color;
@define-color theme_base_color @view_bg_color;
@define-color theme_text_color @view_fg_color;
@define-color theme_selected_bg_color @accent_bg_color;
@define-color theme_selected_fg_color @accent_fg_color;
@define-color insensitive_bg_color color-mix(in srgb, @window_bg_color 60%, @view_bg_color);
@define-color insensitive_fg_color color-mix(in srgb, @window_fg_color 50%, transparent);
@define-color insensitive_base_color @view_bg_color;
@define-color borders color-mix(in srgb, currentColor 15%, transparent);
@define-color theme_unfocused_bg_color @window_bg_color;
@define-color theme_unfocused_fg_color @window_fg_color;
@define-color theme_unfocused_base_color @view_bg_color;
@define-color theme_unfocused_text_color @view_fg_color;
@define-color theme_unfocused_selected_bg_color @accent_bg_color;
@define-color theme_unfocused_selected_fg_color @accent_fg_color;
@define-color unfocused_insensitive_color @insensitive_bg_color;
@define-color unfocused_borders @borders;
